@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -11,14 +10,10 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifdef OLD_HEADER_FILENAME
-#include <iostream.h>
-#else
+#include <cstdlib>
 #include <iostream>
-#endif
 #include <string>
 
-#include "H5private.h" // for HDfree
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
@@ -27,9 +22,9 @@
 #include "H5FcreatProp.h"
 #include "H5OcreatProp.h"
 #include "H5DcreatProp.h"
-#include "H5StrcreatProp.h"
 #include "H5LcreatProp.h"
 #include "H5LaccProp.h"
+#include "H5DaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
 #include "H5AbstractDs.h"
@@ -38,12 +33,10 @@
 #include "H5Attribute.h"
 
 namespace H5 {
-#ifndef H5_NO_STD
 using std::cerr;
 using std::endl;
-#endif // H5_NO_STD
 
-// class H5Object; // forward declaration for UserData4Aiterate
+class H5Object; // forward declaration for UserData4Aiterate
 
 //--------------------------------------------------------------------------
 // Function:    Attribute default constructor
@@ -56,7 +49,7 @@ Attribute::Attribute() : AbstractDs(), H5Location(), id(H5I_INVALID_HID)
 
 //--------------------------------------------------------------------------
 // Function:    Attribute copy constructor
-///\brief       Copy constructor: makes a copy of the original Attribute object.
+///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       original  - IN: Original Attribute object to copy
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -241,8 +234,9 @@ Attribute::getInMemDataSize() const
     }
 
     // Calculate and return the size of the data
-    size_t data_size = type_size * num_elements;
-    return (data_size);
+    size_t data_size = type_size * static_cast<size_t>(num_elements);
+
+    return data_size;
 }
 
 //--------------------------------------------------------------------------
@@ -316,10 +310,10 @@ Attribute::getName(char *attr_name, size_t buf_size) const
 H5std_string
 Attribute::getName() const
 {
-    H5std_string attr_name(""); // attribute name to return
+    H5std_string attr_name; // attribute name to return
 
     // Preliminary call to get the size of the attribute name
-    ssize_t name_size = H5Aget_name(id, static_cast<size_t>(0), NULL);
+    ssize_t name_size = H5Aget_name(id, 0, NULL);
 
     // If H5Aget_name failed, throw exception
     if (name_size < 0) {
@@ -330,11 +324,15 @@ Attribute::getName() const
     }
     // Attribute's name exists, retrieve it
     else if (name_size > 0) {
-        char *name_C = new char[name_size + 1]; // temporary C-string
-        HDmemset(name_C, 0, name_size + 1);     // clear buffer
+        // The actual size is the cast value + 1 for the terminal ASCII NUL
+        // (unfortunate in/out type sign mismatch)
+        size_t actual_name_size = static_cast<size_t>(name_size) + 1;
+
+        // Create buffer for C string
+        char *name_C = new char[actual_name_size]();
 
         // Use overloaded function
-        name_size = getName(name_C, name_size + 1);
+        name_size = getName(name_C, actual_name_size);
 
         // Convert the C attribute name to return
         attr_name = name_C;
@@ -342,8 +340,9 @@ Attribute::getName() const
         // Clean up resource
         delete[] name_C;
     }
+
     // Return attribute's name
-    return (attr_name);
+    return attr_name;
 }
 
 //--------------------------------------------------------------------------
@@ -395,12 +394,12 @@ Attribute::getName(H5std_string &attr_name, size_t len) const
     // If no length is provided, get the entire attribute name
     if (len == 0) {
         attr_name = getName();
-        name_size = attr_name.length();
+        name_size = static_cast<ssize_t>(attr_name.length());
     }
     // If length is provided, get that number of characters in name
     else {
-        char *name_C = new char[len + 1]; // temporary C-string
-        HDmemset(name_C, 0, len + 1);     // clear buffer
+        // Create buffer for C string
+        char *name_C = new char[len + 1]();
 
         // Use overloaded function
         name_size = getName(name_C, len + 1);
@@ -414,7 +413,7 @@ Attribute::getName(H5std_string &attr_name, size_t len) const
     // Otherwise, keep attr_name intact
 
     // Return name size
-    return (name_size);
+    return name_size;
 }
 
 //--------------------------------------------------------------------------
@@ -434,7 +433,7 @@ Attribute::getName(H5std_string &attr_name, size_t len) const
 //--------------------------------------------------------------------------
 // ssize_t Attribute::getName(size_t len, H5std_string& attr_name) const
 //{
-//  return (getName(attr_name, len));
+//    return (getName(attr_name, len));
 //}
 
 //--------------------------------------------------------------------------
@@ -453,31 +452,6 @@ Attribute::getStorageSize() const
     return (storage_size);
 }
 
-//--------------------------------------------------------------------------
-// Function:    Attribute::flush
-///\brief       Flushes all buffers associated with a file specified by
-///             this attribute, to disk.
-///\param       scope - IN: Specifies the scope of the flushing action,
-///             which can be either of these values:
-///             \li \c H5F_SCOPE_GLOBAL - Flushes the entire virtual file
-///             \li \c H5F_SCOPE_LOCAL - Flushes only the specified file
-///\exception   H5::AttributeIException
-///\par Description
-///             This attribute is used to identify the file to be flushed.
-// Programmer   Binh-Minh Ribler - 2013
-// Modification
-//      Mar 2013 - BMR
-//              Duplicated from H5Location
-//--------------------------------------------------------------------------
-void
-Attribute::flush(H5F_scope_t scope) const
-{
-    herr_t ret_value = H5Fflush(getId(), scope);
-    if (ret_value < 0) {
-        throw AttributeIException("Attribute::flush", "H5Fflush failed");
-    }
-}
-
 //--------------------------------------------------------------------------
 // Function:    Attribute::getId
 ///\brief       Get the id of this attribute
@@ -488,6 +462,11 @@ Attribute::flush(H5F_scope_t scope) const
 //              addition, member IdComponent::id is moved into subclasses, and
 //              IdComponent::getId now becomes pure virtual function.
 // Programmer   Binh-Minh Ribler - May, 2008
+// Modification
+//      Aug 2016 - BMR
+//              Note that Attribute is now inheriting from H5Location, because
+//              an attribute id can be used to specify a location in HDF5
+//              library.
 //--------------------------------------------------------------------------
 hid_t
 Attribute::getId() const
@@ -517,10 +496,10 @@ Attribute::p_get_type() const
 
 //--------------------------------------------------------------------------
 // Function:    Attribute::p_read_fixed_len (private)
-// brief        Reads a fixed length \a H5std_string from an attribute.
-// param        mem_type  - IN: Attribute datatype (in memory)
-// param        strg      - IN: Buffer for read string
-// exception    H5::AttributeIException
+// brief       Reads a fixed length \a H5std_string from an attribute.
+// param       mem_type  - IN: Attribute datatype (in memory)
+// param       strg      - IN: Buffer for read string
+// exception   H5::AttributeIException
 // Programmer   Binh-Minh Ribler - Jul, 2009
 // Modification
 //      Jul 2009
@@ -552,13 +531,13 @@ Attribute::p_read_fixed_len(const DataType &mem_type, H5std_string &strg) const
 
 //--------------------------------------------------------------------------
 // Function:    Attribute::p_read_variable_len (private)
-// brief        Reads a variable length \a H5std_string from an attribute.
-// param        mem_type  - IN: Attribute datatype (in memory)
-// param        strg      - IN: Buffer for read string
-// exception    H5::AttributeIException
+// brief       Reads a variable length \a H5std_string from an attribute.
+// param       mem_type  - IN: Attribute datatype (in memory)
+// param       strg      - IN: Buffer for read string
+// exception   H5::AttributeIException
 // Programmer   Binh-Minh Ribler - Jul, 2009
 // Modification
-//      Jul 2009
+//        Jul 2009
 //              Separated the variable length case from the original
 //              Attribute::read. -BMR
 //--------------------------------------------------------------------------
@@ -577,7 +556,7 @@ Attribute::p_read_variable_len(const DataType &mem_type, H5std_string &strg) con
 
     // Get string from the C char* and release resource allocated by C API
     strg = strg_C;
-    HDfree(strg_C);
+    free(strg_C);
 }
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -588,7 +567,7 @@ Attribute::p_read_variable_len(const DataType &mem_type, H5std_string &strg) con
 ///\exception   H5::IdComponentException when the attempt to close the HDF5
 ///             object fails
 // Description:
-//              The underlaying reference counting in the C library ensures
+//              The underlying reference counting in the C library ensures
 //              that the current valid id of this object is properly closed.
 //              Then the object's id is reset to the new id.
 // Programmer   Binh-Minh Ribler - 2000
@@ -606,21 +585,6 @@ Attribute::p_setId(const hid_t new_id)
     // reset object's id to the given id
     id = new_id;
 }
-
-//--------------------------------------------------------------------------
-// Function:    Attribute::throwException
-///\brief       Throws H5::AttributeIException.
-///\param       func_name - Name of the function where failure occurs
-///\param       msg       - Message describing the failure
-///\exception   H5::AttributeIException
-// May 2018
-//--------------------------------------------------------------------------
-void
-Attribute::throwException(const H5std_string &func_name, const H5std_string &msg) const
-{
-    throw AttributeIException(inMemFunc(func_name.c_str()), msg);
-}
-
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 //--------------------------------------------------------------------------
@@ -662,4 +626,5 @@ Attribute::~Attribute()
         cerr << "Attribute::~Attribute - " << close_error.getDetailMsg() << endl;
     }
 }
+
 } // namespace H5
