@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -25,11 +24,8 @@
 #include "h5test.h"
 
 using namespace H5;
-
-#ifndef H5_NO_STD
 using std::cerr;
 using std::endl;
-#endif
 
 #define MESSAGE(V, A)                                                                                        \
     {                                                                                                        \
@@ -43,6 +39,7 @@ using std::endl;
     }
 
 int  check_values(hsize_t i, hsize_t j, int apoint, int acheck);
+void check_values(const char *value, const char *msg, int line, const char *file_name);
 int  test_report(int, const H5std_string &);
 void issue_fail_msg(const char *where, int line, const char *file_name, const char *message = "");
 void issue_fail_msg(const char *where, int line, const char *file_name, const char *func_name,
@@ -50,19 +47,21 @@ void issue_fail_msg(const char *where, int line, const char *file_name, const ch
 
 class InvalidActionException : public Exception {
   public:
-    InvalidActionException(const H5std_string func_name, const H5std_string message = DEFAULT_MSG);
+    InvalidActionException(const H5std_string &func_name, const H5std_string &message = DEFAULT_MSG);
     InvalidActionException();
-    virtual ~InvalidActionException() throw();
+    ~InvalidActionException() throw() override;
 };
 
 class TestFailedException : public Exception {
   public:
-    TestFailedException(const H5std_string func_name, const H5std_string message = DEFAULT_MSG);
+    TestFailedException(const H5std_string &func_name, const H5std_string &message = DEFAULT_MSG);
     TestFailedException();
-    virtual ~TestFailedException() throw();
+    ~TestFailedException() throw() override;
 };
 
 // Overloaded/Template functions to verify values and display proper info
+
+// Verifies
 void verify_val(const char *x, const char *value, const char *where, int line, const char *file_name);
 
 template <class Type1, class Type2>
@@ -89,8 +88,8 @@ verify_val(Type1 x, Type2 value, const char *msg, const char *file_name, int lin
 {
     if (x != value) {
         cerr << endl;
-        cerr << "*** UNEXPECTED VALUE: " << file_name << ":line " << line << ":" << msg << " different: " << x
-             << ", should be " << value << endl;
+        cerr << "*** UNEXPECTED VALUE: " << file_name << ":line " << line << ": " << msg
+             << " different: " << x << ", should be " << value << endl;
         IncTestNumErrs();
         throw TestFailedException(file_name, msg);
     }
@@ -126,8 +125,23 @@ CHECK(Type1 x, Type2 value, const char *msg, int line, const char *file_name)
     }
 }
 
+template <class Type1, class Type2>
+void
+verify_val(Type1 x, Type2 value, float epsilon, const char *msg, int line, const char *file_name)
+{
+    if (x == value) {
+        cerr << endl;
+        cerr << "*** UNEXPECTED FLOAT VALUE: " << file_name << ":line " << line << ": " << msg
+             << " different: " << x << ", should be " << value << " (epsilon=" << epsilon << ")" << endl;
+        IncTestNumErrs();
+        throw TestFailedException(file_name, msg);
+    }
+}
+
 /* Prototypes for the test routines */
+#ifdef __cplusplus
 extern "C" {
+#endif
 void test_array();
 void test_attr();
 void test_compound();
@@ -136,6 +150,7 @@ void test_file();
 void test_filters();
 void test_links();
 void test_h5s();
+void test_iterate();
 void test_object();
 void test_reference();
 void test_types();
@@ -150,19 +165,22 @@ void cleanup_dsproplist();
 void cleanup_dsets();
 void cleanup_file();
 void cleanup_filters();
-void cleanup_links();
 void cleanup_h5s();
+void cleanup_iterate();
+void cleanup_links();
 void cleanup_object();
 void cleanup_reference();
 void cleanup_types();
 void cleanup_vlstrings();
+
+#ifdef __cplusplus
 }
+#endif
 
 /* not yet
 void cleanup_select(void);
 void cleanup_time(void);
 void cleanup_vltypes(void);
-void cleanup_iterate(void);
 void cleanup_array(void);
 void cleanup_genprop(void);
 void cleanup_misc(void);
