@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -18,12 +17,7 @@
    EXTERNAL ROUTINES/VARIABLES:
 
  ***************************************************************************/
-
-#ifdef OLD_HEADER_FILENAME
-#include <iostream.h>
-#else
 #include <iostream>
-#endif
 using std::cerr;
 using std::endl;
 
@@ -41,16 +35,22 @@ const H5std_string FILENAME("tvlstr.h5");
 const int     SPACE1_RANK = 1;
 const hsize_t SPACE1_DIM1 = 4;
 
-/****************************************************************
-**
-**  test_vlstr_alloc_custom(): Test VL datatype custom memory
-**      allocation routines.  This routine just uses malloc to
-**      allocate the memory and increments the amount of memory
-**      allocated.  It is passed into setVlenMemManager.
-**
-**  Note: exact copy from the C version.
-**  (Not used now)
-****************************************************************/
+/*-------------------------------------------------------------------------
+ * Function:    test_vlstr_alloc_custom
+ *
+ * Purpose      Test VL datatype custom memory allocation routines.
+ *
+ * Return       None
+ *
+ * Description
+ *      This routine just uses malloc to allocate the memory and
+ *      increments the amount of memory allocated.  It is passed
+ *      into setVlenMemManager.
+ *
+ *  Note: exact copy from the C version.
+ *  (Not used now)
+ *-------------------------------------------------------------------------
+ */
 #if 0 // not used now
 static void *test_vlstr_alloc_custom(size_t size, void *info)
 {
@@ -75,16 +75,22 @@ static void *test_vlstr_alloc_custom(size_t size, void *info)
 }
 #endif
 
-/****************************************************************
-**
-**  test_vlstr_free_custom(): Test VL datatype custom memory
-**      allocation routines.  This routine just uses free to
-**      release the memory and decrements the amount of memory
-**      allocated.  It is passed into setVlenMemManager.
-**
-**  Note: exact copy from the C version.
-**  (Not used now)
-****************************************************************/
+/*-------------------------------------------------------------------------
+ * Function:    test_vlstr_free_custom
+ *
+ * Purpose      Test VL datatype custom memory de-allocation routines.
+ *
+ * Return       None
+ *
+ * Description
+ *      This routine just uses free to release the memory and
+ *      decrements the amount of memory allocated.  It is passed
+ *      into setVlenMemManager.
+ *
+ *  Note: exact copy from the C version.
+ *  (Not used now)
+ *-------------------------------------------------------------------------
+ */
 #if 0 // not used now
 static void test_vlstr_free_custom(void *_mem, void *info)
 {
@@ -110,11 +116,11 @@ static void test_vlstr_free_custom(void *_mem, void *info)
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_dataset
  *
- * Purpose:     Test writing/reading VL strings on datasets.
+ * Purpose      Test writing/reading VL strings on datasets.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -176,7 +182,7 @@ test_vlstring_dataset()
         // Test scalar type dataset with 1 value.
         dset1 = root.createDataSet("test_scalar_small", vlst, ds_space);
 
-        dynstring_ds_write = (char *)HDcalloc(2, sizeof(char));
+        dynstring_ds_write = static_cast<char *>(HDcalloc(2, sizeof(char)));
         HDmemset(dynstring_ds_write, 'A', 1);
 
         // Write data to the dataset, then read it back.
@@ -215,16 +221,17 @@ test_vlstring_dataset()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_array_dataset
  *
- * Purpose:     Test writing/reading VL string array to/from datasets.
+ * Purpose      Test writing/reading VL string array to/from datasets.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              July, 2009
  *
  *-------------------------------------------------------------------------
  */
 const H5std_string DSSTRARR_NAME("StringArray_dset");
+
 static void
 test_vlstring_array_dataset()
 {
@@ -277,7 +284,7 @@ test_vlstring_array_dataset()
 
         // Create and write another dataset.
         DataSet dataset2(file1->createDataSet("Dataset2", vlst, scalar_space));
-        char   *wdata2 = (char *)HDcalloc(65534, sizeof(char));
+        char   *wdata2 = static_cast<char *>(HDcalloc(65534, sizeof(char)));
         HDmemset(wdata2, 'A', 65533);
         dataset2.write(&wdata2, vlst);
 
@@ -305,19 +312,18 @@ test_vlstring_array_dataset()
         issue_fail_msg("test_vlstring_array_dataset()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if (file1)
-        delete file1;
+    delete file1;
 } // end test_vlstring_array_dataset()
 
 /*-------------------------------------------------------------------------
  * Function:    test_vlstrings_special
  *
- * Purpose:     Test VL string code for special string cases, nil and
+ * Purpose      Test VL string code for special string cases, nil and
  *              zero-sized.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -353,7 +359,7 @@ test_vlstrings_special()
         hsize_t ii; // counting variable
         for (ii = 0; ii < SPACE1_DIM1; ii++)
             if (rdata[ii] != NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", (int)ii, rdata[ii]);
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%s\n", static_cast<int>(ii), rdata[ii]);
 
         // Write dataset to disk, then read it back.
         dataset.write(wdata, vlst);
@@ -365,18 +371,19 @@ test_vlstrings_special()
             size_t rlen = HDstrlen(rdata[ii]);
             if (wlen != rlen) {
                 TestErrPrintf("VL data lengths don't match!, strlen(wdata[%d])=%u, strlen(rdata[%d])=%u\n",
-                              (int)ii, (unsigned)wlen, (int)ii, (unsigned)rlen);
+                              static_cast<int>(ii), static_cast<unsigned>(wlen), static_cast<int>(ii),
+                              static_cast<unsigned>(rlen));
                 continue;
-            } // end if
+            }
             if (HDstrcmp(wdata[ii], rdata[ii]) != 0) {
-                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n", (int)ii, wdata[ii],
-                              (int)ii, rdata[ii]);
+                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",
+                              static_cast<int>(ii), wdata[ii], static_cast<int>(ii), rdata[ii]);
                 continue;
-            } // end if
-        }     // end for
+            }
+        }
 
         // Reclaim the read VL data.
-        DataSet::vlenReclaim((void *)rdata, vlst, sid1);
+        DataSet::vlenReclaim(static_cast<void *>(rdata), vlst, sid1);
 
         // Close Dataset.
         dataset.close();
@@ -401,7 +408,7 @@ test_vlstrings_special()
         // Check data read in.
         for (ii = 0; ii < SPACE1_DIM1; ii++)
             if (rdata[ii] != NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", (int)ii, rdata[ii]);
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%s\n", static_cast<int>(ii), rdata[ii]);
 
         // Try to write nil strings to disk.
         dataset.write(wdata2, vlst);
@@ -412,7 +419,7 @@ test_vlstrings_special()
         // Check data read in.
         for (ii = 0; ii < SPACE1_DIM1; ii++)
             if (rdata[ii] != NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", (int)ii, rdata[ii]);
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%s\n", static_cast<int>(ii), rdata[ii]);
 
         // Close objects and file.
         dataset.close();
@@ -432,16 +439,17 @@ test_vlstrings_special()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_type
  *
- * Purpose:     Test if VL string is treated as string.
+ * Purpose      Test if VL string is treated as string.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
 const H5std_string VLSTR_TYPE("vl_string_type");
+
 static void
 test_vlstring_type()
 {
@@ -459,22 +467,26 @@ test_vlstring_type()
         // Change padding and verify it.
         vlst.setStrpad(H5T_STR_NULLPAD);
         H5T_str_t pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Convert to variable-length string.
         vlst.setSize(H5T_VARIABLE);
 
         // Check if datatype is VL string.
         H5T_class_t type_class = vlst.getClass();
-        verify_val(type_class, H5T_STRING, "DataType::getClass", __LINE__, __FILE__);
+        verify_val(static_cast<long>(type_class), static_cast<long>(H5T_STRING), "DataType::getClass",
+                   __LINE__, __FILE__);
         bool is_variable_str = vlst.isVariableStr();
         verify_val(is_variable_str, true, "DataType::isVariableStr", __LINE__, __FILE__);
 
         // Check default character set and padding.
         H5T_cset_t cset = vlst.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
+        verify_val(static_cast<long>(cset), static_cast<long>(H5T_CSET_ASCII), "StrType::getCset", __LINE__,
+                   __FILE__);
         pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Commit variable-length string datatype to storage.
         vlst.commit(*file1, VLSTR_TYPE);
@@ -497,30 +509,18 @@ test_vlstring_type()
         // Open file.
         file1 = new H5File(FILENAME, H5F_ACC_RDWR);
 
-        { // deprecated
-            // Open the variable-length string datatype just created.
-            vlst = file1->openStrType(VLSTR_TYPE);
-
-            // Verify character set and padding.
-            cset = vlst.getCset();
-            verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
-            pad = vlst.getStrpad();
-            verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
-
-            // Close type to test new function.
-            vlst.close();
-        } // deprecated
-
-        // Open the variable-length string datatype just created.
+        // Open the variable-length string datatype just created
         StrType vlst2(*file1, VLSTR_TYPE);
 
-        // Verify character set and padding.
+        // Verify character set and padding
         cset = vlst2.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
+        verify_val(static_cast<long>(cset), static_cast<long>(H5T_CSET_ASCII), "StrType::getCset", __LINE__,
+                   __FILE__);
         pad = vlst2.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
-        // Close datatype and file.
+        // Close datatype and file
         vlst2.close();
         file1->close();
 
@@ -532,18 +532,17 @@ test_vlstring_type()
         issue_fail_msg("test_vlstring_type()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if (file1)
-        delete file1;
+    delete file1;
 } // end test_vlstring_type()
 
 /*-------------------------------------------------------------------------
  * Function:    test_compact_vlstring
  *
- * Purpose:     Test storing VL strings in compact datasets.
+ * Purpose      Test storing VL strings in compact datasets.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -585,18 +584,19 @@ test_compact_vlstring()
         for (i = 0; i < SPACE1_DIM1; i++) {
             if (HDstrlen(wdata[i]) != strlen(rdata[i])) {
                 TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",
-                              (int)i, (int)strlen(wdata[i]), (int)i, (int)strlen(rdata[i]));
+                              static_cast<int>(i), static_cast<int>(HDstrlen(wdata[i])), static_cast<int>(i),
+                              static_cast<int>(HDstrlen(rdata[i])));
                 continue;
             } // end if
             if (HDstrcmp(wdata[i], rdata[i]) != 0) {
-                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n", (int)i, wdata[i],
-                              (int)i, rdata[i]);
+                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",
+                              static_cast<int>(i), wdata[i], static_cast<int>(i), rdata[i]);
                 continue;
             } // end if
         }     // end for
 
         // Reclaim the read VL data
-        DataSet::vlenReclaim((void *)rdata, vlst, sid1);
+        DataSet::vlenReclaim(static_cast<void *>(rdata), vlst, sid1);
 
         // Close objects and file
         dataset.close();
@@ -617,19 +617,16 @@ test_compact_vlstring()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_attribute
  *
- * Purpose:     Test writing/reading VL strings on attributes.
+ * Purpose      Test writing/reading VL strings on attributes.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
-// String for writing to attribute
-static char *string_att_write = NULL;
-
-// Info for a string attribute
+static char       *string_att_write = NULL;
 const H5std_string ATTRSTR_NAME("String_attr");
 const H5std_string ATTRSTR_DATA("String Attribute");
 
@@ -680,7 +677,7 @@ test_vlstring_attribute()
         // Test creating a "large" sized string attribute
         gr_attr = root.createAttribute("test_scalar_large", vlst, att_space);
 
-        string_att_write = (char *)HDcalloc(8192, sizeof(char));
+        string_att_write = static_cast<char *>(HDcalloc(8192, sizeof(char)));
         HDmemset(string_att_write, 'A', 8191);
 
         // Write data to the attribute, then read it back.
@@ -711,11 +708,11 @@ test_vlstring_attribute()
 /*-------------------------------------------------------------------------
  * Function:    test_read_vl_string_attribute
  *
- * Purpose:     Test reading VL strings from attributes.
+ * Purpose      Test reading VL strings from attributes.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -773,11 +770,11 @@ static void test_read_vl_string_attribute()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_array_attribute
  *
- * Purpose:     Test writing/reading VL string array to/from attributes.
+ * Purpose      Test writing/reading VL string array to/from attributes.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              July, 2009
  *
  *-------------------------------------------------------------------------
@@ -869,7 +866,7 @@ read_scalar_dset(H5File &file, DataType &type, DataSpace &space, char *name, cha
         dset.read(&data_read, type, space, space);
         dset.close();
 
-        if (HDstrcmp(data, data_read))
+        if (HDstrcmp(data, data_read) != 0)
             TestErrPrintf("Expected %s for dataset %s but read %s\n", data, name, data_read);
 
         HDfree(data_read);
@@ -885,18 +882,19 @@ read_scalar_dset(H5File &file, DataType &type, DataSpace &space, char *name, cha
 /*-------------------------------------------------------------------------
  * Function:    test_vl_rewrite
  *
- * Purpose:     Test I/O on VL strings when many objects in the file
+ * Purpose      Test I/O on VL strings when many objects in the file
  *              have been linked/unlinked.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
 const H5std_string FILENAME2("tvlstr2.h5");
 const int          REWRITE_NDATASETS = 32;
+
 static void
 test_vl_rewrite()
 {
@@ -918,32 +916,32 @@ test_vl_rewrite()
         int  i;
         char name[256]; // Buffer for names & data
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             write_scalar_dset(file1, type, space, name, name);
         }
 
         // Effectively copy data from file 1 to 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file1, type, space, name, name);
             write_scalar_dset(file2, type, space, name, name);
         }
 
         // Read back from file 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file2, type, space, name, name);
         }
 
         // Remove from file 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             file2.unlink(name);
         }
 
         // Effectively copy from file 1 to file 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file1, type, space, name, name);
             write_scalar_dset(file2, type, space, name, name);
         }
@@ -966,11 +964,11 @@ test_vl_rewrite()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstrings
  *
- * Purpose:     VL string testing main routine.
+ * Purpose      VL string testing main routine.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -1003,13 +1001,9 @@ test_vlstrings()
 /*-------------------------------------------------------------------------
  * Function:    cleanup_vlstrings
  *
- * Purpose:     Cleanup temporary test files
- *
- * Return:      none
- *
- * Programmer:  Quincey Koziol
- *              September 10, 1999
+ * Purpose      Cleanup temporary test files
  *
+ * Return       none
  *-------------------------------------------------------------------------
  */
 extern "C" void
