@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -13,8 +12,6 @@
 
 #include "H5IMprivate.h"
 #include "H5LTprivate.h"
-#include <string.h>
-#include <stdlib.h>
 
 /*-------------------------------------------------------------------------
  * Function: H5IMmake_image_8bit
@@ -162,7 +159,8 @@ H5IMmake_image_24bit(hid_t loc_id, const char *dset_name, hsize_t width, hsize_t
  *-------------------------------------------------------------------------
  */
 static herr_t
-find_palette(hid_t loc_id, const char *name, const H5A_info_t *ainfo, void *op_data)
+find_palette(H5_ATTR_UNUSED hid_t loc_id, const char *name, H5_ATTR_UNUSED const H5A_info_t *ainfo,
+             H5_ATTR_UNUSED void *op_data)
 {
     int ret = H5_ITER_CONT;
 
@@ -171,9 +169,9 @@ find_palette(hid_t loc_id, const char *name, const H5A_info_t *ainfo, void *op_d
         return -1;
 
     /* Shut compiler up */
-    loc_id  = loc_id;
-    ainfo   = ainfo;
-    op_data = op_data;
+    (void)loc_id;
+    (void)ainfo;
+    (void)op_data;
 
     /* Define a positive value for return value if the attribute was found. This will
      * cause the iterator to immediately return that positive value,
@@ -229,7 +227,6 @@ H5IM_find_palette(hid_t loc_id)
  *
  *-------------------------------------------------------------------------
  */
-
 herr_t
 H5IMget_image_info(hid_t loc_id, const char *dset_name, hsize_t *width, hsize_t *height, hsize_t *planes,
                    char *interlace, hssize_t *npals)
@@ -242,7 +239,7 @@ H5IMget_image_info(hid_t loc_id, const char *dset_name, hsize_t *width, hsize_t
     hid_t       atid = -1;
     H5T_class_t aclass;
     int         has_pal;
-    int         has_attr;
+    hid_t       has_attr;
 
     /* check the arguments */
     if (dset_name == NULL)
@@ -258,11 +255,11 @@ H5IMget_image_info(hid_t loc_id, const char *dset_name, hsize_t *width, hsize_t
         return -1;
 
     /* Try to find the attribute "INTERLACE_MODE" on the >>image<< dataset */
-    if ((has_attr = H5LT_find_attribute(did, "INTERLACE_MODE")) < 0)
+    if ((has_attr = H5Aexists(did, "INTERLACE_MODE")) < 0)
         goto out;
 
     /* It exists, get it */
-    if (has_attr == 1) {
+    if (has_attr > 0) {
 
         if ((aid = H5Aopen(did, "INTERLACE_MODE", H5P_DEFAULT)) < 0)
             goto out;
@@ -284,15 +281,16 @@ H5IMget_image_info(hid_t loc_id, const char *dset_name, hsize_t *width, hsize_t
     if ((sid = H5Dget_space(did)) < 0)
         goto out;
 
+    if (H5Sget_simple_extent_dims(sid, NULL, NULL) > IMAGE24_RANK)
+        goto out;
     /* Get dimensions */
     if (H5Sget_simple_extent_dims(sid, dims, NULL) < 0)
         goto out;
 
     /* Initialize the image dimensions */
 
-    if (has_attr == 1)
-    /* This is a 24 bit image */
-    {
+    if (has_attr > 0) {
+        /* This is a 24 bit image */
 
         if (HDstrncmp(interlace, "INTERLACE_PIXEL", 15) == 0) {
             /* Number of color planes is defined as the third dimension */
@@ -309,9 +307,8 @@ H5IMget_image_info(hid_t loc_id, const char *dset_name, hsize_t *width, hsize_t
         else
             return -1;
     }
-    else
-    /* This is a 8 bit image */
-    {
+    else {
+        /* This is a 8 bit image */
         *height = dims[0];
         *width  = dims[1];
         *planes = 1;
@@ -513,7 +510,7 @@ H5IMlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
     hobj_ref_t *refbuf; /* buffer to read references */
     hssize_t    n_refs;
     hsize_t     dim_ref;
-    int         ok_pal;
+    htri_t      ok_pal;
 
     /* check the arguments */
     if (image_name == NULL)
@@ -532,7 +529,8 @@ H5IMlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
         return -1;
 
     /* Try to find the attribute "PALETTE" on the >>image<< dataset */
-    ok_pal = H5LT_find_attribute(did, "PALETTE");
+    if ((ok_pal = H5Aexists(did, "PALETTE")) < 0)
+        goto out;
 
     /*-------------------------------------------------------------------------
      * It does not exist. We create the attribute and one reference
@@ -571,7 +569,7 @@ H5IMlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
      * The attribute already exists, open it
      *-------------------------------------------------------------------------
      */
-    else if (ok_pal == 1) {
+    else if (ok_pal > 0) {
         if ((aid = H5Aopen(did, "PALETTE", H5P_DEFAULT)) < 0)
             goto out;
 
@@ -632,7 +630,7 @@ H5IMlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
 
         HDfree(refbuf);
 
-    } /* ok_pal ==  1 */
+    } /* ok_pal > 0 */
 
     /* Close the image dataset. */
     if (H5Dclose(did) < 0)
@@ -674,7 +672,8 @@ H5IMunlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
     hid_t       atid;
     hid_t       aid;
     H5T_class_t aclass;
-    int         ok_pal, has_pal;
+    htri_t      ok_pal;
+    int         has_pal;
 
     /* check the arguments */
     if (image_name == NULL)
@@ -700,14 +699,14 @@ H5IMunlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
         return -1;
 
     /* Try to find the attribute "PALETTE" on the >>image<< dataset */
-    ok_pal = H5LT_find_attribute(did, "PALETTE");
+    if ((ok_pal = H5Aexists(did, "PALETTE")) < 0)
+        goto out;
 
     /* It does not exist. Nothing to do */
     if (ok_pal == 0)
-        return -1;
-
-    /* The attribute exists, open it */
-    else if (ok_pal == 1) {
+        goto out;
+    else if (ok_pal > 0) {
+        /* The attribute exists, open it */
         if ((aid = H5Aopen(did, "PALETTE", H5P_DEFAULT)) < 0)
             goto out;
 
@@ -731,8 +730,7 @@ H5IMunlink_palette(hid_t loc_id, const char *image_name, const char *pal_name)
         /* Close the attribute. */
         if (H5Aclose(aid) < 0)
             goto out;
-
-    } /* ok_pal */
+    }
 
     /* Close the image dataset. */
     if (H5Dclose(did) < 0)
@@ -899,7 +897,7 @@ H5IMget_palette_info(hid_t loc_id, const char *image_name, int pal_number, hsize
             goto out;
 
         /* Get the actual palette */
-        if ((pal_id = H5Rdereference(did, H5R_OBJECT, &refbuf[pal_number])) < 0)
+        if ((pal_id = H5Rdereference2(did, H5P_DEFAULT, H5R_OBJECT, &refbuf[pal_number])) < 0)
             goto out;
 
         if ((pal_space_id = H5Dget_space(pal_id)) < 0)
@@ -1008,7 +1006,7 @@ H5IMget_palette(hid_t loc_id, const char *image_name, int pal_number, unsigned c
             goto out;
 
         /* Get the palette id */
-        if ((pal_id = H5Rdereference(did, H5R_OBJECT, &refbuf[pal_number])) < 0)
+        if ((pal_id = H5Rdereference2(did, H5P_DEFAULT, H5R_OBJECT, &refbuf[pal_number])) < 0)
             goto out;
 
         /* Read the palette dataset */
@@ -1064,7 +1062,7 @@ herr_t
 H5IMis_image(hid_t loc_id, const char *dset_name)
 {
     hid_t   did;
-    int     has_class;
+    htri_t  has_class;
     hid_t   atid;
     hid_t   aid = -1;
     char   *attr_data;    /* Name of attribute */
@@ -1083,13 +1081,14 @@ H5IMis_image(hid_t loc_id, const char *dset_name)
         return -1;
 
     /* Try to find the attribute "CLASS" on the dataset */
-    has_class = H5LT_find_attribute(did, "CLASS");
+    if ((has_class = H5Aexists(did, "CLASS")) < 0)
+        goto out;
 
     if (has_class == 0) {
         H5Dclose(did);
         return 0;
     }
-    else if (has_class == 1) {
+    else {
 
         if ((aid = H5Aopen(did, "CLASS", H5P_DEFAULT)) < 0)
             goto out;
@@ -1164,7 +1163,7 @@ herr_t
 H5IMis_palette(hid_t loc_id, const char *dset_name)
 {
     hid_t   did;
-    int     has_class;
+    htri_t  has_class;
     hid_t   atid;
     hid_t   aid = -1;
     char   *attr_data;    /* Name of attribute */
@@ -1183,13 +1182,14 @@ H5IMis_palette(hid_t loc_id, const char *dset_name)
         return -1;
 
     /* Try to find the attribute "CLASS" on the dataset */
-    has_class = H5LT_find_attribute(did, "CLASS");
+    if ((has_class = H5Aexists(did, "CLASS")) < 0)
+        goto out;
 
     if (has_class == 0) {
         H5Dclose(did);
         return 0;
     }
-    else if (has_class == 1) {
+    else {
 
         if ((aid = H5Aopen(did, "CLASS", H5P_DEFAULT)) < 0)
             goto out;
