@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -28,9 +27,9 @@
  *    This tool uses H5LD_memb_t data structure declared in H5LDprivate.h
  */
 
-const char *         progname         = "h5watch"; /* tool name */
-static char *        g_list_of_fields = NULL;      /* command line input for "list_of_fields" */
-static char *        g_dup_fields     = NULL;      /* copy of "list_of_fields" */
+const char          *progname         = "h5watch"; /* tool name */
+static char         *g_list_of_fields = NULL;      /* command line input for "list_of_fields" */
+static char         *g_dup_fields     = NULL;      /* copy of "list_of_fields" */
 static H5LD_memb_t **g_listv          = NULL;      /* vector info for "list_of_fields" */
 
 static hbool_t  g_monitor_size_only = FALSE; /* monitor changes in dataset dimension sizes */
@@ -51,34 +50,34 @@ static herr_t process_cmpd_fields(hid_t fid, char *dsetname);
 static herr_t check_dataset(hid_t fid, char *dsetname);
 static void   leave(int ret);
 static void   usage(const char *prog);
-static void   parse_command_line(int argc, const char *argv[]);
+static void   parse_command_line(int argc, const char *const *argv);
 
 /*
  * Command-line options: The user can only specify long-named parameters.
  * The long-named ones can be partially spelled. When
  * adding more, make sure that they don't clash with each other.
  */
-static const char *        s_opts   = "?";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'},         {"hel", no_arg, 'h'},
-                                       {"dim", no_arg, 'd'},          {"di", no_arg, 'd'},
-                                       {"label", no_arg, 'l'},        {"labe", no_arg, 'l'},
-                                       {"lab", no_arg, 'l'},          {"la", no_arg, 'l'},
-                                       {"simple", no_arg, 'S'},       {"simpl", no_arg, 'S'},
-                                       {"simp", no_arg, 'S'},         {"sim", no_arg, 'S'},
-                                       {"si", no_arg, 'S'},           {"hexdump", no_arg, 'x'},
-                                       {"hexdum", no_arg, 'x'},       {"hexdu", no_arg, 'x'},
-                                       {"hexd", no_arg, 'x'},         {"hex", no_arg, 'x'},
-                                       {"width", require_arg, 'w'},   {"widt", require_arg, 'w'},
-                                       {"wid", require_arg, 'w'},     {"wi", require_arg, 'w'},
-                                       {"polling", require_arg, 'p'}, {"pollin", require_arg, 'p'},
-                                       {"polli", require_arg, 'p'},   {"poll", require_arg, 'p'},
-                                       {"pol", require_arg, 'p'},     {"po", require_arg, 'p'},
-                                       {"fields", require_arg, 'f'},  {"field", require_arg, 'f'},
-                                       {"fiel", require_arg, 'f'},    {"fie", require_arg, 'f'},
-                                       {"fi", require_arg, 'f'},      {"version", no_arg, 'V'},
-                                       {"versio", no_arg, 'V'},       {"versi", no_arg, 'V'},
-                                       {"vers", no_arg, 'V'},         {"ver", no_arg, 'V'},
-                                       {"ve", no_arg, 'V'},           {NULL, 0, '\0'}};
+static const char            *s_opts   = "?";
+static struct h5_long_options l_opts[] = {{"help", no_arg, 'h'},         {"hel", no_arg, 'h'},
+                                          {"dim", no_arg, 'd'},          {"di", no_arg, 'd'},
+                                          {"label", no_arg, 'l'},        {"labe", no_arg, 'l'},
+                                          {"lab", no_arg, 'l'},          {"la", no_arg, 'l'},
+                                          {"simple", no_arg, 'S'},       {"simpl", no_arg, 'S'},
+                                          {"simp", no_arg, 'S'},         {"sim", no_arg, 'S'},
+                                          {"si", no_arg, 'S'},           {"hexdump", no_arg, 'x'},
+                                          {"hexdum", no_arg, 'x'},       {"hexdu", no_arg, 'x'},
+                                          {"hexd", no_arg, 'x'},         {"hex", no_arg, 'x'},
+                                          {"width", require_arg, 'w'},   {"widt", require_arg, 'w'},
+                                          {"wid", require_arg, 'w'},     {"wi", require_arg, 'w'},
+                                          {"polling", require_arg, 'p'}, {"pollin", require_arg, 'p'},
+                                          {"polli", require_arg, 'p'},   {"poll", require_arg, 'p'},
+                                          {"pol", require_arg, 'p'},     {"po", require_arg, 'p'},
+                                          {"fields", require_arg, 'f'},  {"field", require_arg, 'f'},
+                                          {"fiel", require_arg, 'f'},    {"fie", require_arg, 'f'},
+                                          {"fi", require_arg, 'f'},      {"version", no_arg, 'V'},
+                                          {"versio", no_arg, 'V'},       {"versi", no_arg, 'V'},
+                                          {"vers", no_arg, 'V'},         {"ver", no_arg, 'V'},
+                                          {"ve", no_arg, 'V'},           {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
  * Function: doprint()
@@ -174,9 +173,9 @@ doprint(hid_t did, const hsize_t *start, const hsize_t *block, int rank)
     } /* end else */
 
     /* Floating point types should display full precision */
-    sprintf(fmt_float, "%%1.%dg", FLT_DIG);
+    snprintf(fmt_float, sizeof(fmt_float), "%%1.%dg", FLT_DIG);
     info.fmt_float = fmt_float;
-    sprintf(fmt_double, "%%1.%dg", DBL_DIG);
+    snprintf(fmt_double, sizeof(fmt_double), "%%1.%dg", DBL_DIG);
     info.fmt_double = fmt_double;
 
     info.dset_format     = "DSET-%s ";
@@ -498,7 +497,7 @@ check_dataset(hid_t fid, char *dsetname)
     hsize_t      cur_dims[H5S_MAX_RANK]; /* size of dataspace dimensions */
     hsize_t      max_dims[H5S_MAX_RANK]; /* maximum size of dataspace dimensions */
     hbool_t      unlim_max_dims = FALSE; /* whether dataset has unlimited or max. dimension setting */
-    void *       edata;
+    void        *edata;
     H5E_auto2_t  func;
     H5D_layout_t layout;
     herr_t       ret_value = SUCCEED; /* Return value */
@@ -665,7 +664,7 @@ usage(const char *prog)
  *-------------------------------------------------------------------------
  */
 static void
-parse_command_line(int argc, const char *argv[])
+parse_command_line(int argc, const char *const *argv)
 {
     int opt; /* Command line option */
     int tmp;
@@ -677,7 +676,7 @@ parse_command_line(int argc, const char *argv[])
     }
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case '?':
             case 'h': /* --help */
@@ -691,7 +690,7 @@ parse_command_line(int argc, const char *argv[])
                 break;
 
             case 'w': /* --width=N */
-                g_display_width = (int)HDstrtol(opt_arg, NULL, 0);
+                g_display_width = (int)HDstrtol(H5_optarg, NULL, 0);
                 if (g_display_width < 0) {
                     usage(h5tools_getprogname());
                     leave(EXIT_FAILURE);
@@ -711,8 +710,8 @@ parse_command_line(int argc, const char *argv[])
                 break;
 
             case 'p': /* --polling=N */
-                /* g_polling_interval = HDstrtod(opt_arg, NULL); */
-                if ((tmp = (int)HDstrtol(opt_arg, NULL, 10)) <= 0) {
+                /* g_polling_interval = HDstrtod(H5_optarg, NULL); */
+                if ((tmp = (int)HDstrtol(H5_optarg, NULL, 10)) <= 0) {
                     usage(h5tools_getprogname());
                     leave(EXIT_FAILURE);
                 }
@@ -721,7 +720,7 @@ parse_command_line(int argc, const char *argv[])
 
             case 'f': /* --fields=<list_of_fields> */
                 if (g_list_of_fields == NULL) {
-                    if ((g_list_of_fields = HDstrdup(opt_arg)) == NULL) {
+                    if ((g_list_of_fields = HDstrdup(H5_optarg)) == NULL) {
                         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
                         leave(EXIT_FAILURE);
                     }
@@ -729,7 +728,7 @@ parse_command_line(int argc, const char *argv[])
                 else {
                     char *str;
 
-                    if ((str = HDstrdup(opt_arg)) == NULL) {
+                    if ((str = HDstrdup(H5_optarg)) == NULL) {
                         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
                         leave(EXIT_FAILURE);
                     }
@@ -751,7 +750,7 @@ parse_command_line(int argc, const char *argv[])
     }
 
     /* check for object to be processed */
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing dataset name\n");
         usage(h5tools_getprogname());
         leave(EXIT_FAILURE);
@@ -790,7 +789,7 @@ catch_signal(int H5_ATTR_UNUSED signo)
  *-------------------------------------------------------------------------
  */
 int
-main(int argc, const char *argv[])
+main(int argc, char *argv[])
 {
     char  drivername[50]; /* VFD name */
     char *fname = NULL;   /* File name */
@@ -819,9 +818,9 @@ main(int argc, const char *argv[])
     }
 
     /* parse command line options */
-    parse_command_line(argc, argv);
+    parse_command_line(argc, (const char *const *)argv);
 
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing dataset name\n");
         usage(h5tools_getprogname());
         leave(EXIT_FAILURE);
@@ -845,7 +844,7 @@ main(int argc, const char *argv[])
      * then there must have been something wrong with the file (perhaps it
      * doesn't exist).
      */
-    if ((fname = HDstrdup(argv[opt_ind])) == NULL) {
+    if ((fname = HDstrdup(argv[H5_optind])) == NULL) {
         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
@@ -921,7 +920,7 @@ main(int argc, const char *argv[])
         }
     }
 
-    /* If everything is fine, start monitoring the datset */
+    /* If everything is fine, start monitoring the dataset */
     if (h5tools_getstatus() != EXIT_FAILURE)
         if (monitor_dataset(fid, dname) < 0)
             h5tools_setstatus(EXIT_FAILURE);
