@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -68,10 +67,10 @@
  */
 typedef struct H5A_bt2_od_wrt_t {
     /* downward */
-    H5F_t * f;               /* Pointer to file that fractal heap is in */
+    H5F_t  *f;               /* Pointer to file that fractal heap is in */
     H5HF_t *fheap;           /* Fractal heap handle to operate on */
     H5HF_t *shared_fheap;    /* Fractal heap handle for shared messages */
-    H5A_t * attr;            /* Attribute to write */
+    H5A_t  *attr;            /* Attribute to write */
     haddr_t corder_bt2_addr; /* v2 B-tree address of creation order index */
 } H5A_bt2_od_wrt_t;
 
@@ -81,7 +80,7 @@ typedef struct H5A_bt2_od_wrt_t {
  */
 typedef struct {
     /* downward (internal) */
-    H5F_t * f;            /* Pointer to file that fractal heap is in */
+    H5F_t  *f;            /* Pointer to file that fractal heap is in */
     H5HF_t *fheap;        /* Fractal heap handle               */
     H5HF_t *shared_fheap; /* Fractal heap handle for shared messages */
     hsize_t count;        /* # of attributes examined          */
@@ -90,7 +89,7 @@ typedef struct {
     hid_t                     loc_id;  /* Object ID for application callback */
     hsize_t                   skip;    /* Number of attributes to skip      */
     const H5A_attr_iter_op_t *attr_op; /* Callback for each attribute       */
-    void *                    op_data; /* Callback data for each attribute  */
+    void                     *op_data; /* Callback data for each attribute  */
 
     /* upward */
     int op_ret; /* Return value from callback        */
@@ -103,7 +102,7 @@ typedef struct {
  */
 typedef struct {
     /* downward (internal) */
-    H5F_t *                         f;      /* Pointer to file that fractal heap is in */
+    H5F_t                          *f;      /* Pointer to file that fractal heap is in */
     const H5A_dense_bt2_name_rec_t *record; /* v2 B-tree record for attribute */
 
     /* upward */
@@ -126,9 +125,9 @@ typedef struct H5A_bt2_ud_rm_t {
  */
 typedef struct H5A_bt2_ud_rmbi_t {
     /* downward */
-    H5F_t *    f;              /* Pointer to file that fractal heap is in */
-    H5HF_t *   fheap;          /* Fractal heap handle               */
-    H5HF_t *   shared_fheap;   /* Fractal heap handle for shared messages */
+    H5F_t     *f;              /* Pointer to file that fractal heap is in */
+    H5HF_t    *fheap;          /* Fractal heap handle               */
+    H5HF_t    *shared_fheap;   /* Fractal heap handle for shared messages */
     H5_index_t idx_type;       /* Index type for operation */
     haddr_t    other_bt2_addr; /* v2 B-tree address of "other" index */
 } H5A_bt2_ud_rmbi_t;
@@ -170,9 +169,9 @@ H5A__dense_create(H5F_t *f, H5O_ainfo_t *ainfo)
 {
     H5HF_create_t fheap_cparam;         /* Fractal heap creation parameters */
     H5B2_create_t bt2_cparam;           /* v2 B-tree creation parameters */
-    H5HF_t *      fheap      = NULL;    /* Fractal heap handle */
-    H5B2_t *      bt2_name   = NULL;    /* v2 B-tree handle for names */
-    H5B2_t *      bt2_corder = NULL;    /* v2 B-tree handle for creation order */
+    H5HF_t       *fheap      = NULL;    /* Fractal heap handle */
+    H5B2_t       *bt2_name   = NULL;    /* v2 B-tree handle for names */
+    H5B2_t       *bt2_corder = NULL;    /* v2 B-tree handle for creation order */
     herr_t        ret_value  = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
@@ -277,7 +276,7 @@ H5A__dense_fnd_cb(const H5A_t *attr, hbool_t *took_ownership, void *_user_attr)
     const H5A_t **user_attr = (const H5A_t **)_user_attr; /* User data from v2 B-tree attribute lookup */
     herr_t        ret_value = SUCCEED;                    /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(attr);
@@ -334,12 +333,12 @@ H5A_t *
 H5A__dense_open(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name)
 {
     H5A_bt2_ud_common_t udata;               /* User data for v2 B-tree modify */
-    H5HF_t *            fheap        = NULL; /* Fractal heap handle */
-    H5HF_t *            shared_fheap = NULL; /* Fractal heap handle for shared header messages */
-    H5B2_t *            bt2_name     = NULL; /* v2 B-tree handle for name index */
+    H5HF_t             *fheap        = NULL; /* Fractal heap handle */
+    H5HF_t             *shared_fheap = NULL; /* Fractal heap handle for shared header messages */
+    H5B2_t             *bt2_name     = NULL; /* v2 B-tree handle for name index */
     htri_t              attr_sharable;       /* Flag indicating attributes are shareable */
-    htri_t              attr_exists;         /* Attribute exists in v2 B-tree */
-    H5A_t *             ret_value = NULL;    /* Return value */
+    hbool_t             attr_exists;         /* Attribute exists in v2 B-tree */
+    H5A_t              *ret_value = NULL;    /* Return value */
 
     FUNC_ENTER_PACKAGE
 
@@ -388,9 +387,10 @@ H5A__dense_open(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name)
     udata.found_op_data = &ret_value;
 
     /* Find & copy the attribute in the 'name' index */
-    if ((attr_exists = H5B2_find(bt2_name, &udata, NULL, NULL)) < 0)
+    attr_exists = FALSE;
+    if (H5B2_find(bt2_name, &udata, &attr_exists, NULL, NULL) < 0)
         HGOTO_ERROR(H5E_ATTR, H5E_NOTFOUND, NULL, "can't search for attribute in name index")
-    else if (attr_exists == FALSE)
+    if (attr_exists == FALSE)
         HGOTO_ERROR(H5E_ATTR, H5E_NOTFOUND, NULL, "can't locate attribute in name index")
 
 done:
@@ -421,11 +421,11 @@ herr_t
 H5A__dense_insert(H5F_t *f, const H5O_ainfo_t *ainfo, H5A_t *attr)
 {
     H5A_bt2_ud_ins_t udata;                       /* User data for v2 B-tree insertion */
-    H5HF_t *         fheap        = NULL;         /* Fractal heap handle for attributes */
-    H5HF_t *         shared_fheap = NULL;         /* Fractal heap handle for shared header messages */
-    H5B2_t *         bt2_name     = NULL;         /* v2 B-tree handle for name index */
-    H5B2_t *         bt2_corder   = NULL;         /* v2 B-tree handle for creation order index */
-    H5WB_t *         wb           = NULL;         /* Wrapped buffer for attribute data */
+    H5HF_t          *fheap        = NULL;         /* Fractal heap handle for attributes */
+    H5HF_t          *shared_fheap = NULL;         /* Fractal heap handle for shared header messages */
+    H5B2_t          *bt2_name     = NULL;         /* v2 B-tree handle for name index */
+    H5B2_t          *bt2_corder   = NULL;         /* v2 B-tree handle for creation order index */
+    H5WB_t          *wb           = NULL;         /* Wrapped buffer for attribute data */
     uint8_t          attr_buf[H5A_ATTR_BUF_SIZE]; /* Buffer for serializing message */
     unsigned         mesg_flags = 0;              /* Flags for storing message */
     htri_t           attr_sharable;               /* Flag indicating attributes are shareable */
@@ -487,7 +487,7 @@ H5A__dense_insert(H5F_t *f, const H5O_ainfo_t *ainfo, H5A_t *attr)
         udata.id = attr->sh_loc.u.heap_id;
     } /* end if */
     else {
-        void * attr_ptr;  /* Pointer to serialized message */
+        void  *attr_ptr;  /* Pointer to serialized message */
         size_t attr_size; /* Size of serialized attribute in the heap */
 
         /* Find out the size of buffer needed for serialized message */
@@ -579,7 +579,7 @@ H5A__dense_write_bt2_cb2(void *_record, void *_op_data, hbool_t *changed)
     H5A_dense_bt2_corder_rec_t *record = (H5A_dense_bt2_corder_rec_t *)_record; /* Record from B-tree */
     H5O_fheap_id_t *new_heap_id        = (H5O_fheap_id_t *)_op_data; /* "op data" from v2 B-tree modify */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
     HDassert(record);
@@ -610,13 +610,13 @@ static herr_t
 H5A__dense_write_bt2_cb(void *_record, void *_op_data, hbool_t *changed)
 {
     H5A_dense_bt2_name_rec_t *record     = (H5A_dense_bt2_name_rec_t *)_record; /* Record from B-tree */
-    H5A_bt2_od_wrt_t *        op_data    = (H5A_bt2_od_wrt_t *)_op_data; /* "op data" from v2 B-tree modify */
-    H5B2_t *                  bt2_corder = NULL;           /* v2 B-tree handle for creation order index */
-    H5WB_t *                  wb         = NULL;           /* Wrapped buffer for attribute data */
+    H5A_bt2_od_wrt_t         *op_data    = (H5A_bt2_od_wrt_t *)_op_data; /* "op data" from v2 B-tree modify */
+    H5B2_t                   *bt2_corder = NULL;           /* v2 B-tree handle for creation order index */
+    H5WB_t                   *wb         = NULL;           /* Wrapped buffer for attribute data */
     uint8_t                   attr_buf[H5A_ATTR_BUF_SIZE]; /* Buffer for serializing attribute */
     herr_t                    ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(record);
@@ -661,7 +661,7 @@ H5A__dense_write_bt2_cb(void *_record, void *_op_data, hbool_t *changed)
         *changed = TRUE;
     } /* end if */
     else {
-        void * attr_ptr;  /* Pointer to serialized message */
+        void  *attr_ptr;  /* Pointer to serialized message */
         size_t attr_size; /* Size of serialized attribute in the heap */
 
         /* Find out the size of buffer needed for serialized attribute */
@@ -723,9 +723,9 @@ H5A__dense_write(H5F_t *f, const H5O_ainfo_t *ainfo, H5A_t *attr)
 {
     H5A_bt2_ud_common_t udata;               /* User data for v2 B-tree modify */
     H5A_bt2_od_wrt_t    op_data;             /* "Op data" for v2 B-tree modify */
-    H5HF_t *            fheap        = NULL; /* Fractal heap handle */
-    H5HF_t *            shared_fheap = NULL; /* Fractal heap handle for shared header messages */
-    H5B2_t *            bt2_name     = NULL; /* v2 B-tree handle for name index */
+    H5HF_t             *fheap        = NULL; /* Fractal heap handle */
+    H5HF_t             *shared_fheap = NULL; /* Fractal heap handle for shared header messages */
+    H5B2_t             *bt2_name     = NULL; /* v2 B-tree handle for name index */
     htri_t              attr_sharable;       /* Flag indicating attributes are shareable */
     herr_t              ret_value = SUCCEED; /* Return value */
 
@@ -819,7 +819,7 @@ H5A__dense_copy_fh_cb(const void *obj, size_t obj_len, void *_udata)
     H5A_fh_ud_cp_t *udata     = (H5A_fh_ud_cp_t *)_udata; /* User data for fractal heap 'op' callback */
     herr_t          ret_value = SUCCEED;                  /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Decode attribute information & keep a copy */
     /* (we make a copy instead of calling the user/library callback directly in
@@ -859,14 +859,14 @@ herr_t
 H5A__dense_rename(H5F_t *f, const H5O_ainfo_t *ainfo, const char *old_name, const char *new_name)
 {
     H5A_bt2_ud_common_t udata;               /* User data for v2 B-tree modify */
-    H5HF_t *            fheap        = NULL; /* Fractal heap handle */
-    H5HF_t *            shared_fheap = NULL; /* Fractal heap handle for shared header messages */
-    H5B2_t *            bt2_name     = NULL; /* v2 B-tree handle for name index */
-    H5B2_t *            bt2_corder   = NULL; /* v2 B-tree handle for creation order ndex */
-    H5A_t *             attr_copy    = NULL; /* Copy of attribute to rename */
+    H5HF_t             *fheap        = NULL; /* Fractal heap handle */
+    H5HF_t             *shared_fheap = NULL; /* Fractal heap handle for shared header messages */
+    H5B2_t             *bt2_name     = NULL; /* v2 B-tree handle for name index */
+    H5B2_t             *bt2_corder   = NULL; /* v2 B-tree handle for creation order ndex */
+    H5A_t              *attr_copy    = NULL; /* Copy of attribute to rename */
     htri_t              attr_sharable;       /* Flag indicating attributes are shareable */
     htri_t              shared_mesg;         /* Should this message be stored in the Shared Message table? */
-    htri_t              attr_exists;         /* Attribute exists in v2 B-tree */
+    hbool_t             attr_exists;         /* Attribute exists in v2 B-tree */
     herr_t              ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
@@ -917,9 +917,10 @@ H5A__dense_rename(H5F_t *f, const H5O_ainfo_t *ainfo, const char *old_name, cons
     udata.found_op_data = &attr_copy;
 
     /* Get copy of attribute through 'name' tracking v2 B-tree */
-    if ((attr_exists = H5B2_find(bt2_name, &udata, NULL, NULL)) < 0)
+    attr_exists = FALSE;
+    if (H5B2_find(bt2_name, &udata, &attr_exists, NULL, NULL) < 0)
         HGOTO_ERROR(H5E_ATTR, H5E_NOTFOUND, FAIL, "can't search for attribute in name index")
-    else if (attr_exists == FALSE)
+    if (attr_exists == FALSE)
         HGOTO_ERROR(H5E_ATTR, H5E_NOTFOUND, FAIL, "can't locate attribute in name index")
     HDassert(attr_copy);
 
@@ -942,7 +943,7 @@ H5A__dense_rename(H5F_t *f, const H5O_ainfo_t *ainfo, const char *old_name, cons
 
     /* Need to remove the attribute from the creation order index v2 B-tree */
     if (ainfo->index_corder) {
-        htri_t corder_attr_exists; /* Attribute exists in v2 B-tree */
+        hbool_t corder_attr_exists; /* Attribute exists in v2 B-tree */
 
         /* Open the creation order index v2 B-tree */
         HDassert(H5F_addr_defined(ainfo->corder_bt2_addr));
@@ -952,7 +953,8 @@ H5A__dense_rename(H5F_t *f, const H5O_ainfo_t *ainfo, const char *old_name, cons
         /* Set up the creation order to search for */
         udata.corder = attr_copy->shared->crt_idx;
 
-        if ((corder_attr_exists = H5B2_find(bt2_corder, &udata, NULL, NULL)) < 0)
+        corder_attr_exists = FALSE;
+        if (H5B2_find(bt2_corder, &udata, &corder_attr_exists, NULL, NULL) < 0)
             HGOTO_ERROR(H5E_ATTR, H5E_NOTFOUND, FAIL, "can't search for attribute in name index")
 
         if (corder_attr_exists) {
@@ -1043,14 +1045,14 @@ H5A__dense_iterate_bt2_cb(const void *_record, void *_bt2_udata)
     H5A_bt2_ud_it_t *bt2_udata = (H5A_bt2_ud_it_t *)_bt2_udata; /* User data for callback */
     herr_t           ret_value = H5_ITER_CONT;                  /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check for skipping attributes */
     if (bt2_udata->skip > 0)
         --bt2_udata->skip;
     else {
         H5A_fh_ud_cp_t fh_udata; /* User data for fractal heap 'op' callback */
-        H5HF_t *       fheap;    /* Fractal heap handle for attribute storage */
+        H5HF_t        *fheap;    /* Fractal heap handle for attribute storage */
 
         /* Check for iterating over shared attribute */
         if (record->flags & H5O_MSG_FLAG_SHARED)
@@ -1136,10 +1138,10 @@ H5A__dense_iterate(H5F_t *f, hid_t loc_id, const H5O_ainfo_t *ainfo, H5_index_t
                    H5_iter_order_t order, hsize_t skip, hsize_t *last_attr, const H5A_attr_iter_op_t *attr_op,
                    void *op_data)
 {
-    H5HF_t *         fheap        = NULL;      /* Fractal heap handle */
-    H5HF_t *         shared_fheap = NULL;      /* Fractal heap handle for shared header messages */
+    H5HF_t          *fheap        = NULL;      /* Fractal heap handle */
+    H5HF_t          *shared_fheap = NULL;      /* Fractal heap handle for shared header messages */
     H5A_attr_table_t atable       = {0, NULL}; /* Table of attributes */
-    H5B2_t *         bt2          = NULL;      /* v2 B-tree handle for index */
+    H5B2_t          *bt2          = NULL;      /* v2 B-tree handle for index */
     haddr_t          bt2_addr;                 /* Address of v2 B-tree to use for lookup */
     herr_t           ret_value = FAIL;         /* Return value */
 
@@ -1268,12 +1270,12 @@ static herr_t
 H5A__dense_remove_bt2_cb(const void *_record, void *_udata)
 {
     const H5A_dense_bt2_name_rec_t *record = (const H5A_dense_bt2_name_rec_t *)_record;
-    H5A_bt2_ud_rm_t *               udata  = (H5A_bt2_ud_rm_t *)_udata; /* User data for callback */
-    H5A_t * attr       = *(H5A_t **)udata->common.found_op_data;        /* Pointer to attribute to remove */
+    H5A_bt2_ud_rm_t                *udata  = (H5A_bt2_ud_rm_t *)_udata; /* User data for callback */
+    H5A_t  *attr       = *(H5A_t **)udata->common.found_op_data;        /* Pointer to attribute to remove */
     H5B2_t *bt2_corder = NULL;    /* v2 B-tree handle for creation order index */
     herr_t  ret_value  = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check for removing the link from the creation order index */
     if (H5F_addr_defined(udata->corder_bt2_addr)) {
@@ -1331,10 +1333,10 @@ herr_t
 H5A__dense_remove(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name)
 {
     H5A_bt2_ud_rm_t udata;               /* User data for v2 B-tree record removal */
-    H5HF_t *        fheap        = NULL; /* Fractal heap handle */
-    H5HF_t *        shared_fheap = NULL; /* Fractal heap handle for shared header messages */
-    H5B2_t *        bt2_name     = NULL; /* v2 B-tree handle for name index */
-    H5A_t *         attr_copy    = NULL; /* Copy of attribute to remove */
+    H5HF_t         *fheap        = NULL; /* Fractal heap handle */
+    H5HF_t         *shared_fheap = NULL; /* Fractal heap handle for shared header messages */
+    H5B2_t         *bt2_name     = NULL; /* v2 B-tree handle for name index */
+    H5A_t          *attr_copy    = NULL; /* Copy of attribute to remove */
     htri_t          attr_sharable;       /* Flag indicating attributes are shareable */
     herr_t          ret_value = SUCCEED; /* Return value */
 
@@ -1416,16 +1418,16 @@ done:
 static herr_t
 H5A__dense_remove_by_idx_bt2_cb(const void *_record, void *_bt2_udata)
 {
-    H5HF_t *                        fheap;         /* Fractal heap handle */
-    H5B2_t *                        bt2    = NULL; /* v2 B-tree handle for index */
+    H5HF_t                         *fheap;         /* Fractal heap handle */
+    H5B2_t                         *bt2    = NULL; /* v2 B-tree handle for index */
     const H5A_dense_bt2_name_rec_t *record = (const H5A_dense_bt2_name_rec_t *)_record; /* v2 B-tree record */
-    H5A_bt2_ud_rmbi_t *             bt2_udata = (H5A_bt2_ud_rmbi_t *)_bt2_udata; /* User data for callback */
+    H5A_bt2_ud_rmbi_t              *bt2_udata = (H5A_bt2_ud_rmbi_t *)_bt2_udata; /* User data for callback */
     H5A_fh_ud_cp_t                  fh_udata; /* User data for fractal heap 'op' callback */
     H5O_shared_t                    sh_loc;   /* Shared message info for attribute */
     hbool_t use_sh_loc;          /* Whether to use the attribute's shared location or the separate one */
     herr_t  ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Set up the user data for fractal heap 'op' callback */
     fh_udata.f      = bt2_udata->f;
@@ -1543,10 +1545,10 @@ herr_t
 H5A__dense_remove_by_idx(H5F_t *f, const H5O_ainfo_t *ainfo, H5_index_t idx_type, H5_iter_order_t order,
                          hsize_t n)
 {
-    H5HF_t *         fheap        = NULL;      /* Fractal heap handle */
-    H5HF_t *         shared_fheap = NULL;      /* Fractal heap handle for shared header messages */
+    H5HF_t          *fheap        = NULL;      /* Fractal heap handle */
+    H5HF_t          *shared_fheap = NULL;      /* Fractal heap handle for shared header messages */
     H5A_attr_table_t atable       = {0, NULL}; /* Table of attributes */
-    H5B2_t *         bt2          = NULL;      /* v2 B-tree handle for index */
+    H5B2_t          *bt2          = NULL;      /* v2 B-tree handle for index */
     haddr_t          bt2_addr;                 /* Address of v2 B-tree to use for operation */
     herr_t           ret_value = SUCCEED;      /* Return value */
 
@@ -1665,15 +1667,15 @@ done:
  *
  *-------------------------------------------------------------------------
  */
-htri_t
-H5A__dense_exists(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name)
+herr_t
+H5A__dense_exists(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name, hbool_t *attr_exists)
 {
     H5A_bt2_ud_common_t udata;               /* User data for v2 B-tree modify */
-    H5HF_t *            fheap        = NULL; /* Fractal heap handle */
-    H5HF_t *            shared_fheap = NULL; /* Fractal heap handle for shared header messages */
-    H5B2_t *            bt2_name     = NULL; /* v2 B-tree handle for name index */
+    H5HF_t             *fheap        = NULL; /* Fractal heap handle */
+    H5HF_t             *shared_fheap = NULL; /* Fractal heap handle for shared header messages */
+    H5B2_t             *bt2_name     = NULL; /* v2 B-tree handle for name index */
     htri_t              attr_sharable;       /* Flag indicating attributes are shareable */
-    htri_t              ret_value = TRUE;    /* Return value */
+    herr_t              ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
@@ -1681,6 +1683,7 @@ H5A__dense_exists(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name)
     HDassert(f);
     HDassert(ainfo);
     HDassert(name);
+    HDassert(attr_exists);
 
     /* Open the fractal heap */
     if (NULL == (fheap = H5HF_open(f, ainfo->fheap_addr)))
@@ -1722,7 +1725,7 @@ H5A__dense_exists(H5F_t *f, const H5O_ainfo_t *ainfo, const char *name)
     udata.found_op_data = NULL;
 
     /* Find the attribute in the 'name' index */
-    if ((ret_value = H5B2_find(bt2_name, &udata, NULL, NULL)) < 0)
+    if (H5B2_find(bt2_name, &udata, attr_exists, NULL, NULL) < 0)
         HGOTO_ERROR(H5E_ATTR, H5E_NOTFOUND, FAIL, "can't search for attribute in name index")
 
 done:
@@ -1755,10 +1758,10 @@ H5A__dense_delete_bt2_cb(const void *_record, void *_bt2_udata)
     const H5A_dense_bt2_name_rec_t *record =
         (const H5A_dense_bt2_name_rec_t *)_record;                      /* Record from B-tree */
     H5A_bt2_ud_common_t *bt2_udata = (H5A_bt2_ud_common_t *)_bt2_udata; /* User data for callback */
-    H5A_t *              attr      = NULL;                              /* Attribute being removed */
+    H5A_t               *attr      = NULL;                              /* Attribute being removed */
     herr_t               ret_value = SUCCEED;                           /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check for shared attribute */
     if (record->flags & H5O_MSG_FLAG_SHARED) {
@@ -1816,7 +1819,7 @@ herr_t
 H5A__dense_delete(H5F_t *f, H5O_ainfo_t *ainfo)
 {
     H5A_bt2_ud_common_t udata;               /* v2 B-tree user data for deleting attributes */
-    H5HF_t *            fheap     = NULL;    /* Fractal heap handle */
+    H5HF_t             *fheap     = NULL;    /* Fractal heap handle */
     herr_t              ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
