@@ -22,18 +22,18 @@
  *     Relies on "s3comms" utility layer to implement the AWS REST API.
  */
 
-/* Interface initialization */
-#define H5_INTERFACE_INIT_FUNC H5FD_ros3_init_interface
+#ifdef H5_HAVE_ROS3_VFD
+/* This source code file is part of the H5FD driver module */
+#include "H5FDdrvr_module.h"
+#endif
 
 #include "H5private.h"   /* Generic Functions        */
 #include "H5Eprivate.h"  /* Error handling           */
-#include "H5Fprivate.h"  /* File access              */
 #include "H5FDprivate.h" /* File drivers             */
 #include "H5FDros3.h"    /* ros3 file driver         */
 #include "H5FLprivate.h" /* Free Lists               */
 #include "H5Iprivate.h"  /* IDs                      */
 #include "H5MMprivate.h" /* Memory management        */
-#include "H5Pprivate.h"  /* Property lists           */
 #include "H5FDs3comms.h" /* S3 Communications        */
 
 #ifdef H5_HAVE_ROS3_VFD
@@ -70,11 +70,10 @@ static hid_t H5FD_ROS3_g = 0;
 #define ROS3_STATS_START_POWER 10
 #define ROS3_STATS_BIN_COUNT   16 /* MUST BE GREATER THAN 0 */
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+/*
  * Calculate `BASE ^ (START_POWER + (INTERVAL * bin_i))`
  * Stores result at `(unsigned long long *) out_ptr`.
  * Used in computing boundaries between stats bins.
- * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  */
 #define ROS3_STATS_POW(bin_i, out_ptr)                                                                       \
     {                                                                                                        \
@@ -88,7 +87,8 @@ static hid_t H5FD_ROS3_g = 0;
         *(out_ptr) = donotshadowresult;                                                                      \
     }
 
-/* array to hold pre-computed boundaries for stats bins */
+/* array to hold pre-computed boundaries for stats bins
+ */
 static unsigned long long ros3_stats_boundaries[ROS3_STATS_BIN_COUNT];
 
 /***************************************************************************
@@ -216,81 +216,72 @@ typedef struct H5FD_ros3_t {
 #define ADDR_OVERFLOW(A) (HADDR_UNDEF == (A) || ((A) & ~(haddr_t)MAXADDR))
 
 /* Prototypes */
-static H5FD_t *H5FD_ros3_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr);
-static herr_t  H5FD_ros3_close(H5FD_t *_file);
-static int     H5FD_ros3_cmp(const H5FD_t *_f1, const H5FD_t *_f2);
-static herr_t  H5FD_ros3_query(const H5FD_t *_f1, unsigned long *flags);
-static haddr_t H5FD_ros3_get_eoa(const H5FD_t *_file, H5FD_mem_t type);
-static herr_t  H5FD_ros3_set_eoa(H5FD_t *_file, H5FD_mem_t type, haddr_t addr);
-static haddr_t H5FD_ros3_get_eof(const H5FD_t *_file);
-static herr_t  H5FD_ros3_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle);
-static herr_t  H5FD_ros3_read(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
-                              void *buf);
-static herr_t  H5FD_ros3_write(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
-                               const void *buf);
-static herr_t  H5FD_ros3_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
-static herr_t  H5FD_ros3_validate_config(const H5FD_ros3_fapl_t *fa);
-static void   *H5FD_ros3_fapl_get(H5FD_t *_file);
-static void   *H5FD_ros3_fapl_copy(const void *_old_fa);
-static herr_t  H5FD_ros3_fapl_free(void *_fa);
+static herr_t  H5FD__ros3_term(void);
+static void   *H5FD__ros3_fapl_get(H5FD_t *_file);
+static void   *H5FD__ros3_fapl_copy(const void *_old_fa);
+static herr_t  H5FD__ros3_fapl_free(void *_fa);
+static H5FD_t *H5FD__ros3_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr);
+static herr_t  H5FD__ros3_close(H5FD_t *_file);
+static int     H5FD__ros3_cmp(const H5FD_t *_f1, const H5FD_t *_f2);
+static herr_t  H5FD__ros3_query(const H5FD_t *_f1, unsigned long *flags);
+static haddr_t H5FD__ros3_get_eoa(const H5FD_t *_file, H5FD_mem_t type);
+static herr_t  H5FD__ros3_set_eoa(H5FD_t *_file, H5FD_mem_t type, haddr_t addr);
+static haddr_t H5FD__ros3_get_eof(const H5FD_t *_file, H5FD_mem_t type);
+static herr_t  H5FD__ros3_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle);
+static herr_t  H5FD__ros3_read(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
+                               void *buf);
+static herr_t  H5FD__ros3_write(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
+                                const void *buf);
+static herr_t  H5FD__ros3_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
+
+static herr_t H5FD__ros3_validate_config(const H5FD_ros3_fapl_t *fa);
 
 static const H5FD_class_t H5FD_ros3_g = {
+    H5FD_CLASS_VERSION,       /* struct version       */
+    H5FD_ROS3_VALUE,          /* value                */
     "ros3",                   /* name                 */
     MAXADDR,                  /* maxaddr              */
     H5F_CLOSE_WEAK,           /* fc_degree            */
+    H5FD__ros3_term,          /* terminate            */
     NULL,                     /* sb_size              */
     NULL,                     /* sb_encode            */
     NULL,                     /* sb_decode            */
     sizeof(H5FD_ros3_fapl_t), /* fapl_size            */
-    H5FD_ros3_fapl_get,       /* fapl_get             */
-    H5FD_ros3_fapl_copy,      /* fapl_copy            */
-    H5FD_ros3_fapl_free,      /* fapl_free            */
+    H5FD__ros3_fapl_get,      /* fapl_get             */
+    H5FD__ros3_fapl_copy,     /* fapl_copy            */
+    H5FD__ros3_fapl_free,     /* fapl_free            */
     0,                        /* dxpl_size            */
     NULL,                     /* dxpl_copy            */
     NULL,                     /* dxpl_free            */
-    H5FD_ros3_open,           /* open                 */
-    H5FD_ros3_close,          /* close                */
-    H5FD_ros3_cmp,            /* cmp                  */
-    H5FD_ros3_query,          /* query                */
+    H5FD__ros3_open,          /* open                 */
+    H5FD__ros3_close,         /* close                */
+    H5FD__ros3_cmp,           /* cmp                  */
+    H5FD__ros3_query,         /* query                */
     NULL,                     /* get_type_map         */
     NULL,                     /* alloc                */
     NULL,                     /* free                 */
-    H5FD_ros3_get_eoa,        /* get_eoa              */
-    H5FD_ros3_set_eoa,        /* set_eoa              */
-    H5FD_ros3_get_eof,        /* get_eof              */
-    H5FD_ros3_get_handle,     /* get_handle           */
-    H5FD_ros3_read,           /* read                 */
-    H5FD_ros3_write,          /* write                */
+    H5FD__ros3_get_eoa,       /* get_eoa              */
+    H5FD__ros3_set_eoa,       /* set_eoa              */
+    H5FD__ros3_get_eof,       /* get_eof              */
+    H5FD__ros3_get_handle,    /* get_handle           */
+    H5FD__ros3_read,          /* read                 */
+    H5FD__ros3_write,         /* write                */
+    NULL,                     /* read_vector          */
+    NULL,                     /* write_vector         */
+    NULL,                     /* read_selection       */
+    NULL,                     /* write_selection      */
     NULL,                     /* flush                */
-    H5FD_ros3_truncate,       /* truncate             */
+    H5FD__ros3_truncate,      /* truncate             */
     NULL,                     /* lock                 */
     NULL,                     /* unlock               */
+    NULL,                     /* del                  */
+    NULL,                     /* ctl                  */
     H5FD_FLMAP_DICHOTOMY      /* fl_map               */
 };
 
 /* Declare a free list to manage the H5FD_ros3_t struct */
 H5FL_DEFINE_STATIC(H5FD_ros3_t);
 
-/*-------------------------------------------------------------------------
- * Function:    H5FD_ros3_init_interface
- *
- * Purpose:     Initializes any interface-specific data or routines.
- *
- * Return:      Success:    The driver ID for the ros3 driver.
- *              Failure:    Negative
- *
- * Programmer:  Jacob Smith 2017
- *
- *-------------------------------------------------------------------------
- */
-static herr_t
-H5FD_ros3_init_interface(void)
-{
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
-
-    FUNC_LEAVE_NOAPI(H5FD_ros3_init())
-} /* H5FD_ros3_init_interface() */
-
 /*-------------------------------------------------------------------------
  * Function:    H5FD_ros3_init
  *
@@ -307,7 +298,7 @@ H5FD_ros3_init_interface(void)
 hid_t
 H5FD_ros3_init(void)
 {
-    hid_t ret_value = H5I_INVALID_HID; /* Return value */
+    hid_t ret_value = H5I_INVALID_HID;
 #if ROS3_STATS
     unsigned int bin_i;
 #endif
@@ -315,11 +306,15 @@ H5FD_ros3_init(void)
     FUNC_ENTER_NOAPI(H5I_INVALID_HID)
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD_ros3_init() called.\n");
 #endif
 
-    if (H5I_VFL != H5I_get_type(H5FD_ROS3_g))
+    if (H5I_VFL != H5I_get_type(H5FD_ROS3_g)) {
         H5FD_ROS3_g = H5FD_register(&H5FD_ros3_g, sizeof(H5FD_class_t), FALSE);
+        if (H5I_INVALID_HID == H5FD_ROS3_g) {
+            HGOTO_ERROR(H5E_ID, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register ros3");
+        }
+    }
 
 #if ROS3_STATS
     /* pre-compute statsbin boundaries
@@ -332,7 +327,6 @@ H5FD_ros3_init(void)
     }
 #endif
 
-    /* Set return value */
     ret_value = H5FD_ROS3_g;
 
 done:
@@ -340,36 +334,36 @@ done:
 } /* end H5FD_ros3_init() */
 
 /*---------------------------------------------------------------------------
- * Function:    H5FD_ros3_term
+ * Function:    H5FD__ros3_term
  *
  * Purpose:     Shut down the VFD
  *
- * Returns:     <none>
+ * Returns:     SUCCEED (Can't fail)
  *
  * Programmer:  Jacob Smith 2017
  *
  *---------------------------------------------------------------------------
  */
-void
-H5FD_ros3_term(void)
+static herr_t
+H5FD__ros3_term(void)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_term() called.\n");
 #endif
 
     /* Reset VFL ID */
     H5FD_ROS3_g = 0;
 
-    FUNC_LEAVE_NOAPI_VOID
-} /* end H5FD_ros3_term() */
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5FD__ros3_term() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5Pset_fapl_ros3
  *
  * Purpose:     Modify the file access property list to use the H5FD_ROS3
- *              driver defined in this source file.  All driver specfic
+ *              driver defined in this source file.  All driver specific
  *              properties are passed in as a pointer to a suitably
  *              initialized instance of H5FD_ros3_fapl_t
  *
@@ -381,47 +375,47 @@ H5FD_ros3_term(void)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Pset_fapl_ros3(hid_t fapl_id, H5FD_ros3_fapl_t *fa)
+H5Pset_fapl_ros3(hid_t fapl_id, const H5FD_ros3_fapl_t *fa)
 {
     H5P_genplist_t *plist     = NULL; /* Property list pointer */
     herr_t          ret_value = FAIL;
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "i*x", fapl_id, fa);
+    H5TRACE2("e", "i*#", fapl_id, fa);
 
     HDassert(fa != NULL);
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5Pset_fapl_ros3() called.\n");
 #endif
 
     plist = H5P_object_verify(fapl_id, H5P_FILE_ACCESS);
     if (plist == NULL)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file access property list")
 
-    if (FAIL == H5FD_ros3_validate_config(fa))
+    if (FAIL == H5FD__ros3_validate_config(fa))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid ros3 config")
 
-    ret_value = H5P_set_driver(plist, H5FD_ROS3, (void *)fa);
+    ret_value = H5P_set_driver(plist, H5FD_ROS3, (const void *)fa, NULL);
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pset_fapl_ros3() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_ros3_validate_config()
+ * Function:    H5FD__ros3_validate_config()
  *
  * Purpose:     Test to see if the supplied instance of H5FD_ros3_fapl_t
- *              contains internally consistant data.  Return SUCCEED if so,
+ *              contains internally consistent data.  Return SUCCEED if so,
  *              and FAIL otherwise.
  *
- *              Note the difference between internally consistant and
+ *              Note the difference between internally consistent and
  *              correct.  As we will have to try to access the target
  *              object to determine whether the supplied data is correct,
- *              we will settle for internal consistancy at this point
+ *              we will settle for internal consistency at this point
  *
  * Return:      SUCCEED if instance of H5FD_ros3_fapl_t contains internally
- *              consistant data, FAIL otherwise.
+ *              consistent data, FAIL otherwise.
  *
  * Programmer:  Jacob Smith
  *              9/10/17
@@ -429,11 +423,11 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_validate_config(const H5FD_ros3_fapl_t *fa)
+H5FD__ros3_validate_config(const H5FD_ros3_fapl_t *fa)
 {
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     HDassert(fa != NULL);
 
@@ -447,7 +441,7 @@ H5FD_ros3_validate_config(const H5FD_ros3_fapl_t *fa)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_validate_config() */
+} /* end H5FD__ros3_validate_config() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5Pget_fapl_ros3
@@ -465,42 +459,42 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Pget_fapl_ros3(hid_t fapl_id, H5FD_ros3_fapl_t *fa_out)
+H5Pget_fapl_ros3(hid_t fapl_id, H5FD_ros3_fapl_t *fa_dst /*out*/)
 {
-    const H5FD_ros3_fapl_t *fa        = NULL;
+    const H5FD_ros3_fapl_t *fa_src    = NULL;
     H5P_genplist_t         *plist     = NULL;
     herr_t                  ret_value = SUCCEED;
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "i*x", fapl_id, fa_out);
+    H5TRACE2("e", "ix", fapl_id, fa_dst);
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5Pget_fapl_ros3() called.\n");
 #endif
 
-    if (fa_out == NULL)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "fa_out is NULL")
+    if (fa_dst == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "fa_dst is NULL")
 
     plist = H5P_object_verify(fapl_id, H5P_FILE_ACCESS);
     if (plist == NULL)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file access list")
 
-    if (H5FD_ROS3 != H5P_get_driver(plist))
+    if (H5FD_ROS3 != H5P_peek_driver(plist))
         HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "incorrect VFL driver")
 
-    fa = (const H5FD_ros3_fapl_t *)H5P_get_driver_info(plist);
-    if (fa == NULL)
+    fa_src = (const H5FD_ros3_fapl_t *)H5P_peek_driver_info(plist);
+    if (fa_src == NULL)
         HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "bad VFL driver info")
 
     /* Copy the ros3 fapl data out */
-    HDmemcpy(fa_out, fa, sizeof(H5FD_ros3_fapl_t));
+    H5MM_memcpy(fa_dst, fa_src, sizeof(H5FD_ros3_fapl_t));
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pget_fapl_ros3() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_ros3_fapl_get
+ * Function:    H5FD__ros3_fapl_get
  *
  * Purpose:     Gets a file access property list which could be used to
  *              create an identical file.
@@ -515,20 +509,20 @@ done:
  *-------------------------------------------------------------------------
  */
 static void *
-H5FD_ros3_fapl_get(H5FD_t *_file)
+H5FD__ros3_fapl_get(H5FD_t *_file)
 {
     H5FD_ros3_t      *file      = (H5FD_ros3_t *)_file;
     H5FD_ros3_fapl_t *fa        = NULL;
     void             *ret_value = NULL;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     fa = (H5FD_ros3_fapl_t *)H5MM_calloc(sizeof(H5FD_ros3_fapl_t));
     if (fa == NULL)
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     /* Copy the fields of the structure */
-    HDmemcpy(fa, &(file->fa), sizeof(H5FD_ros3_fapl_t));
+    H5MM_memcpy(fa, &(file->fa), sizeof(H5FD_ros3_fapl_t));
 
     /* Set return value */
     ret_value = fa;
@@ -539,10 +533,10 @@ done:
             H5MM_xfree(fa);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_fapl_get() */
+} /* end H5FD__ros3_fapl_get() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_ros3_fapl_copy
+ * Function:    H5FD__ros3_fapl_copy
  *
  * Purpose:     Copies the ros3-specific file access properties.
  *
@@ -556,19 +550,19 @@ done:
  *-------------------------------------------------------------------------
  */
 static void *
-H5FD_ros3_fapl_copy(const void *_old_fa)
+H5FD__ros3_fapl_copy(const void *_old_fa)
 {
     const H5FD_ros3_fapl_t *old_fa    = (const H5FD_ros3_fapl_t *)_old_fa;
     H5FD_ros3_fapl_t       *new_fa    = NULL;
     void                   *ret_value = NULL;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     new_fa = (H5FD_ros3_fapl_t *)H5MM_malloc(sizeof(H5FD_ros3_fapl_t));
     if (new_fa == NULL)
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
-    HDmemcpy(new_fa, old_fa, sizeof(H5FD_ros3_fapl_t));
+    H5MM_memcpy(new_fa, old_fa, sizeof(H5FD_ros3_fapl_t));
     ret_value = new_fa;
 
 done:
@@ -577,10 +571,10 @@ done:
             H5MM_xfree(new_fa);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_fapl_copy() */
+} /* end H5FD__ros3_fapl_copy() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_ros3_fapl_free
+ * Function:    H5FD__ros3_fapl_free
  *
  * Purpose:     Frees the ros3-specific file access properties.
  *
@@ -592,18 +586,18 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_fapl_free(void *_fa)
+H5FD__ros3_fapl_free(void *_fa)
 {
     H5FD_ros3_fapl_t *fa = (H5FD_ros3_fapl_t *)_fa;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     HDassert(fa != NULL); /* sanity check */
 
     H5MM_xfree(fa);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5FD_ros3_fapl_free() */
+} /* end H5FD__ros3_fapl_free() */
 
 #if ROS3_STATS
 /*----------------------------------------------------------------------------
@@ -633,10 +627,10 @@ ros3_reset_stats(H5FD_ros3_t *file)
     unsigned i         = 0;
     herr_t   ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDprintf("ros3_reset_stats() called\n");
 #endif
 
     if (file == NULL)
@@ -661,7 +655,7 @@ done:
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_open()
+ * Function: H5FD__ros3_open()
  *
  * Purpose:
  *
@@ -691,7 +685,7 @@ done:
  *-------------------------------------------------------------------------
  */
 static H5FD_t *
-H5FD_ros3_open(const char *url, unsigned flags, hid_t fapl_id, haddr_t maxaddr)
+H5FD__ros3_open(const char *url, unsigned flags, hid_t fapl_id, haddr_t maxaddr)
 {
     H5FD_ros3_t     *file = NULL;
     struct tm       *now  = NULL;
@@ -701,10 +695,10 @@ H5FD_ros3_open(const char *url, unsigned flags, hid_t fapl_id, haddr_t maxaddr)
     H5FD_ros3_fapl_t fa;
     H5FD_t          *ret_value = NULL;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_open() called.\n");
 #endif
 
     /* Sanity check on file offsets */
@@ -761,7 +755,7 @@ H5FD_ros3_open(const char *url, unsigned flags, hid_t fapl_id, haddr_t maxaddr)
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "unable to allocate file struct")
 
     file->s3r_handle = handle;
-    HDmemcpy(&(file->fa), &fa, sizeof(H5FD_ros3_fapl_t));
+    H5MM_memcpy(&(file->fa), &fa, sizeof(H5FD_ros3_fapl_t));
 
 #if ROS3_STATS
     if (FAIL == ros3_reset_stats(file))
@@ -781,7 +775,7 @@ done:
     }                          /* end if null return value (error) */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_open() */
+} /* end H5FD__ros3_open() */
 
 #if ROS3_STATS
 /*----------------------------------------------------------------------------
@@ -858,7 +852,7 @@ ros3_fprint_stats(FILE *stream, const H5FD_ros3_t *file)
     unsigned           suffix_i     = 0;
     const char         suffixes[]   = {' ', 'K', 'M', 'G', 'T', 'P'};
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     if (stream == NULL)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "file stream cannot be null");
@@ -1065,7 +1059,7 @@ done:
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_close()
+ * Function: H5FD__ros3_close()
  *
  * Purpose:
  *
@@ -1081,15 +1075,15 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_close(H5FD_t H5_ATTR_UNUSED *_file)
+H5FD__ros3_close(H5FD_t H5_ATTR_UNUSED *_file)
 {
     H5FD_ros3_t *file      = (H5FD_ros3_t *)_file;
     herr_t       ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_close() called.\n");
 #endif
 
     /* Sanity checks */
@@ -1114,11 +1108,11 @@ done:
     curl_global_cleanup(); /* cleanup to answer init on open */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_close() */
+} /* end H5FD__ros3_close() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_cmp()
+ * Function: H5FD__ros3_cmp()
  *
  * Purpose:
  *
@@ -1147,7 +1141,7 @@ done:
  *-------------------------------------------------------------------------
  */
 static int
-H5FD_ros3_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
+H5FD__ros3_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
 {
     const H5FD_ros3_t  *f1        = (const H5FD_ros3_t *)_f1;
     const H5FD_ros3_t  *f2        = (const H5FD_ros3_t *)_f2;
@@ -1155,10 +1149,10 @@ H5FD_ros3_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
     const parsed_url_t *purl2     = NULL;
     int                 ret_value = 0;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_cmp() called.\n");
 #endif
 
     HDassert(f1->s3r_handle != NULL);
@@ -1243,10 +1237,10 @@ H5FD_ros3_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5FD_ros3_cmp() */
+} /* H5FD__ros3_cmp() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_ros3_query
+ * Function:    H5FD__ros3_query
  *
  * Purpose:     Set the flags that this VFL driver is capable of supporting.
  *              (listed in H5FDpublic.h)
@@ -1265,12 +1259,12 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_query(const H5FD_t H5_ATTR_UNUSED *_file, unsigned long *flags /* out */)
+H5FD__ros3_query(const H5FD_t H5_ATTR_UNUSED *_file, unsigned long *flags)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_query() called.\n");
 #endif
 
     /* Set the VFL feature flags that this driver supports */
@@ -1281,11 +1275,11 @@ H5FD_ros3_query(const H5FD_t H5_ATTR_UNUSED *_file, unsigned long *flags /* out
     } /* end if */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5FD_ros3_query() */
+} /* H5FD__ros3_query() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_get_eoa()
+ * Function: H5FD__ros3_get_eoa()
  *
  * Purpose:
  *
@@ -1303,22 +1297,22 @@ H5FD_ros3_query(const H5FD_t H5_ATTR_UNUSED *_file, unsigned long *flags /* out
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_ros3_get_eoa(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
+H5FD__ros3_get_eoa(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
 {
     const H5FD_ros3_t *file = (const H5FD_ros3_t *)_file;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_get_eoa() called.\n");
 #endif
 
     FUNC_LEAVE_NOAPI(file->eoa)
-} /* end H5FD_ros3_get_eoa() */
+} /* end H5FD__ros3_get_eoa() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_set_eoa()
+ * Function: H5FD__ros3_set_eoa()
  *
  * Purpose:
  *
@@ -1334,24 +1328,24 @@ H5FD_ros3_get_eoa(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
+H5FD__ros3_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
 {
     H5FD_ros3_t *file = (H5FD_ros3_t *)_file;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_set_eoa() called.\n");
 #endif
 
     file->eoa = addr;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5FD_ros3_set_eoa() */
+} /* H5FD__ros3_set_eoa() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_get_eof()
+ * Function: H5FD__ros3_get_eof()
  *
  * Purpose:
  *
@@ -1368,22 +1362,22 @@ H5FD_ros3_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_ros3_get_eof(const H5FD_t *_file)
+H5FD__ros3_get_eof(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
 {
     const H5FD_ros3_t *file = (const H5FD_ros3_t *)_file;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_get_eof() called.\n");
 #endif
 
     FUNC_LEAVE_NOAPI(H5FD_s3comms_s3r_get_filesize(file->s3r_handle))
-} /* end H5FD_ros3_get_eof() */
+} /* end H5FD__ros3_get_eof() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_get_handle()
+ * Function: H5FD__ros3_get_handle()
  *
  * Purpose:
  *
@@ -1399,15 +1393,15 @@ H5FD_ros3_get_eof(const H5FD_t *_file)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_get_handle(H5FD_t *_file, hid_t H5_ATTR_UNUSED fapl, void **file_handle)
+H5FD__ros3_get_handle(H5FD_t *_file, hid_t H5_ATTR_UNUSED fapl, void **file_handle)
 {
     H5FD_ros3_t *file      = (H5FD_ros3_t *)_file;
     herr_t       ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_get_handle() called.\n");
 #endif
 
     if (!file_handle)
@@ -1417,11 +1411,11 @@ H5FD_ros3_get_handle(H5FD_t *_file, hid_t H5_ATTR_UNUSED fapl, void **file_handl
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_get_handle() */
+} /* end H5FD__ros3_get_handle() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_read()
+ * Function: H5FD__ros3_read()
  *
  * Purpose
  *
@@ -1442,8 +1436,8 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t addr,
-               size_t size, void *buf)
+H5FD__ros3_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t addr,
+                size_t size, void *buf)
 {
     H5FD_ros3_t *file      = (H5FD_ros3_t *)_file;
     size_t       filesize  = 0;
@@ -1454,10 +1448,10 @@ H5FD_ros3_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUS
     unsigned       bin_i = 0;
 #endif /* ROS3_STATS */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_read() called.\n");
 #endif
 
     HDassert(file != NULL);
@@ -1498,11 +1492,11 @@ H5FD_ros3_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUS
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_read() */
+} /* end H5FD__ros3_read() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_write()
+ * Function: H5FD__ros3_write()
  *
  * Purpose:
  *
@@ -1519,26 +1513,26 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_write(H5FD_t H5_ATTR_UNUSED *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id,
-                haddr_t H5_ATTR_UNUSED addr, size_t H5_ATTR_UNUSED size, const void H5_ATTR_UNUSED *buf)
+H5FD__ros3_write(H5FD_t H5_ATTR_UNUSED *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id,
+                 haddr_t H5_ATTR_UNUSED addr, size_t H5_ATTR_UNUSED size, const void H5_ATTR_UNUSED *buf)
 {
     herr_t ret_value = FAIL;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_write() called.\n");
 #endif
 
     HGOTO_ERROR(H5E_VFL, H5E_UNSUPPORTED, FAIL, "cannot write to read-only file.")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5FD_ros3_write() */
+} /* H5FD__ros3_write() */
 
 /*-------------------------------------------------------------------------
  *
- * Function: H5FD_ros3_truncate()
+ * Function: H5FD__ros3_truncate()
  *
  * Purpose:
  *
@@ -1557,20 +1551,21 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_ros3_truncate(H5FD_t H5_ATTR_UNUSED *_file, hid_t H5_ATTR_UNUSED dxpl_id, hbool_t H5_ATTR_UNUSED closing)
+H5FD__ros3_truncate(H5FD_t H5_ATTR_UNUSED *_file, hid_t H5_ATTR_UNUSED dxpl_id,
+                    hbool_t H5_ATTR_UNUSED closing)
 {
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
 #if ROS3_DEBUG
-    HDfprintf(stdout, "called %s.\n", FUNC);
+    HDfprintf(stdout, "H5FD__ros3_truncate() called.\n");
 #endif
 
     HGOTO_ERROR(H5E_VFL, H5E_UNSUPPORTED, FAIL, "cannot truncate read-only file.")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_ros3_truncate() */
+} /* end H5FD__ros3_truncate() */
 
 #endif /* H5_HAVE_ROS3_VFD */
