@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -22,6 +21,7 @@
  *          and is not intended for production use!
  */
 #include <assert.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -29,6 +29,11 @@
 
 #include "hdf5.h"
 
+#ifdef H5_HAVE_FLOCK
+/* Needed for lock type definitions (e.g., LOCK_EX) */
+#include <sys/file.h>
+#endif /* H5_HAVE_FLOCK */
+
 #ifdef H5_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -41,21 +46,14 @@
 #include <windows.h>
 #include <io.h>
 
-/* This is not defined in the Windows header files */
-#ifndef F_OK
-#define F_OK 00
-#endif
-
-#endif
-
-#ifdef MAX
-#undef MAX
-#endif /* MAX */
-#define MAX(X, Y) ((X) > (Y) ? (X) : (Y))
+#endif /* H5_HAVE_WIN32_API */
 
 /* The driver identification number, initialized at runtime */
 static hid_t H5FD_STDIO_g = 0;
 
+/* Whether to ignore file locks when disabled (env var value) */
+static htri_t ignore_disabled_file_locks_s = -1;
+
 /* The maximum number of bytes which can be written in a single I/O operation */
 static size_t H5_STDIO_MAX_IO_BYTES_g = (size_t)-1;
 
@@ -86,7 +84,8 @@ typedef struct H5FD_stdio_t {
     haddr_t            eof;          /* end of file; current file size   */
     haddr_t            pos;          /* current file I/O position        */
     unsigned           write_access; /* Flag to indicate the file was opened with write access */
-    H5FD_stdio_file_op op;           /* last operation */
+    hbool_t            ignore_disabled_file_locks;
+    H5FD_stdio_file_op op; /* last operation */
 #ifndef H5_HAVE_WIN32_API
     /* On most systems the combination of device and i-node number uniquely
      * identify a file.  Note that Cygwin, MinGW and other Windows POSIX
@@ -162,6 +161,7 @@ typedef struct H5FD_stdio_t {
      (file_offset_t)((A) + (Z)) < (file_offset_t)(A))
 
 /* Prototypes */
+static herr_t  H5FD_stdio_term(void);
 static H5FD_t *H5FD_stdio_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr);
 static herr_t  H5FD_stdio_close(H5FD_t *lf);
 static int     H5FD_stdio_cmp(const H5FD_t *_f1, const H5FD_t *_f2);
@@ -169,47 +169,59 @@ static herr_t  H5FD_stdio_query(const H5FD_t *_f1, unsigned long *flags);
 static haddr_t H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, hsize_t size);
 static haddr_t H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t type);
 static herr_t  H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t type, haddr_t addr);
-static haddr_t H5FD_stdio_get_eof(const H5FD_t *_file);
+static haddr_t H5FD_stdio_get_eof(const H5FD_t *_file, H5FD_mem_t type);
 static herr_t  H5FD_stdio_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle);
 static herr_t  H5FD_stdio_read(H5FD_t *lf, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
                                void *buf);
 static herr_t  H5FD_stdio_write(H5FD_t *lf, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
                                 const void *buf);
-static herr_t  H5FD_stdio_flush(H5FD_t *_file, hid_t dxpl_id, unsigned closing);
+static herr_t  H5FD_stdio_flush(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
 static herr_t  H5FD_stdio_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
+static herr_t  H5FD_stdio_lock(H5FD_t *_file, hbool_t rw);
+static herr_t  H5FD_stdio_unlock(H5FD_t *_file);
+static herr_t  H5FD_stdio_delete(const char *filename, hid_t fapl_id);
 
 static const H5FD_class_t H5FD_stdio_g = {
-    "stdio",               /* name         */
-    MAXADDR,               /* maxaddr      */
-    H5F_CLOSE_WEAK,        /* fc_degree    */
-    NULL,                  /* sb_size      */
-    NULL,                  /* sb_encode    */
-    NULL,                  /* sb_decode    */
-    0,                     /* fapl_size    */
-    NULL,                  /* fapl_get     */
-    NULL,                  /* fapl_copy    */
-    NULL,                  /* fapl_free    */
-    0,                     /* dxpl_size    */
-    NULL,                  /* dxpl_copy    */
-    NULL,                  /* dxpl_free    */
-    H5FD_stdio_open,       /* open         */
-    H5FD_stdio_close,      /* close        */
-    H5FD_stdio_cmp,        /* cmp          */
-    H5FD_stdio_query,      /* query        */
-    NULL,                  /* get_type_map */
-    H5FD_stdio_alloc,      /* alloc        */
-    NULL,                  /* free         */
-    H5FD_stdio_get_eoa,    /* get_eoa      */
-    H5FD_stdio_set_eoa,    /* set_eoa      */
-    H5FD_stdio_get_eof,    /* get_eof      */
-    H5FD_stdio_get_handle, /* get_handle   */
-    H5FD_stdio_read,       /* read         */
-    H5FD_stdio_write,      /* write        */
-    H5FD_stdio_flush,      /* flush        */
-    H5FD_stdio_truncate,   /* truncate     */
-    NULL,                  /* lock         */
-    NULL,                  /* unlock       */
-    H5FD_FLMAP_DICHOTOMY   /* fl_map       */
+    H5FD_CLASS_VERSION,    /* struct version  */
+    H5_VFD_STDIO,          /* value           */
+    "stdio",               /* name            */
+    MAXADDR,               /* maxaddr         */
+    H5F_CLOSE_WEAK,        /* fc_degree       */
+    H5FD_stdio_term,       /* terminate       */
+    NULL,                  /* sb_size         */
+    NULL,                  /* sb_encode       */
+    NULL,                  /* sb_decode       */
+    0,                     /* fapl_size       */
+    NULL,                  /* fapl_get        */
+    NULL,                  /* fapl_copy       */
+    NULL,                  /* fapl_free       */
+    0,                     /* dxpl_size       */
+    NULL,                  /* dxpl_copy       */
+    NULL,                  /* dxpl_free       */
+    H5FD_stdio_open,       /* open            */
+    H5FD_stdio_close,      /* close           */
+    H5FD_stdio_cmp,        /* cmp             */
+    H5FD_stdio_query,      /* query           */
+    NULL,                  /* get_type_map    */
+    H5FD_stdio_alloc,      /* alloc           */
+    NULL,                  /* free            */
+    H5FD_stdio_get_eoa,    /* get_eoa         */
+    H5FD_stdio_set_eoa,    /* set_eoa         */
+    H5FD_stdio_get_eof,    /* get_eof         */
+    H5FD_stdio_get_handle, /* get_handle      */
+    H5FD_stdio_read,       /* read            */
+    H5FD_stdio_write,      /* write           */
+    NULL,                  /* read_vector     */
+    NULL,                  /* write_vector    */
+    NULL,                  /* read_selection  */
+    NULL,                  /* write_selection */
+    H5FD_stdio_flush,      /* flush           */
+    H5FD_stdio_truncate,   /* truncate        */
+    H5FD_stdio_lock,       /* lock            */
+    H5FD_stdio_unlock,     /* unlock          */
+    H5FD_stdio_delete,     /* del             */
+    NULL,                  /* ctl             */
+    H5FD_FLMAP_DICHOTOMY   /* fl_map          */
 };
 
 /*-------------------------------------------------------------------------
@@ -230,9 +242,20 @@ static const H5FD_class_t H5FD_stdio_g = {
 hid_t
 H5FD_stdio_init(void)
 {
+    char *lock_env_var = NULL; /* Environment variable pointer */
+
     /* Clear the error stack */
     H5Eclear2(H5E_DEFAULT);
 
+    /* Check the use disabled file locks environment variable */
+    lock_env_var = getenv(HDF5_USE_FILE_LOCKING);
+    if (lock_env_var && !strcmp(lock_env_var, "BEST_EFFORT"))
+        ignore_disabled_file_locks_s = 1; /* Override: Ignore disabled locks */
+    else if (lock_env_var && (!strcmp(lock_env_var, "TRUE") || !strcmp(lock_env_var, "1")))
+        ignore_disabled_file_locks_s = 0; /* Override: Don't ignore disabled locks */
+    else
+        ignore_disabled_file_locks_s = -1; /* Environment variable not set, or not set correctly */
+
     if (H5I_VFL != H5Iget_type(H5FD_STDIO_g))
         H5FD_STDIO_g = H5FDregister(&H5FD_stdio_g);
 
@@ -244,20 +267,20 @@ H5FD_stdio_init(void)
  *
  * Purpose:  Shut down the VFD
  *
- * Returns:     None
+ * Returns:     Non-negative on success or negative on failure
  *
  * Programmer:  Quincey Koziol
  *              Friday, Jan 30, 2004
  *
  *---------------------------------------------------------------------------
  */
-void
+static herr_t
 H5FD_stdio_term(void)
 {
     /* Reset VFL ID */
     H5FD_STDIO_g = 0;
 
-    return;
+    return 0;
 } /* end H5FD_stdio_term() */
 
 /*-------------------------------------------------------------------------
@@ -397,6 +420,22 @@ H5FD_stdio_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
         file->eof = (haddr_t)x;
     }
 
+    /* Check the file locking flags in the fapl */
+    if (ignore_disabled_file_locks_s != -1)
+        /* The environment variable was set, so use that preferentially */
+        file->ignore_disabled_file_locks = ignore_disabled_file_locks_s;
+    else {
+        hbool_t unused;
+
+        /* Use the value in the property list */
+        if (H5Pget_file_locking(fapl_id, &unused, &file->ignore_disabled_file_locks) < 0) {
+            free(file);
+            fclose(f);
+            H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_CANTGET,
+                        "unable to get use disabled file locks property", NULL);
+        }
+    }
+
     /* Get the file descriptor (needed for truncate and some Windows information) */
 #ifdef H5_HAVE_WIN32_API
     file->fd = _fileno(file->fp);
@@ -553,18 +592,24 @@ H5FD_stdio_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_query(const H5FD_t *_f, unsigned long *flags /* out */)
+H5FD_stdio_query(const H5FD_t *_f, unsigned long /*OUT*/ *flags)
 {
     /* Quiet the compiler */
     (void)_f;
 
-    /* Set the VFL feature flags that this driver supports */
+    /* Set the VFL feature flags that this driver supports.
+     *
+     * Note that this VFD does not support SWMR due to the unpredictable
+     * nature of the buffering layer.
+     */
     if (flags) {
         *flags = 0;
-        *flags |= H5FD_FEAT_AGGREGATE_METADATA;  /* OK to aggregate metadata allocations */
+        *flags |= H5FD_FEAT_AGGREGATE_METADATA;  /* OK to aggregate metadata allocations  */
         *flags |= H5FD_FEAT_ACCUMULATE_METADATA; /* OK to accumulate metadata for faster writes */
-        *flags |= H5FD_FEAT_DATA_SIEVE; /* OK to perform data sieving for faster raw data reads & writes */
-        *flags |= H5FD_FEAT_AGGREGATE_SMALLDATA; /* OK to aggregate "small" raw data allocations */
+        *flags |= H5FD_FEAT_DATA_SIEVE; /* OK to perform data sieving for faster raw data reads & writes    */
+        *flags |= H5FD_FEAT_AGGREGATE_SMALLDATA;    /* OK to aggregate "small" raw data allocations    */
+        *flags |= H5FD_FEAT_DEFAULT_VFD_COMPATIBLE; /* VFD creates a file which can be opened with the default
+                                                       VFD      */
     }
 
     return 0;
@@ -589,8 +634,7 @@ H5FD_stdio_query(const H5FD_t *_f, unsigned long *flags /* out */)
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, hid_t /*H5_ATTR_UNUSED*/ dxpl_id,
-                 hsize_t size)
+H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxpl_id, hsize_t size)
 {
     H5FD_stdio_t *file = (H5FD_stdio_t *)_file;
     haddr_t       addr;
@@ -605,13 +649,6 @@ H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, hid_t /*H5_A
     /* Compute the address for the block to allocate */
     addr = file->eoa;
 
-    /* Check if we need to align this block */
-    if (size >= file->pub.threshold) {
-        /* Check for an already aligned block */
-        if ((addr % file->pub.alignment) != 0)
-            addr = ((addr / file->pub.alignment) + 1) * file->pub.alignment;
-    } /* end if */
-
     file->eoa = addr + size;
 
     return addr;
@@ -634,7 +671,7 @@ H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, hid_t /*H5_A
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type)
+H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type)
 {
     const H5FD_stdio_t *file = (const H5FD_stdio_t *)_file;
 
@@ -664,7 +701,7 @@ H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, haddr_t addr)
+H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, haddr_t addr)
 {
     H5FD_stdio_t *file = (H5FD_stdio_t *)_file;
 
@@ -698,14 +735,20 @@ H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, haddr_t ad
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_stdio_get_eof(const H5FD_t *_file)
+H5FD_stdio_get_eof(const H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type)
 {
     const H5FD_stdio_t *file = (const H5FD_stdio_t *)_file;
 
+    /* Quiet the compiler */
+    (void)type;
+
     /* Clear the error stack */
     H5Eclear2(H5E_DEFAULT);
 
-    return MAX(file->eof, file->eoa);
+    /* Quiet the compiler */
+    (void)type;
+
+    return (file->eof);
 } /* end H5FD_stdio_get_eof() */
 
 /*-------------------------------------------------------------------------
@@ -721,7 +764,7 @@ H5FD_stdio_get_eof(const H5FD_t *_file)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle)
+H5FD_stdio_get_handle(H5FD_t *_file, hid_t /*UNUSED*/ fapl, void **file_handle)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_get_handle"; /* Function Name for error reporting */
@@ -758,7 +801,8 @@ H5FD_stdio_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, size_t size, void *buf /*out*/)
+H5FD_stdio_read(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxpl_id, haddr_t addr,
+                size_t size, void /*OUT*/ *buf)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_read"; /* Function Name for error reporting */
@@ -860,7 +904,8 @@ H5FD_stdio_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, siz
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_write(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, size_t size, const void *buf)
+H5FD_stdio_write(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxpl_id, haddr_t addr,
+                 size_t size, const void *buf)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_write"; /* Function Name for error reporting */
@@ -947,7 +992,7 @@ H5FD_stdio_write(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, si
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_flush(H5FD_t *_file, hid_t dxpl_id, unsigned closing)
+H5FD_stdio_flush(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t closing)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_flush"; /* Function Name for error reporting */
@@ -991,7 +1036,7 @@ H5FD_stdio_flush(H5FD_t *_file, hid_t dxpl_id, unsigned closing)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing)
+H5FD_stdio_truncate(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t /*UNUSED*/ closing)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_truncate"; /* Function Name for error reporting */
@@ -1020,7 +1065,7 @@ H5FD_stdio_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing)
             rewind(file->fp);
 
             /* Windows uses this odd QuadPart union for 32/64-bit portability */
-            li.QuadPart = (__int64)file->eoa;
+            li.QuadPart = (LONGLONG)file->eoa;
 
             /* Extend the file to make sure it's large enough.
              *
@@ -1065,6 +1110,132 @@ H5FD_stdio_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing)
     return 0;
 } /* end H5FD_stdio_truncate() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5FD_stdio_lock
+ *
+ * Purpose:     Lock a file via flock
+ *              NOTE: This function is a no-op if flock() is not present.
+ *
+ * Errors:
+ *    IO    FCNTL    flock failed.
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ * Programmer:  Vailin Choi; March 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5FD_stdio_lock(H5FD_t *_file, hbool_t rw)
+{
+#ifdef H5_HAVE_FLOCK
+    H5FD_stdio_t      *file = (H5FD_stdio_t *)_file; /* VFD file struct                      */
+    int                lock_flags;                   /* file locking flags                   */
+    static const char *func = "H5FD_stdio_lock";     /* Function Name for error reporting    */
+
+    /* Clear the error stack */
+    H5Eclear2(H5E_DEFAULT);
+
+    assert(file);
+
+    /* Set exclusive or shared lock based on rw status */
+    lock_flags = rw ? LOCK_EX : LOCK_SH;
+
+    /* Place a non-blocking lock on the file */
+    if (flock(file->fd, lock_flags | LOCK_NB) < 0) {
+        if (file->ignore_disabled_file_locks && ENOSYS == errno)
+            /* When errno is set to ENOSYS, the file system does not support
+             * locking, so ignore it.
+             */
+            errno = 0;
+        else
+            H5Epush_ret(func, H5E_ERR_CLS, H5E_VFL, H5E_CANTLOCKFILE, "file lock failed", -1);
+    } /* end if */
+
+    /* Flush the stream */
+    if (fflush(file->fp) < 0)
+        H5Epush_ret(func, H5E_ERR_CLS, H5E_IO, H5E_WRITEERROR, "fflush failed", -1);
+
+#endif /* H5_HAVE_FLOCK */
+
+    return 0;
+} /* end H5FD_stdio_lock() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5F_stdio_unlock
+ *
+ * Purpose:     Unlock a file via flock
+ *              NOTE: This function is a no-op if flock() is not present.
+ *
+ * Errors:
+ *    IO    FCNTL    flock failed.
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ * Programmer:  Vailin Choi; March 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5FD_stdio_unlock(H5FD_t *_file)
+{
+#ifdef H5_HAVE_FLOCK
+    H5FD_stdio_t      *file = (H5FD_stdio_t *)_file; /* VFD file struct                      */
+    static const char *func = "H5FD_stdio_unlock";   /* Function Name for error reporting    */
+
+    /* Clear the error stack */
+    H5Eclear2(H5E_DEFAULT);
+
+    assert(file);
+
+    /* Flush the stream */
+    if (fflush(file->fp) < 0)
+        H5Epush_ret(func, H5E_ERR_CLS, H5E_IO, H5E_WRITEERROR, "fflush failed", -1);
+
+    /* Place a non-blocking lock on the file */
+    if (flock(file->fd, LOCK_UN) < 0) {
+        if (file->ignore_disabled_file_locks && ENOSYS == errno)
+            /* When errno is set to ENOSYS, the file system does not support
+             * locking, so ignore it.
+             */
+            errno = 0;
+        else
+            H5Epush_ret(func, H5E_ERR_CLS, H5E_VFL, H5E_CANTUNLOCKFILE, "file unlock failed", -1);
+    } /* end if */
+
+#endif /* H5_HAVE_FLOCK */
+
+    return 0;
+} /* end H5FD_stdio_unlock() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5FD_stdio_delete
+ *
+ * Purpose:     Delete a file
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5FD_stdio_delete(const char *filename, hid_t /*UNUSED*/ fapl_id)
+{
+    static const char *func = "H5FD_stdio_delete"; /* Function Name for error reporting    */
+
+    /* Clear the error stack */
+    H5Eclear2(H5E_DEFAULT);
+
+    assert(filename);
+
+    /* Quiet compiler */
+    (void)fapl_id;
+
+    if (remove(filename) < 0)
+        H5Epush_ret(func, H5E_ERR_CLS, H5E_VFL, H5E_CANTDELETEFILE, "can't delete file)", -1);
+
+    return 0;
+} /* end H5FD_stdio_delete() */
+
 #ifdef H5private_H
 /*
  * This is not related to the functionality of the driver code.
