@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -11,119 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/** \defgroup H5G H5G
- *
- * Use the functions in this module to manage HDF5 groups.
- *
- * <table>
- * <tr><th>Create</th><th>Read</th></tr>
- * <tr valign="top">
- *   <td>
- *   \snippet{lineno} H5G_examples.c create
- *   </td>
- *   <td>
- *   \snippet{lineno} H5G_examples.c read
- *   </td>
- * <tr><th>Update</th><th>Delete</th></tr>
- * <tr valign="top">
- *   <td>
- *   \snippet{lineno} H5G_examples.c update
- *   </td>
- *   <td>
- *   \snippet{lineno} H5G_examples.c delete
- *   </td>
- * </tr>
- * </table>
- *
- * \details \Bold{Groups in HDF5:} A group associates names with objects and
- *          provides a mechanism for mapping a name to an object. Since all
- *          objects appear in at least one group (with the possible exception of
- *          the root object) and since objects can have names in more than one
- *          group, the set of all objects in an HDF5 file is a directed
- *          graph. The internal nodes (nodes with out-degree greater than zero)
- *          must be groups while the leaf nodes (nodes with out-degree zero) are
- *          either empty groups or objects of some other type. Exactly one
- *          object in every non-empty file is the root object. The root object
- *          always has a positive in-degree because it is pointed to by the file
- *          super block.
- *
- *          \Bold{Locating objects in the HDF5 file hierarchy:} An object name
- *          consists of one or more components separated from one another by
- *          slashes. An absolute name begins with a slash and the object is
- *          located by looking for the first component in the root object, then
- *          looking for the second component in the first object, etc., until
- *          the entire name is traversed. A relative name does not begin with a
- *          slash and the traversal begins at the location specified by the
- *          create or access function.
- *
- *          \Bold{Group implementations in HDF5:} The original HDF5 group
- *          implementation provided a single indexed structure for link
- *          storage. A new group implementation, in HDF5 Release 1.8.0, enables
- *          more efficient compact storage for very small groups, improved link
- *          indexing for large groups, and other advanced features.
- *
- *          \li The \Emph{original indexed} format remains the default. Links
- *              are stored in a B-tree in the group’s local heap.
- *          \li Groups created in the new \Emph{compact-or-indexed} format, the
- *              implementation introduced with Release 1.8.0, can be tuned for
- *              performance, switching between the compact and indexed formats
- *              at thresholds set in the user application.
- *              - The \Emph{compact} format will conserve file space and processing
- *                overhead when working with small groups and is particularly
- *                valuable when a group contains no links. Links are stored
- *                as a list of messages in the group’s header.
- *              - The \Emph{indexed} format will yield improved
- *                performance when working with large groups, e.g., groups
- *                containing thousands to millions of members. Links are stored in
- *                a fractal heap and indexed with an improved B-tree.
- *          \li The new implementation also enables the use of link names consisting of
- *              non-ASCII character sets (see H5Pset_char_encoding()) and is
- *              required for all link types other than hard or soft links, e.g.,
- *              external and user-defined links (see the \ref H5L APIs).
- *
- *          The original group structure and the newer structures are not
- *          directly interoperable. By default, a group will be created in the
- *          original indexed format. An existing group can be changed to a
- *          compact-or-indexed format if the need arises; there is no capability
- *          to change back. As stated above, once in the compact-or-indexed
- *          format, a group can switch between compact and indexed as needed.
- *
- *          Groups will be initially created in the compact-or-indexed format
- *          only when one or more of the following conditions is met:
- *          \li The low version bound value of the library version bounds property
- *              has been set to Release 1.8.0 or later in the file access property
- *              list (see H5Pset_libver_bounds()). Currently, that would require an
- *              H5Pset_libver_bounds() call with the low parameter set to
- *              #H5F_LIBVER_LATEST.\n When this property is set for an HDF5 file,
- *              all objects in the file will be created using the latest available
- *              format; no effort will be made to create a file that can be read by
- *              older libraries.
- *          \li The creation order tracking property, #H5P_CRT_ORDER_TRACKED, has been
- *              set in the group creation property list (see H5Pset_link_creation_order()).
- *
- *          An existing group, currently in the original indexed format, will be
- *          converted to the compact-or-indexed format upon the occurrence of
- *          any of the following events:
- *          \li An external or user-defined link is inserted into the group.
- *          \li A link named with a string composed of non-ASCII characters is
- *              inserted into the group.
- *
- *          The compact-or-indexed format offers performance improvements that
- *          will be most notable at the extremes, i.e., in groups with zero
- *          members and in groups with tens of thousands of members. But
- *          measurable differences may sometimes appear at a threshold as low as
- *          eight group members. Since these performance thresholds and criteria
- *          differ from application to application, tunable settings are
- *          provided to govern the switch between the compact and indexed
- *          formats (see H5Pset_link_phase_change()). Optimal thresholds will
- *          depend on the application and the operating environment.
- *
- *          Future versions of HDF5 will retain the ability to create, read,
- *          write, and manipulate all groups stored in either the original
- *          indexed format or the compact-or-indexed format.
- *
- */
-
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Gpublic.h
@@ -238,6 +124,19 @@ extern "C" {
  */
 H5_DLL hid_t H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gcreate}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Gcreate_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                             const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Gcreate_async(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id,
+                              hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -280,7 +179,7 @@ H5_DLL hid_t H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcp
  *          H5Gclose() when the group is no longer needed so that resource
  *          leaks will not develop.
  *
- * \see H5Olink(), H5Dcreate(), Using Identifiers
+ * \see H5Olink(), H5Gcreate()
  *
  * \since 1.8.0
  *
@@ -317,6 +216,18 @@ H5_DLL hid_t H5Gcreate_anon(hid_t loc_id, hid_t gcpl_id, hid_t gapl_id);
  */
 H5_DLL hid_t H5Gopen2(hid_t loc_id, const char *name, hid_t gapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gopen}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Gopen_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                           const char *name, hid_t gapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Gopen_async(hid_t loc_id, const char *name, hid_t gapl_id, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -368,6 +279,18 @@ H5_DLL hid_t H5Gget_create_plist(hid_t group_id);
  */
 H5_DLL herr_t H5Gget_info(hid_t loc_id, H5G_info_t *ginfo);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gget_info}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gget_info_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                                H5G_info_t *ginfo /*out*/, hid_t es_id);
+#else
+H5_DLL herr_t H5Gget_info_async(hid_t loc_id, H5G_info_t *ginfo /*out*/, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -402,6 +325,20 @@ H5_DLL herr_t H5Gget_info(hid_t loc_id, H5G_info_t *ginfo);
  */
 H5_DLL herr_t H5Gget_info_by_name(hid_t loc_id, const char *name, H5G_info_t *ginfo, hid_t lapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gget_info_by_name}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gget_info_by_name_async(const char *app_file, const char *app_func, unsigned app_line,
+                                        hid_t loc_id, const char *name, H5G_info_t *ginfo /*out*/,
+                                        hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL herr_t H5Gget_info_by_name_async(hid_t loc_id, const char *name, H5G_info_t *ginfo /*out*/,
+                                        hid_t lapl_id, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -450,6 +387,22 @@ H5_DLL herr_t H5Gget_info_by_name(hid_t loc_id, const char *name, H5G_info_t *gi
 H5_DLL herr_t H5Gget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_t idx_type,
                                  H5_iter_order_t order, hsize_t n, H5G_info_t *ginfo, hid_t lapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gget_info_by_idx}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gget_info_by_idx_async(const char *app_file, const char *app_func, unsigned app_line,
+                                       hid_t loc_id, const char *group_name, H5_index_t idx_type,
+                                       H5_iter_order_t order, hsize_t n, H5G_info_t *ginfo /*out*/,
+                                       hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL herr_t H5Gget_info_by_idx_async(hid_t loc_id, const char *group_name, H5_index_t idx_type,
+                                       H5_iter_order_t order, hsize_t n, H5G_info_t *ginfo /*out*/,
+                                       hid_t lapl_id, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -529,6 +482,42 @@ H5_DLL herr_t H5Grefresh(hid_t group_id);
  */
 H5_DLL herr_t H5Gclose(hid_t group_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gclose}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gclose_async(const char *app_file, const char *app_func, unsigned app_line, hid_t group_id,
+                             hid_t es_id);
+#else
+H5_DLL herr_t H5Gclose_async(hid_t group_id, hid_t es_id);
+#endif
+
+/// \cond DEV
+/* API Wrappers for async routines */
+/* (Must be defined _after_ the function prototype) */
+/* (And must only defined when included in application code, not the library) */
+#ifndef H5G_MODULE
+#define H5Gcreate_async(...)           H5Gcreate_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gopen_async(...)             H5Gopen_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gget_info_async(...)         H5Gget_info_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gget_info_by_name_async(...) H5Gget_info_by_name_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gget_info_by_idx_async(...)  H5Gget_info_by_idx_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gclose_async(...)            H5Gclose_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+
+/* Define "wrapper" versions of function calls, to allow compile-time values to
+ *      be passed in by language wrapper or library layer on top of HDF5.
+ */
+#define H5Gcreate_async_wrap           H5_NO_EXPAND(H5Gcreate_async)
+#define H5Gopen_async_wrap             H5_NO_EXPAND(H5Gopen_async)
+#define H5Gget_info_async_wrap         H5_NO_EXPAND(H5Gget_info_async)
+#define H5Gget_info_by_name_async_wrap H5_NO_EXPAND(H5Gget_info_by_name_async)
+#define H5Gget_info_by_idx_async_wrap  H5_NO_EXPAND(H5Gget_info_by_idx_async)
+#define H5Gclose_async_wrap            H5_NO_EXPAND(H5Gclose_async)
+#endif /* H5G_MODULE */
+/// \endcond
+
 /* Symbols defined for compatibility with previous versions of the HDF5 API.
  *
  * Use of these symbols is deprecated.
@@ -773,7 +762,7 @@ H5_DLL herr_t H5Glink2(hid_t cur_loc_id, const char *cur_name, H5G_link_t type,
  *
  * \attention Exercise care in moving groups as it is possible to render data in
  *            a file inaccessible with H5Gmove(). See The Group Interface in the
- *            HDF5 User's Guide.
+ *            \ref UG.
  *
  * \version 1.8.0 Function deprecated in this release.
  *
@@ -804,7 +793,7 @@ H5_DLL herr_t H5Gmove(hid_t src_loc_id, const char *src_name, const char *dst_na
  *
  * \attention Exercise care in moving groups as it is possible to render data in
  *            a file inaccessible with H5Gmove2(). See The Group Interface in the
- *            HDF5 User's Guide.
+ *            \ref UG.
  *
  * \version 1.8.0 Function deprecated in this release.
  *
@@ -841,11 +830,11 @@ H5_DLL herr_t H5Gmove2(hid_t src_loc_id, const char *src_name, hid_t dst_loc_id,
  *          Note that space identified as freespace is available for re-use only
  *          as long as the file remains open; once a file has been closed, the
  *          HDF5 library loses track of freespace. See “Freespace Management” in
- *          the HDF5 User's Guide for further details.
+ *          the \ref UG for further details.
  *
  * \attention Exercise care in moving groups as it is possible to render data in
  *            a file inaccessible with H5Gunlink(). See The Group Interface in the
- *            HDF5 User's Guide.
+ *            \ref UG.
  *
  * \version 1.8.0 Function deprecated in this release.
  *
