@@ -1,71 +1,66 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-
-/* Programmer:  Quincey Koziol <koziol@hdfgroup.org>
+/* Programmer:  Quincey Koziol
  *              Thursday, March  1, 2007
  *
  * Purpose:	A message holding driver info settings
  *              in the superblock extension.
  */
 
-#include "H5Omodule.h"          /* This source code file is part of the H5O module */
+#include "H5Omodule.h" /* This source code file is part of the H5O module */
 
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5Opkg.h"      /* Object headers			*/
+#include "H5MMprivate.h" /* Memory management			*/
 
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5Opkg.h"             /* Object headers			*/
-#include "H5MMprivate.h"	/* Memory management			*/
-
-static void  *H5O_drvinfo_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags,
-    unsigned *ioflags, size_t p_size, const uint8_t *p);
-static herr_t H5O_drvinfo_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void  *H5O_drvinfo_copy(const void *_mesg, void *_dest);
-static size_t H5O_drvinfo_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
+static void  *H5O__drvinfo_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags,
+                                  size_t p_size, const uint8_t *p);
+static herr_t H5O__drvinfo_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
+static void  *H5O__drvinfo_copy(const void *_mesg, void *_dest);
+static size_t H5O__drvinfo_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
 static herr_t H5O__drvinfo_reset(void *_mesg);
-static herr_t H5O__drvinfo_debug(H5F_t *f, const void *_mesg, FILE *stream,
-    int indent, int fwidth);
+static herr_t H5O__drvinfo_debug(H5F_t *f, const void *_mesg, FILE *stream, int indent, int fwidth);
 
 /* This message derives from H5O message class */
 const H5O_msg_class_t H5O_MSG_DRVINFO[1] = {{
-    H5O_DRVINFO_ID,             /*message id number                     */
-    "driver info",		/*message name for debugging            */
-    sizeof(H5O_drvinfo_t),	/*native message size                   */
-    0,				/* messages are sharable?       */
-    H5O_drvinfo_decode,		/*decode message                        */
-    H5O_drvinfo_encode,		/*encode message                        */
-    H5O_drvinfo_copy,           /*copy the native value                 */
-    H5O_drvinfo_size,		/*raw message size			*/
-    H5O__drvinfo_reset,         /*free internal memory			*/
-    NULL,                       /* free method				*/
-    NULL,			/* file delete method			*/
-    NULL,			/* link method				*/
-    NULL,			/*set share method		*/
-    NULL,		    	/*can share method		        */
-    NULL,			/* pre copy native value to file	*/
-    NULL,			/* copy native value to file		*/
-    NULL,			/* post copy native value to file	*/
-    NULL,			/* get creation index		        */
-    NULL,			/* set creation index		        */
-    H5O__drvinfo_debug           /*debug the message			*/
+    H5O_DRVINFO_ID,        /*message id number                     */
+    "driver info",         /*message name for debugging            */
+    sizeof(H5O_drvinfo_t), /*native message size                   */
+    0,                     /* messages are shareable?               */
+    H5O__drvinfo_decode,   /*decode message                        */
+    H5O__drvinfo_encode,   /*encode message                        */
+    H5O__drvinfo_copy,     /*copy the native value                 */
+    H5O__drvinfo_size,     /*raw message size			*/
+    H5O__drvinfo_reset,    /*free internal memory			*/
+    NULL,                  /* free method				*/
+    NULL,                  /* file delete method			*/
+    NULL,                  /* link method				*/
+    NULL,                  /*set share method		        */
+    NULL,                  /*can share method		        */
+    NULL,                  /* pre copy native value to file	*/
+    NULL,                  /* copy native value to file		*/
+    NULL,                  /* post copy native value to file	*/
+    NULL,                  /* get creation index		        */
+    NULL,                  /* set creation index		        */
+    H5O__drvinfo_debug     /*debug the message			*/
 }};
 
 /* Current version of driver info information */
-#define H5O_DRVINFO_VERSION 	0
+#define H5O_DRVINFO_VERSION 0
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_drvinfo_decode
+ * Function:	H5O__drvinfo_decode
  *
  * Purpose:	Decode a shared message table message and return a pointer
  *              to a newly allocated H5O_drvinfo_t struct.
@@ -79,26 +74,26 @@ const H5O_msg_class_t H5O_MSG_DRVINFO[1] = {{
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_drvinfo_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
-    unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
-    size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+H5O__drvinfo_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
+                    unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
+                    size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
 {
-    H5O_drvinfo_t	*mesg;          /* Native message */
-    void		*ret_value = NULL;      /* Return value */
+    H5O_drvinfo_t *mesg;             /* Native message */
+    void          *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(f);
     HDassert(p);
 
     /* Version of message */
-    if(*p++ != H5O_DRVINFO_VERSION)
+    if (*p++ != H5O_DRVINFO_VERSION)
         HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message")
 
     /* Allocate space for message */
-    if(NULL == (mesg = (H5O_drvinfo_t *)H5MM_calloc(sizeof(H5O_drvinfo_t))))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for driver info message")
+    if (NULL == (mesg = (H5O_drvinfo_t *)H5MM_calloc(sizeof(H5O_drvinfo_t))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for driver info message")
 
     /* Retrieve driver name */
     H5MM_memcpy(mesg->name, p, 8);
@@ -110,9 +105,9 @@ H5O_drvinfo_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
     HDassert(mesg->len);
 
     /* Allocate space for buffer */
-    if(NULL == (mesg->buf = (uint8_t *)H5MM_malloc(mesg->len))) {
+    if (NULL == (mesg->buf = (uint8_t *)H5MM_malloc(mesg->len))) {
         mesg = (H5O_drvinfo_t *)H5MM_xfree(mesg);
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for driver info buffer")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for driver info buffer")
     } /* end if */
 
     /* Copy encoded driver info into buffer */
@@ -123,11 +118,10 @@ H5O_drvinfo_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_drvinfo_decode() */
+} /* end H5O__drvinfo_decode() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_drvinfo_encode
+ * Function:	H5O__drvinfo_encode
  *
  * Purpose:	Encode a v1 B-tree 'K' value message.
  *
@@ -139,11 +133,12 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_drvinfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
+H5O__drvinfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p,
+                    const void *_mesg)
 {
     const H5O_drvinfo_t *mesg = (const H5O_drvinfo_t *)_mesg;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -159,11 +154,10 @@ H5O_drvinfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_share
     H5MM_memcpy(p, mesg->buf, mesg->len);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_drvinfo_encode() */
+} /* end H5O__drvinfo_encode() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_drvinfo_copy
+ * Function:	H5O__drvinfo_copy
  *
  * Purpose:	Copies a message from _MESG to _DEST, allocating _DEST if
  *		necessary.
@@ -177,28 +171,29 @@ H5O_drvinfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_share
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_drvinfo_copy(const void *_mesg, void *_dest)
+H5O__drvinfo_copy(const void *_mesg, void *_dest)
 {
-    const H5O_drvinfo_t	*mesg = (const H5O_drvinfo_t *)_mesg;
-    H5O_drvinfo_t	*dest = (H5O_drvinfo_t *)_dest;
-    void		*ret_value = NULL;      /* Return value */
+    const H5O_drvinfo_t *mesg      = (const H5O_drvinfo_t *)_mesg;
+    H5O_drvinfo_t       *dest      = (H5O_drvinfo_t *)_dest;
+    void                *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(mesg);
 
-    if(!dest && NULL == (dest = (H5O_drvinfo_t *)H5MM_malloc(sizeof(H5O_drvinfo_t))))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for shared message table message")
+    if (!dest && NULL == (dest = (H5O_drvinfo_t *)H5MM_malloc(sizeof(H5O_drvinfo_t))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL,
+                    "memory allocation failed for shared message table message")
 
     /* Shallow copy the fields */
     *dest = *mesg;
 
     /* Copy the buffer */
-    if(NULL == (dest->buf = (uint8_t *)H5MM_malloc(mesg->len))) {
-        if(dest != _dest)
+    if (NULL == (dest->buf = (uint8_t *)H5MM_malloc(mesg->len))) {
+        if (dest != _dest)
             dest = (H5O_drvinfo_t *)H5MM_xfree(dest);
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
     } /* end if */
     H5MM_memcpy(dest->buf, mesg->buf, mesg->len);
 
@@ -207,11 +202,10 @@ H5O_drvinfo_copy(const void *_mesg, void *_dest)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_drvinfo_copy() */
+} /* end H5O__drvinfo_copy() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_drvinfo_size
+ * Function:	H5O__drvinfo_size
  *
  * Purpose:	Returns the size of the raw message in bytes not counting the
  *		message type or size fields, but only the data fields.
@@ -225,26 +219,25 @@ done:
  *-------------------------------------------------------------------------
  */
 static size_t
-H5O_drvinfo_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared, const void *_mesg)
+H5O__drvinfo_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared, const void *_mesg)
 {
-    const H5O_drvinfo_t *mesg = (const H5O_drvinfo_t *)_mesg;
-    size_t ret_value = 0;       /* Return value */
+    const H5O_drvinfo_t *mesg      = (const H5O_drvinfo_t *)_mesg;
+    size_t               ret_value = 0; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(f);
     HDassert(mesg);
 
-    ret_value = 1 +             /* Version number */
-		8 +             /* Driver name */
-		2 +             /* Buffer length */
-		mesg->len;      /* Buffer */
+    ret_value = 1 +        /* Version number */
+                8 +        /* Driver name */
+                2 +        /* Buffer length */
+                mesg->len; /* Buffer */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_drvinfo_size() */
+} /* end H5O__drvinfo_size() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__drvinfo_reset
  *
@@ -254,7 +247,6 @@ H5O_drvinfo_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_s
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              Mar  1 2007
  *
  *-------------------------------------------------------------------------
@@ -262,9 +254,9 @@ H5O_drvinfo_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_s
 static herr_t
 H5O__drvinfo_reset(void *_mesg)
 {
-    H5O_drvinfo_t *mesg = (H5O_drvinfo_t *) _mesg;
+    H5O_drvinfo_t *mesg = (H5O_drvinfo_t *)_mesg;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
     HDassert(mesg);
@@ -275,7 +267,6 @@ H5O__drvinfo_reset(void *_mesg)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__drvinfo_reset() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__drvinfo_debug
  *
@@ -289,12 +280,11 @@ H5O__drvinfo_reset(void *_mesg)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O__drvinfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream,
-    int indent, int fwidth)
+H5O__drvinfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int indent, int fwidth)
 {
     const H5O_drvinfo_t *mesg = (const H5O_drvinfo_t *)_mesg;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -303,12 +293,8 @@ H5O__drvinfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream,
     HDassert(indent >= 0);
     HDassert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
-	      "Driver name:", mesg->name);
-    HDfprintf(stream, "%*s%-*s %Zu\n", indent, "", fwidth,
-	      "Buffer size:", mesg->len);
+    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "Driver name:", mesg->name);
+    HDfprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth, "Buffer size:", mesg->len);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__drvinfo_debug() */
-
-
