@@ -2,10 +2,10 @@
  * Copyright by The HDF Group.                                               *
  * All rights reserved.                                                      *
  *                                                                           *
- * This file is part of HDF5. The full HDF5 copyright notice, including      *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -15,52 +15,41 @@
  *
  */
 
-
 /****************/
 /* Module Setup */
 /****************/
 
-#include "H5PLmodule.h"          /* This source code file is part of the H5PL module */
-
+#include "H5PLmodule.h" /* This source code file is part of the H5PL module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"      /* Generic Functions            */
-#include "H5Eprivate.h"     /* Error handling               */
-#include "H5MMprivate.h"    /* Memory management            */
-#include "H5PLpkg.h"        /* Plugin                       */
-#include "H5Zprivate.h"     /* Filter pipeline              */
-
+#include "H5private.h"   /* Generic Functions            */
+#include "H5Eprivate.h"  /* Error handling               */
+#include "H5MMprivate.h" /* Memory management            */
+#include "H5PLpkg.h"     /* Plugin                       */
+#include "H5Zprivate.h"  /* Filter pipeline              */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-/* Package initialization variable */
-hbool_t H5_PKG_INIT_VAR = FALSE;
-
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
@@ -68,16 +57,14 @@ hbool_t H5_PKG_INIT_VAR = FALSE;
 /* Bitmask that controls whether classes of plugins
  * (e.g.: filters, VOL drivers) can be loaded.
  */
-static unsigned int     H5PL_plugin_control_mask_g = H5PL_ALL_PLUGIN;
+static unsigned int H5PL_plugin_control_mask_g = H5PL_ALL_PLUGIN;
 
 /* This flag will be set to FALSE if the HDF5_PLUGIN_PRELOAD
  * environment variable was set to H5PL_NO_PLUGIN at
  * package initialization.
  */
-static hbool_t          H5PL_allow_plugins_g = TRUE;
+static hbool_t H5PL_allow_plugins_g = TRUE;
 
-
-
 /*-------------------------------------------------------------------------
  * Function:    H5PL__get_plugin_control_mask
  *
@@ -90,7 +77,7 @@ static hbool_t          H5PL_allow_plugins_g = TRUE;
 herr_t
 H5PL__get_plugin_control_mask(unsigned int *mask /*out*/)
 {
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE_NOERR
 
@@ -104,7 +91,6 @@ H5PL__get_plugin_control_mask(unsigned int *mask /*out*/)
 
 } /* end H5PL__get_plugin_control_mask() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5PL__set_plugin_control_mask
  *
@@ -117,7 +103,7 @@ H5PL__get_plugin_control_mask(unsigned int *mask /*out*/)
 herr_t
 H5PL__set_plugin_control_mask(unsigned int mask)
 {
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE_NOERR
 
@@ -133,33 +119,31 @@ H5PL__set_plugin_control_mask(unsigned int mask)
 
 } /* end H5PL__set_plugin_control_mask() */
 
-
 /*-------------------------------------------------------------------------
- * Function:    H5PL__init_package
+ * Function:    H5PL_init
  *
- * Purpose:     Initialize any package-specific data and call any init
- *              routines for the package.
- *
- * Return:      SUCCEED/FAIL
+ * Purpose:     Initialize the interface from some other layer.
  *
+ * Return:      Success:        non-negative
+ *              Failure:        negative
  *-------------------------------------------------------------------------
  */
 herr_t
-H5PL__init_package(void)
+H5PL_init(void)
 {
-    char        *env_var = NULL;
-    herr_t      ret_value = SUCCEED;
+    char  *env_var   = NULL;
+    herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_PACKAGE
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Check the environment variable to determine if the user wants
      * to ignore plugins. The special symbol H5PL_NO_PLUGIN (defined in
      * H5PLpublic.h) means we don't want to load plugins.
      */
-    if (NULL != (env_var = HDgetenv("HDF5_PLUGIN_PRELOAD")))
+    if (NULL != (env_var = HDgetenv(HDF5_PLUGIN_PRELOAD)))
         if (!HDstrcmp(env_var, H5PL_NO_PLUGIN)) {
             H5PL_plugin_control_mask_g = 0;
-            H5PL_allow_plugins_g = FALSE;
+            H5PL_allow_plugins_g       = FALSE;
         }
 
     /* Create the table of previously-loaded plugins */
@@ -172,9 +156,8 @@ H5PL__init_package(void)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5PL__init_package() */
+}
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5PL_term_package
  *
@@ -192,34 +175,26 @@ int
 H5PL_term_package(void)
 {
     hbool_t already_closed = FALSE;
-    int     ret_value = 0;
+    int     ret_value      = 0;
 
     FUNC_ENTER_NOAPI_NOINIT
 
-    if (H5_PKG_INIT_VAR) {
+    /* Close the plugin cache.
+     * We need to bump the return value if we did any real work here.
+     */
+    if (H5PL__close_plugin_cache(&already_closed) < 0)
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing plugin cache")
+    if (!already_closed)
+        ret_value++;
 
-        /* Close the plugin cache.
-         * We need to bump the return value if we did any real work here.
-         */
-        if (H5PL__close_plugin_cache(&already_closed) < 0)
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing plugin cache")
-        if (!already_closed)
-            ret_value++;
-
-        /* Close the search path table and free the paths */
-        if (H5PL__close_path_table() < 0)
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing search path table")
-
-        /* Mark the interface as uninitialized */
-        if (0 == ret_value)
-            H5_PKG_INIT_VAR = FALSE;
-    } /* end if */
+    /* Close the search path table and free the paths */
+    if (H5PL__close_path_table() < 0)
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing search path table")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5PL_term_package() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5PL_load
  *
@@ -237,10 +212,10 @@ done:
 const void *
 H5PL_load(H5PL_type_t type, const H5PL_key_t *key)
 {
-    H5PL_search_params_t    search_params;          /* Plugin search parameters     */
-    hbool_t                 found = FALSE;          /* Whether the plugin was found */
-    const void             *plugin_info = NULL;     /* Information from the plugin  */
-    const void             *ret_value = NULL;
+    H5PL_search_params_t search_params;       /* Plugin search parameters     */
+    hbool_t              found       = FALSE; /* Whether the plugin was found */
+    const void          *plugin_info = NULL;  /* Information from the plugin  */
+    const void          *ret_value   = NULL;
 
     FUNC_ENTER_NOAPI(NULL)
 
@@ -250,10 +225,18 @@ H5PL_load(H5PL_type_t type, const H5PL_key_t *key)
             if ((H5PL_plugin_control_mask_g & H5PL_FILTER_PLUGIN) == 0)
                 HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "filter plugins disabled")
             break;
+
         case H5PL_TYPE_VOL:
-            if((H5PL_plugin_control_mask_g & H5PL_VOL_PLUGIN) == 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "Virtual Object Layer (VOL) driver plugins disabled")
+            if ((H5PL_plugin_control_mask_g & H5PL_VOL_PLUGIN) == 0)
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL,
+                            "Virtual Object Layer (VOL) driver plugins disabled")
             break;
+
+        case H5PL_TYPE_VFD:
+            if ((H5PL_plugin_control_mask_g & H5PL_VFD_PLUGIN) == 0)
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "Virtual File Driver (VFD) plugins disabled")
+            break;
+
         case H5PL_TYPE_ERROR:
         case H5PL_TYPE_NONE:
         default:
@@ -262,11 +245,11 @@ H5PL_load(H5PL_type_t type, const H5PL_key_t *key)
 
     /* Set up the search parameters */
     search_params.type = type;
-    search_params.key = key;
+    search_params.key  = key;
 
     /* Search in the table of already loaded plugin libraries */
-    if(H5PL__find_plugin_in_cache(&search_params, &found, &plugin_info) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, NULL, "search in plugin cache  failed")
+    if (H5PL__find_plugin_in_cache(&search_params, &found, &plugin_info) < 0)
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, NULL, "search in plugin cache failed")
 
     /* If not found, try iterating through the path table to find an appropriate plugin */
     if (!found)
@@ -281,15 +264,36 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5PL_load() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5PL__open
  *
  * Purpose:     Opens a plugin.
  *
- *              The success parameter will be set to TRUE and the plugin_info
- *              parameter will be filled in on success. Otherwise, they
- *              will be FALSE and NULL, respectively.
+ *              `path` specifies the path to the plugin library file.
+ *
+ *              `type` specifies the type of plugin being searched for and
+ *              will be used to verify that a loaded plugin matches the
+ *              type requested. H5PL_TYPE_NONE may be passed, in which case
+ *              no plugin type verification is performed. This is most
+ *              useful when iterating over available plugins without regard
+ *              to their types.
+ *
+ *              `key` specifies the information that will be used to find a
+ *              specific plugin. For filter plugins, this is typically an
+ *              integer identifier. For VOL connector and VFD plugins, this
+ *              is typically either an integer identifier or a name string.
+ *              After a plugin has been opened, this information will be
+ *              compared against the relevant information provided by the
+ *              plugin to ensure that the plugin is a match. If
+ *              H5PL_TYPE_NONE is provided for `type`, then `key` should be
+ *              NULL.
+ *
+ *              On successful open of a plugin, the `success` parameter
+ *              will be set to TRUE and the `plugin_type` and `plugin_info`
+ *              parameters will be filled appropriately. On failure, the
+ *              `success` parameter will be set to FALSE, the `plugin_type`
+ *              parameter will be set to H5PL_TYPE_ERROR and the
+ *              `plugin_info` parameter will be set to NULL.
  *
  * Return:      SUCCEED/FAIL
  *
@@ -304,26 +308,32 @@ done:
  *       get_plugin_info function pointer, but early (4.4.7, at least) gcc
  *       only allows diagnostic pragmas to be toggled outside of functions.
  */
-H5_GCC_DIAG_OFF(pedantic)
+H5_GCC_CLANG_DIAG_OFF("pedantic")
 herr_t
-H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key,
-    hbool_t *success, const void **plugin_info)
+H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *success,
+           H5PL_type_t *plugin_type, const void **plugin_info)
 {
-    H5PL_HANDLE             handle = NULL;
-    H5PL_get_plugin_type_t  get_plugin_type = NULL;
-    H5PL_get_plugin_info_t  get_plugin_info = NULL;
-    herr_t                  ret_value = SUCCEED;
+    H5PL_HANDLE            handle          = NULL;
+    H5PL_get_plugin_type_t get_plugin_type = NULL;
+    H5PL_get_plugin_info_t get_plugin_info = NULL;
+    H5PL_type_t            loaded_plugin_type;
+    H5PL_key_t             tmp_key;
+    herr_t                 ret_value = SUCCEED;
 
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
     HDassert(path);
+    if (type == H5PL_TYPE_NONE)
+        HDassert(!key);
     HDassert(success);
     HDassert(plugin_info);
 
     /* Initialize out parameters */
-    *success = FALSE;
+    *success     = FALSE;
     *plugin_info = NULL;
+    if (plugin_type)
+        *plugin_type = H5PL_TYPE_ERROR;
 
     /* There are different reasons why a library can't be open, e.g. wrong architecture.
      * If we can't open the library, just return.
@@ -346,54 +356,88 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key,
         HGOTO_DONE(SUCCEED)
 
     /* Check the plugin type and return if it doesn't match the one passed in */
-    if(type != (H5PL_type_t)(*get_plugin_type)())
+    loaded_plugin_type = (H5PL_type_t)(*get_plugin_type)();
+    if ((type != H5PL_TYPE_NONE) && (type != loaded_plugin_type))
         HGOTO_DONE(SUCCEED)
 
     /* Get the plugin information */
-    switch (type) {
-        case H5PL_TYPE_FILTER:
-        {
+    switch (loaded_plugin_type) {
+        case H5PL_TYPE_FILTER: {
             const H5Z_class2_t *filter_info;
 
             /* Get the plugin info */
             if (NULL == (filter_info = (const H5Z_class2_t *)(*get_plugin_info)()))
                 HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get filter info from plugin")
 
+            /* Setup temporary plugin key if one wasn't supplied */
+            if (!key) {
+                tmp_key.id = filter_info->id;
+                key        = &tmp_key;
+            }
+
             /* If the filter IDs match, we're done. Set the output parameters. */
             if (filter_info->id == key->id) {
+                if (plugin_type)
+                    *plugin_type = H5PL_TYPE_FILTER;
                 *plugin_info = (const void *)filter_info;
-                *success = TRUE;
+                *success     = TRUE;
             }
 
             break;
         }
 
-        case H5PL_TYPE_VOL:
-        {
-            const H5VL_class_t *cls;
+        case H5PL_TYPE_VOL: {
+            const void *cls;
 
             /* Get the plugin info */
-            if(NULL == (cls = (const H5VL_class_t *)(*get_plugin_info)()))
+            if (NULL == (cls = (const void *)(*get_plugin_info)()))
                 HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get VOL connector info from plugin")
 
-            /* Which kind of key are we looking for? */
-            if(key->vol.kind == H5VL_GET_CONNECTOR_BY_NAME) {
-                /* If the plugin names match, we're done. Set the output parameters. */
-                if(cls->name && !HDstrcmp(cls->name, key->vol.u.name)) {
-                    *plugin_info = (const void *)cls;
-                    *success = TRUE;
-                } /* end if */
-            } /* end if */
-            else {
-                /* Sanity check */
-                HDassert(key->vol.kind == H5VL_GET_CONNECTOR_BY_VALUE);
+            /* Setup temporary plugin key if one wasn't supplied */
+            if (!key) {
+                tmp_key.vol.kind   = H5VL_GET_CONNECTOR_BY_NAME;
+                tmp_key.vol.u.name = ((const H5VL_class_t *)cls)->name;
+                key                = &tmp_key;
+            }
 
-                /* If the plugin values match, we're done. Set the output parameters. */
-                if(cls->value == key->vol.u.value) {
-                    *plugin_info = (const void *)cls;
-                    *success = TRUE;
-                } /* end if */
-            } /* end else */
+            /* Ask VOL interface if this class is the one we are looking for and is compatible, etc */
+            if (H5VL_check_plugin_load(cls, key, success) < 0)
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, FAIL, "VOL connector compatibility check failed")
+
+            /* Check for finding the correct plugin */
+            if (*success) {
+                if (plugin_type)
+                    *plugin_type = H5PL_TYPE_VOL;
+                *plugin_info = cls;
+            }
+
+            break;
+        }
+
+        case H5PL_TYPE_VFD: {
+            const void *cls;
+
+            /* Get the plugin info */
+            if (NULL == (cls = (const void *)(*get_plugin_info)()))
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get VFD info from plugin")
+
+            /* Setup temporary plugin key if one wasn't supplied */
+            if (!key) {
+                tmp_key.vfd.kind   = H5FD_GET_DRIVER_BY_NAME;
+                tmp_key.vfd.u.name = ((const H5FD_class_t *)cls)->name;
+                key                = &tmp_key;
+            }
+
+            /* Ask VFD interface if this class is the one we are looking for and is compatible, etc */
+            if (H5FD_check_plugin_load(cls, key, success) < 0)
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, FAIL, "VFD compatibility check failed")
+
+            /* Check for finding the correct plugin */
+            if (*success) {
+                if (plugin_type)
+                    *plugin_type = H5PL_TYPE_VFD;
+                *plugin_info = cls;
+            }
 
             break;
         }
@@ -406,7 +450,7 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key,
 
     /* If we found the correct plugin, store it in the cache */
     if (*success)
-        if (H5PL__add_plugin(type, key, handle))
+        if (H5PL__add_plugin(loaded_plugin_type, key, handle))
             HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to add new plugin to plugin cache")
 
 done:
@@ -416,9 +460,8 @@ done:
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5PL__open() */
-H5_GCC_DIAG_ON(pedantic)
+H5_GCC_CLANG_DIAG_ON("pedantic")
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5PL__close
  *
@@ -438,3 +481,27 @@ H5PL__close(H5PL_HANDLE handle)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5PL__close() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5PL_iterate
+ *
+ * Purpose:     Iterates over all the available plugins and calls the
+ *              specified callback function on each plugin.
+ *
+ * Return:      H5_ITER_CONT if all plugins are processed successfully
+ *              H5_ITER_STOP if short-circuit success occurs while
+ *                  processing plugins
+ *              H5_ITER_ERROR if an error occurs while processing plugins
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5PL_iterate(H5PL_iterate_type_t iter_type, H5PL_iterate_t iter_op, void *op_data)
+{
+    herr_t ret_value = H5_ITER_CONT;
+
+    FUNC_ENTER_NOAPI_NOERR
+
+    ret_value = H5PL__path_table_iterate(iter_type, iter_op, op_data);
+
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5PL_iterate() */
