@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -68,7 +67,7 @@
 #define H5D_XFER_BTREE_SPLIT_RATIO_SIZE sizeof(double[3])
 #define H5D_XFER_BTREE_SPLIT_RATIO_DEF                                                                       \
     {                                                                                                        \
-        0.1f, 0.5f, 0.9f                                                                                     \
+        0.1, 0.5, 0.9                                                                                        \
     }
 #define H5D_XFER_BTREE_SPLIT_RATIO_ENC H5P__dxfr_btree_split_ratio_enc
 #define H5D_XFER_BTREE_SPLIT_RATIO_DEC H5P__dxfr_btree_split_ratio_dec
@@ -159,6 +158,16 @@
 #define H5D_XFER_XFORM_COPY  H5P__dxfr_xform_copy
 #define H5D_XFER_XFORM_CMP   H5P__dxfr_xform_cmp
 #define H5D_XFER_XFORM_CLOSE H5P__dxfr_xform_close
+/* Definitions for dataset I/O selection property */
+#define H5D_XFER_DSET_IO_SEL_SIZE  sizeof(H5S_t *)
+#define H5D_XFER_DSET_IO_SEL_DEF   NULL
+#define H5D_XFER_DSET_IO_SEL_COPY  H5P__dxfr_dset_io_hyp_sel_copy
+#define H5D_XFER_DSET_IO_SEL_CMP   H5P__dxfr_dset_io_hyp_sel_cmp
+#define H5D_XFER_DSET_IO_SEL_CLOSE H5P__dxfr_dset_io_hyp_sel_close
+#ifdef QAK
+#define H5D_XFER_DSET_IO_SEL_ENC H5P__dxfr_edc_enc
+#define H5D_XFER_DSET_IO_SEL_DEC H5P__dxfr_edc_dec
+#endif /* QAK */
 
 /******************/
 /* Local Typedefs */
@@ -196,6 +205,9 @@ static herr_t H5P__dxfr_xform_del(hid_t prop_id, const char *name, size_t size,
 static herr_t H5P__dxfr_xform_copy(const char *name, size_t size, void *value);
 static int    H5P__dxfr_xform_cmp(const void *value1, const void *value2, size_t size);
 static herr_t H5P__dxfr_xform_close(const char *name, size_t size, void *value);
+static herr_t H5P__dxfr_dset_io_hyp_sel_copy(const char *name, size_t size, void *value);
+static int    H5P__dxfr_dset_io_hyp_sel_cmp(const void *value1, const void *value2, size_t size);
+static herr_t H5P__dxfr_dset_io_hyp_sel_close(const char *name, size_t size, void *value);
 
 /*********************/
 /* Package Variables */
@@ -233,7 +245,7 @@ static const size_t H5D_def_max_temp_buf_g =
     H5D_XFER_MAX_TEMP_BUF_DEF; /* Default value for maximum temp buffer size */
 static const void *H5D_def_tconv_buf_g =
     H5D_XFER_TCONV_BUF_DEF; /* Default value for type conversion buffer */
-static const void *    H5D_def_bkgr_buf_g = H5D_XFER_BKGR_BUF_DEF; /* Default value for background buffer */
+static const void     *H5D_def_bkgr_buf_g = H5D_XFER_BKGR_BUF_DEF; /* Default value for background buffer */
 static const H5T_bkg_t H5D_def_bkgr_buf_type_g = H5D_XFER_BKGR_BUF_TYPE_DEF;
 static const double    H5D_def_btree_split_ratio_g[3] =
     H5D_XFER_BTREE_SPLIT_RATIO_DEF; /* Default value for B-tree node split ratios */
@@ -262,7 +274,9 @@ static const H5Z_EDC_t H5D_def_enable_edc_g = H5D_XFER_EDC_DEF;       /* Default
 static const H5Z_cb_t  H5D_def_filter_cb_g  = H5D_XFER_FILTER_CB_DEF; /* Default value for filter callback */
 static const H5T_conv_cb_t H5D_def_conv_cb_g =
     H5D_XFER_CONV_CB_DEF; /* Default value for datatype conversion callback */
-static const void *H5D_def_xfer_xform_g = H5D_XFER_XFORM_DEF; /* Default value for data transform */
+static const void  *H5D_def_xfer_xform_g = H5D_XFER_XFORM_DEF; /* Default value for data transform */
+static const H5S_t *H5D_def_dset_io_sel_g =
+    H5D_XFER_DSET_IO_SEL_DEF; /* Default value for dataset I/O selection */
 
 /*-------------------------------------------------------------------------
  * Function:    H5P__dxfr_reg_prop
@@ -280,7 +294,7 @@ H5P__dxfr_reg_prop(H5P_genclass_t *pclass)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Register the max. temp buffer size property */
     if (H5P__register_real(pclass, H5D_XFER_MAX_TEMP_BUF_NAME, H5D_XFER_MAX_TEMP_BUF_SIZE,
@@ -420,6 +434,13 @@ H5P__dxfr_reg_prop(H5P_genclass_t *pclass)
                            H5D_XFER_XFORM_CLOSE) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTINSERT, FAIL, "can't insert property into class")
 
+    /* Register the dataset I/O selection property */
+    if (H5P__register_real(pclass, H5D_XFER_DSET_IO_SEL_NAME, H5D_XFER_DSET_IO_SEL_SIZE,
+                           &H5D_def_dset_io_sel_g, NULL, NULL, NULL, NULL, NULL, NULL,
+                           H5D_XFER_DSET_IO_SEL_COPY, H5D_XFER_DSET_IO_SEL_CMP,
+                           H5D_XFER_DSET_IO_SEL_CLOSE) < 0)
+        HGOTO_ERROR(H5E_PLIST, H5E_CANTINSERT, FAIL, "can't insert property into class")
+
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5P__dxfr_reg_prop() */
@@ -443,9 +464,9 @@ static herr_t
 H5P__dxfr_bkgr_buf_type_enc(const void *value, void **_pp, size_t *size)
 {
     const H5T_bkg_t *bkgr_buf_type = (const H5T_bkg_t *)value; /* Create local alias for values */
-    uint8_t **       pp            = (uint8_t **)_pp;
+    uint8_t        **pp            = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(bkgr_buf_type);
@@ -479,10 +500,10 @@ H5P__dxfr_bkgr_buf_type_enc(const void *value, void **_pp, size_t *size)
 static herr_t
 H5P__dxfr_bkgr_buf_type_dec(const void **_pp, void *_value)
 {
-    H5T_bkg_t *     bkgr_buf_type = (H5T_bkg_t *)_value; /* Background buffer type */
+    H5T_bkg_t      *bkgr_buf_type = (H5T_bkg_t *)_value; /* Background buffer type */
     const uint8_t **pp            = (const uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
     HDassert(pp);
@@ -514,9 +535,9 @@ static herr_t
 H5P__dxfr_btree_split_ratio_enc(const void *value, void **_pp, size_t *size)
 {
     const double *btree_split_ratio = (const double *)value; /* Create local alias for values */
-    uint8_t **    pp                = (uint8_t **)_pp;
+    uint8_t     **pp                = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(btree_split_ratio);
@@ -562,12 +583,12 @@ H5P__dxfr_btree_split_ratio_enc(const void *value, void **_pp, size_t *size)
 static herr_t
 H5P__dxfr_btree_split_ratio_dec(const void **_pp, void *_value)
 {
-    double *        btree_split_ratio = (double *)_value; /* B-tree split ratio */
+    double         *btree_split_ratio = (double *)_value; /* B-tree split ratio */
     unsigned        enc_size;                             /* Size of encoded property */
     const uint8_t **pp        = (const uint8_t **)_pp;
     herr_t          ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
     HDassert(pp);
@@ -607,7 +628,7 @@ H5P__dxfr_xform_set(hid_t H5_ATTR_UNUSED prop_id, const char H5_ATTR_UNUSED *nam
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(value);
@@ -639,7 +660,7 @@ H5P__dxfr_xform_get(hid_t H5_ATTR_UNUSED prop_id, const char H5_ATTR_UNUSED *nam
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(value);
@@ -674,10 +695,10 @@ H5P__dxfr_xform_enc(const void *value, void **_pp, size_t *size)
         *(const H5Z_data_xform_t *const *)value; /* Create local alias for values */
     const char *pexp      = NULL;                /* Pointer to transform expression */
     size_t      len       = 0;                   /* Length of transform expression */
-    uint8_t **  pp        = (uint8_t **)_pp;
+    uint8_t   **pp        = (uint8_t **)_pp;
     herr_t      ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDcompile_assert(sizeof(size_t) <= sizeof(uint64_t));
@@ -744,12 +765,12 @@ H5P__dxfr_xform_dec(const void **_pp, void *_value)
 {
     H5Z_data_xform_t **data_xform_prop = (H5Z_data_xform_t **)_value; /* New data xform property */
     size_t             len;                                           /* Length of encoded string */
-    const uint8_t **   pp = (const uint8_t **)_pp;
+    const uint8_t    **pp = (const uint8_t **)_pp;
     unsigned           enc_size;
     uint64_t           enc_value;
     herr_t             ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
     HDassert(pp);
@@ -794,7 +815,7 @@ H5P__dxfr_xform_del(hid_t H5_ATTR_UNUSED prop_id, const char H5_ATTR_UNUSED *nam
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     HDassert(value);
 
@@ -824,7 +845,7 @@ H5P__dxfr_xform_copy(const char H5_ATTR_UNUSED *name, size_t H5_ATTR_UNUSED size
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(value);
@@ -860,7 +881,7 @@ H5P__dxfr_xform_cmp(const void *_xform1, const void *_xform2, size_t H5_ATTR_UNU
     const char *pexp1, *pexp2;                    /* Pointers to transform expressions */
     herr_t      ret_value = 0;                    /* Return value */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(xform1);
@@ -894,7 +915,7 @@ H5P__dxfr_xform_cmp(const void *_xform1, const void *_xform2, size_t H5_ATTR_UNU
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5P__dxfr_xform_copy() */
+} /* end H5P__dxfr_xform_cmp() */
 
 /*-------------------------------------------------------------------------
  * Function: H5P__dxfr_xform_close
@@ -914,7 +935,7 @@ H5P__dxfr_xform_close(const char H5_ATTR_UNUSED *name, size_t H5_ATTR_UNUSED siz
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     HDassert(value);
 
@@ -940,7 +961,7 @@ done:
 herr_t
 H5Pset_data_transform(hid_t plist_id, const char *expression)
 {
-    H5P_genplist_t *  plist;                     /* Property list pointer */
+    H5P_genplist_t   *plist;                     /* Property list pointer */
     H5Z_data_xform_t *data_xform_prop = NULL;    /* New data xform property */
     herr_t            ret_value       = SUCCEED; /* return value */
 
@@ -953,7 +974,7 @@ H5Pset_data_transform(hid_t plist_id, const char *expression)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* See if a data transform is already set, and free it if it is */
     if (H5P_peek(plist, H5D_XFER_XFORM_NAME, &data_xform_prop) < 0)
@@ -965,7 +986,7 @@ H5Pset_data_transform(hid_t plist_id, const char *expression)
 
     /* Create data transform info from expression */
     if (NULL == (data_xform_prop = H5Z_xform_create(expression)))
-        HGOTO_ERROR(H5E_PLINE, H5E_NOSPACE, FAIL, "unable to create data transform info")
+        HGOTO_ERROR(H5E_PLIST, H5E_NOSPACE, FAIL, "unable to create data transform info")
 
     /* Update property list (takes ownership of transform) */
     if (H5P_poke(plist, H5D_XFER_XFORM_NAME, &data_xform_prop) < 0)
@@ -974,7 +995,7 @@ H5Pset_data_transform(hid_t plist_id, const char *expression)
 done:
     if (ret_value < 0)
         if (data_xform_prop && H5Z_xform_destroy(data_xform_prop) < 0)
-            HDONE_ERROR(H5E_PLINE, H5E_CLOSEERROR, FAIL, "unable to release data transform expression")
+            HDONE_ERROR(H5E_PLIST, H5E_CLOSEERROR, FAIL, "unable to release data transform expression")
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pset_data_transform() */
@@ -1004,10 +1025,10 @@ done:
 ssize_t
 H5Pget_data_transform(hid_t plist_id, char *expression /*out*/, size_t size)
 {
-    H5P_genplist_t *  plist;                  /* Property list pointer */
+    H5P_genplist_t   *plist;                  /* Property list pointer */
     H5Z_data_xform_t *data_xform_prop = NULL; /* New data xform property */
     size_t            len;
-    const char *      pexp;
+    const char       *pexp;
     ssize_t           ret_value; /* return value */
 
     FUNC_ENTER_API(FAIL)
@@ -1015,7 +1036,7 @@ H5Pget_data_transform(hid_t plist_id, char *expression /*out*/, size_t size)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     if (H5P_peek(plist, H5D_XFER_XFORM_NAME, &data_xform_prop) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "error getting data transform expression")
@@ -1077,7 +1098,7 @@ H5Pset_buffer(hid_t plist_id, size_t size, void *tconv, void *bkg)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Update property list */
     if (H5P_set(plist, H5D_XFER_MAX_TEMP_BUF_NAME, &size) < 0)
@@ -1117,7 +1138,7 @@ H5Pget_buffer(hid_t plist_id, void **tconv /*out*/, void **bkg /*out*/)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, 0, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, 0, "can't find object for ID")
 
     /* Return values */
     if (tconv)
@@ -1166,7 +1187,7 @@ H5Pset_preserve(hid_t plist_id, hbool_t status)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Update property list */
     need_bkg = status ? H5T_BKG_YES : H5T_BKG_NO;
@@ -1203,7 +1224,7 @@ H5Pget_preserve(hid_t plist_id)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Get value */
     if (H5P_get(plist, H5D_XFER_BKGR_BUF_TYPE_NAME, &need_bkg) < 0)
@@ -1246,7 +1267,7 @@ H5Pset_edc_check(hid_t plist_id, H5Z_EDC_t check)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Update property list */
     if (H5P_set(plist, H5D_XFER_EDC_NAME, &check) < 0)
@@ -1282,7 +1303,7 @@ H5Pget_edc_check(hid_t plist_id)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, H5Z_ERROR_EDC, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, H5Z_ERROR_EDC, "can't find object for ID")
 
     /* Update property list */
     if (H5P_get(plist, H5D_XFER_EDC_NAME, &ret_value) < 0)
@@ -1314,11 +1335,11 @@ H5Pset_filter_callback(hid_t plist_id, H5Z_filter_func_t func, void *op_data)
     H5Z_cb_t        cb_struct;
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE3("e", "ix*x", plist_id, func, op_data);
+    H5TRACE3("e", "iZF*x", plist_id, func, op_data);
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Update property list */
     cb_struct.func    = func;
@@ -1353,11 +1374,11 @@ H5Pset_type_conv_cb(hid_t plist_id, H5T_conv_except_func_t op, void *operate_dat
     H5T_conv_cb_t   cb_struct;
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE3("e", "ix*x", plist_id, op, operate_data);
+    H5TRACE3("e", "iTE*x", plist_id, op, operate_data);
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Update property list */
     cb_struct.func      = op;
@@ -1385,18 +1406,18 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Pget_type_conv_cb(hid_t plist_id, H5T_conv_except_func_t *op, void **operate_data)
+H5Pget_type_conv_cb(hid_t plist_id, H5T_conv_except_func_t *op /*out*/, void **operate_data /*out*/)
 {
     H5P_genplist_t *plist; /* Property list pointer */
     H5T_conv_cb_t   cb_struct;
     herr_t          ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE3("e", "i*x**x", plist_id, op, operate_data);
+    H5TRACE3("e", "ixx", plist_id, op, operate_data);
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Get property */
     if (H5P_get(plist, H5D_XFER_CONV_CB_NAME, &cb_struct) < 0)
@@ -1437,7 +1458,7 @@ H5Pget_btree_ratios(hid_t plist_id, double *left /*out*/, double *middle /*out*/
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Get the split ratios */
     if (H5P_get(plist, H5D_XFER_BTREE_SPLIT_RATIO_NAME, &btree_split_ratio) < 0)
@@ -1491,7 +1512,7 @@ H5Pset_btree_ratios(hid_t plist_id, double left, double middle, double right)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Set values */
     split_ratio[0] = left;
@@ -1576,7 +1597,7 @@ H5Pset_vlen_mem_manager(hid_t plist_id, H5MM_allocate_t alloc_func, void *alloc_
     herr_t          ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE5("e", "ix*xx*x", plist_id, alloc_func, alloc_info, free_func, free_info);
+    H5TRACE5("e", "iMa*xMf*x", plist_id, alloc_func, alloc_info, free_func, free_info);
 
     /* Check arguments */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
@@ -1614,7 +1635,7 @@ H5Pget_vlen_mem_manager(hid_t plist_id, H5MM_allocate_t *alloc_func /*out*/, voi
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     if (alloc_func)
         if (H5P_get(plist, H5D_XFER_VLEN_ALLOC_NAME, alloc_func) < 0)
@@ -1669,7 +1690,7 @@ H5Pset_hyper_vector_size(hid_t plist_id, size_t vector_size)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Update property list */
     if (H5P_set(plist, H5D_XFER_HYPER_VECTOR_SIZE_NAME, &vector_size) < 0)
@@ -1702,7 +1723,7 @@ H5Pget_hyper_vector_size(hid_t plist_id, size_t *vector_size /*out*/)
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Return values */
     if (vector_size)
@@ -1732,9 +1753,9 @@ static herr_t
 H5P__dxfr_io_xfer_mode_enc(const void *value, void **_pp, size_t *size)
 {
     const H5FD_mpio_xfer_t *xfer_mode = (const H5FD_mpio_xfer_t *)value; /* Create local alias for values */
-    uint8_t **              pp        = (uint8_t **)_pp;
+    uint8_t               **pp        = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(xfer_mode);
@@ -1769,9 +1790,9 @@ static herr_t
 H5P__dxfr_io_xfer_mode_dec(const void **_pp, void *_value)
 {
     H5FD_mpio_xfer_t *xfer_mode = (H5FD_mpio_xfer_t *)_value; /* I/O transfer mode */
-    const uint8_t **  pp        = (const uint8_t **)_pp;
+    const uint8_t   **pp        = (const uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
     HDassert(pp);
@@ -1806,7 +1827,7 @@ H5P__dxfr_mpio_collective_opt_enc(const void *value, void **_pp, size_t *size)
         (const H5FD_mpio_collective_opt_t *)value; /* Create local alias for values */
     uint8_t **pp = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(coll_opt);
@@ -1844,7 +1865,7 @@ H5P__dxfr_mpio_collective_opt_dec(const void **_pp, void *_value)
         (H5FD_mpio_collective_opt_t *)_value; /* MPI-I/O collective optimization mode */
     const uint8_t **pp = (const uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
     HDassert(pp);
@@ -1879,7 +1900,7 @@ H5P__dxfr_mpio_chunk_opt_hard_enc(const void *value, void **_pp, size_t *size)
         (const H5FD_mpio_chunk_opt_t *)value; /* Create local alias for values */
     uint8_t **pp = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(chunk_opt);
@@ -1914,9 +1935,9 @@ static herr_t
 H5P__dxfr_mpio_chunk_opt_hard_dec(const void **_pp, void *_value)
 {
     H5FD_mpio_chunk_opt_t *chunk_opt = (H5FD_mpio_chunk_opt_t *)_value; /* MPI-I/O chunk optimization mode */
-    const uint8_t **       pp        = (const uint8_t **)_pp;
+    const uint8_t        **pp        = (const uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
     HDassert(pp);
@@ -1944,17 +1965,18 @@ H5P__dxfr_mpio_chunk_opt_hard_dec(const void **_pp, void *_value)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Pget_mpio_actual_chunk_opt_mode(hid_t plist_id, H5D_mpio_actual_chunk_opt_mode_t *actual_chunk_opt_mode)
+H5Pget_mpio_actual_chunk_opt_mode(hid_t                             plist_id,
+                                  H5D_mpio_actual_chunk_opt_mode_t *actual_chunk_opt_mode /*out*/)
 {
     H5P_genplist_t *plist;
     herr_t          ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "i*Do", plist_id, actual_chunk_opt_mode);
+    H5TRACE2("e", "ix", plist_id, actual_chunk_opt_mode);
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Return values */
     if (actual_chunk_opt_mode)
@@ -1979,17 +2001,17 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Pget_mpio_actual_io_mode(hid_t plist_id, H5D_mpio_actual_io_mode_t *actual_io_mode)
+H5Pget_mpio_actual_io_mode(hid_t plist_id, H5D_mpio_actual_io_mode_t *actual_io_mode /*out*/)
 {
     H5P_genplist_t *plist;
     herr_t          ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "i*Di", plist_id, actual_io_mode);
+    H5TRACE2("e", "ix", plist_id, actual_io_mode);
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Return values */
     if (actual_io_mode)
@@ -2012,18 +2034,18 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Pget_mpio_no_collective_cause(hid_t plist_id, uint32_t *local_no_collective_cause,
-                                uint32_t *global_no_collective_cause)
+H5Pget_mpio_no_collective_cause(hid_t plist_id, uint32_t *local_no_collective_cause /*out*/,
+                                uint32_t *global_no_collective_cause /*out*/)
 {
     H5P_genplist_t *plist;
     herr_t          ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE3("e", "i*Iu*Iu", plist_id, local_no_collective_cause, global_no_collective_cause);
+    H5TRACE3("e", "ixx", plist_id, local_no_collective_cause, global_no_collective_cause);
 
     /* Get the plist structure */
     if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Return values */
     if (local_no_collective_cause)
@@ -2057,9 +2079,9 @@ static herr_t
 H5P__dxfr_edc_enc(const void *value, void **_pp, size_t *size)
 {
     const H5Z_EDC_t *check = (const H5Z_EDC_t *)value; /* Create local alias for values */
-    uint8_t **       pp    = (uint8_t **)_pp;
+    uint8_t        **pp    = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(check);
@@ -2093,10 +2115,10 @@ H5P__dxfr_edc_enc(const void *value, void **_pp, size_t *size)
 static herr_t
 H5P__dxfr_edc_dec(const void **_pp, void *_value)
 {
-    H5Z_EDC_t *     check = (H5Z_EDC_t *)_value; /* EDC property */
+    H5Z_EDC_t      *check = (H5Z_EDC_t *)_value; /* EDC property */
     const uint8_t **pp    = (const uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
     HDassert(pp);
@@ -2108,3 +2130,259 @@ H5P__dxfr_edc_dec(const void **_pp, void *_value)
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5P__dxfr_edc_dec() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5P__dxfr_dset_io_hyp_sel_copy
+ *
+ * Purpose:     Creates a copy of the dataset I/O selection.
+ *
+ * Return:	Non-negative on success/Negative on failure
+ *
+ * Programmer:	Quincey Koziol
+ *              Sunday, January 31, 2021
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5P__dxfr_dset_io_hyp_sel_copy(const char H5_ATTR_UNUSED *name, size_t H5_ATTR_UNUSED size, void *value)
+{
+    H5S_t *orig_space = *(H5S_t **)value; /* Original dataspace for property */
+    H5S_t *new_space  = NULL;             /* New dataspace for property */
+    herr_t ret_value  = SUCCEED;          /* Return value */
+
+    FUNC_ENTER_PACKAGE
+
+    /* If there's a dataspace I/O selection set, copy it */
+    if (orig_space) {
+        /* Make copy of dataspace */
+        if (NULL == (new_space = H5S_copy(orig_space, FALSE, TRUE)))
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTCOPY, FAIL, "error copying the dataset I/O selection")
+
+        /* Set new value for property */
+        *(void **)value = new_space;
+    } /* end if */
+
+done:
+    /* Cleanup on error */
+    if (ret_value < 0)
+        if (new_space && H5S_close(new_space) < 0)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTCLOSEOBJ, FAIL, "error closing dataset I/O selection dataspace")
+
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5P__dxfr_dset_io_hyp_sel_copy() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5P__dxfr_dset_io_hyp_sel_cmp
+ *
+ * Purpose:     Compare two dataset I/O selections.
+ *
+ * Return:      positive if VALUE1 is greater than VALUE2, negative if VALUE2 is
+ *		greater than VALUE1 and zero if VALUE1 and VALUE2 are equal.
+ *
+ * Programmer:	Quincey Koziol
+ *              Sunday, January 31, 2021
+ *
+ *-------------------------------------------------------------------------
+ */
+static int
+H5P__dxfr_dset_io_hyp_sel_cmp(const void *_space1, const void *_space2, size_t H5_ATTR_UNUSED size)
+{
+    const H5S_t *const *space1    = (const H5S_t *const *)_space1; /* Create local aliases for values */
+    const H5S_t *const *space2    = (const H5S_t *const *)_space2; /* Create local aliases for values */
+    herr_t              ret_value = 0;                             /* Return value */
+
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* Sanity check */
+    HDassert(space1);
+    HDassert(space1);
+    HDassert(size == sizeof(H5S_t *));
+
+    /* Check for a property being set */
+    if (*space1 == NULL && *space2 != NULL)
+        HGOTO_DONE(-1);
+    if (*space1 != NULL && *space2 == NULL)
+        HGOTO_DONE(1);
+
+    if (*space1) {
+        HDassert(*space2);
+
+        /* Compare the extents of the dataspaces */
+        /* (Error & not-equal count the same) */
+        if (TRUE != H5S_extent_equal(*space1, *space2))
+            HGOTO_DONE(-1);
+
+        /* Compare the selection "shape" of the dataspaces
+         * (Error & not-equal count the same)
+         *
+         * Since H5S_select_shape_same() can result in the dataspaces being
+         * rebuilt, the parameters are not const which makes it impossible
+         * to match the cmp prototype. Since we need to compare them,
+         * we quiet the const warning.
+         */
+        H5_GCC_CLANG_DIAG_OFF("cast-qual")
+        if (TRUE != H5S_select_shape_same((H5S_t *)*space1, (H5S_t *)*space2))
+            HGOTO_DONE(-1);
+        H5_GCC_CLANG_DIAG_ON("cast-qual")
+    } /* end if */
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5P__dxfr_dset_io_hyp_sel_cmp() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5P__dxfr_dset_io_hyp_sel_close
+ *
+ * Purpose:     Frees resources for dataset I/O selection
+ *
+ * Return:	Non-negative on success/Negative on failure
+ *
+ * Programmer:	Quincey Koziol
+ *              Sunday, January 31, 2021
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5P__dxfr_dset_io_hyp_sel_close(const char H5_ATTR_UNUSED *name, size_t H5_ATTR_UNUSED size, void *_value)
+{
+    H5S_t *space     = *(H5S_t **)_value; /* Dataspace for property */
+    herr_t ret_value = SUCCEED;           /* Return value */
+
+    FUNC_ENTER_PACKAGE
+
+    /* Release any dataspace */
+    if (space && H5S_close(space) < 0)
+        HGOTO_ERROR(H5E_PLIST, H5E_CANTCLOSEOBJ, FAIL, "error closing dataset I/O selection dataspace")
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5P__dxfr_dset_io_hyp_sel_close() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5Pset_dataset_io_hyperslab_selection
+ *
+ * Purpose:	H5Pset_dataset_io_hyperslab_selection() is designed to be used
+ *              in conjunction with using H5S_PLIST for the file dataspace
+ *              ID when making a call to H5Dread() or H5Dwrite().  When used
+ *              with H5S_PLIST, the selection created by one or more calls to
+ *              this routine is used for determining which dataset elements to
+ *              access.
+ *
+ *              'rank' is the dimensionality of the selection and determines
+ *              the size of the 'start', 'stride', 'count', and 'block' arrays.
+ *              'rank' must be between 1 and H5S_MAX_RANK, inclusive.
+ *
+ *              The 'op', 'start', 'stride', 'count', and 'block' parameters
+ *              behave identically to their behavior for H5Sselect_hyperslab(),
+ *              please see the documentation for that routine for details about
+ *              their use.
+ *
+ * Return:	Non-negative on success/Negative on failure
+ *
+ * Programmer:	Quincey Koziol
+ *              Saturday, January 30, 2021
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5Pset_dataset_io_hyperslab_selection(hid_t plist_id, unsigned rank, H5S_seloper_t op, const hsize_t start[],
+                                      const hsize_t stride[], const hsize_t count[], const hsize_t block[])
+{
+    H5P_genplist_t *plist = NULL;                  /* Property list pointer */
+    H5S_t          *space;                         /* Dataspace to hold selection */
+    hbool_t         space_created       = FALSE;   /* Whether a new dataspace has been created */
+    hbool_t         reset_prop_on_error = FALSE;   /* Whether to reset the property on failure */
+    herr_t          ret_value           = SUCCEED; /* return value */
+
+    FUNC_ENTER_API(FAIL)
+    H5TRACE7("e", "iIuSs*h*h*h*h", plist_id, rank, op, start, stride, count, block);
+
+    /* Check arguments */
+    if (rank < 1 || rank > H5S_MAX_RANK)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid rank value: %u", rank)
+    if (!(op > H5S_SELECT_NOOP && op < H5S_SELECT_INVALID))
+        HGOTO_ERROR(H5E_ARGS, H5E_UNSUPPORTED, FAIL, "invalid selection operation")
+    if (start == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "'count' pointer is NULL")
+    if (stride != NULL) {
+        unsigned u; /* Local index variable */
+
+        /* Check for 0-sized strides */
+        for (u = 0; u < rank; u++)
+            if (stride[u] == 0)
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid value - stride[%u]==0", u)
+    } /* end if */
+    if (count == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "'start' pointer is NULL")
+    /* block is allowed to be NULL, and will be assumed to be all '1's when NULL */
+
+    /* Get the plist structure */
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_DATASET_XFER)))
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
+
+    /* See if a dataset I/O selection is already set, and free it if it is */
+    if (H5P_peek(plist, H5D_XFER_DSET_IO_SEL_NAME, &space) < 0)
+        HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "error getting dataset I/O selection")
+
+    /* Check for operation on existing dataspace selection */
+    if (NULL != space) {
+        int sndims; /* Rank of existing dataspace */
+
+        /* Get dimensions from current dataspace for selection */
+        if ((sndims = H5S_GET_EXTENT_NDIMS(space)) < 0)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get selection's dataspace rank")
+
+        /* Check for different # of dimensions */
+        if ((unsigned)sndims != rank) {
+            /* Set up new dataspace for 'set' operation, otherwise fail */
+            if (op == H5S_SELECT_SET) {
+                /* Close previous dataspace */
+                if (H5S_close(space) < 0)
+                    HGOTO_ERROR(H5E_PLIST, H5E_CLOSEERROR, FAIL, "unable to release dataspace")
+
+                /* Reset 'space' pointer, so it's re-created */
+                space = NULL;
+
+                /* Set flag to reset property list on error */
+                reset_prop_on_error = TRUE;
+            } /* end if */
+            else
+                HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "different rank for previous and new selections")
+        } /* end if */
+    }     /* end if */
+
+    /* Check for first time called */
+    if (NULL == space) {
+        hsize_t  dims[H5S_MAX_RANK]; /* Dimensions for new dataspace */
+        unsigned u;                  /* Local index variable */
+
+        /* Initialize dimensions to largest possible actual size */
+        for (u = 0; u < rank; u++)
+            dims[u] = (H5S_UNLIMITED - 1);
+
+        /* Create dataspace of the correct dimensionality, with maximum dimensions */
+        if (NULL == (space = H5S_create_simple(rank, dims, NULL)))
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTCREATE, FAIL, "unable to create dataspace for selection")
+        space_created = TRUE;
+    } /* end if */
+
+    /* Set selection for dataspace */
+    if (H5S_select_hyperslab(space, op, start, stride, count, block) < 0)
+        HGOTO_ERROR(H5E_PLIST, H5E_CANTSELECT, FAIL, "can't create selection")
+
+    /* Update property list (takes ownership of dataspace, if new) */
+    if (H5P_poke(plist, H5D_XFER_DSET_IO_SEL_NAME, &space) < 0)
+        HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "error setting dataset I/O selection")
+    space_created = FALSE; /* Reset now that property owns the dataspace */
+
+done:
+    /* Cleanup on failure */
+    if (ret_value < 0) {
+        if (reset_prop_on_error && plist && H5P_poke(plist, H5D_XFER_DSET_IO_SEL_NAME, &space) < 0)
+            HDONE_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "error setting dataset I/O selection")
+        if (space_created && H5S_close(space) < 0)
+            HDONE_ERROR(H5E_PLIST, H5E_CLOSEERROR, FAIL, "unable to release dataspace")
+    } /* end if */
+
+    FUNC_LEAVE_API(ret_value)
+} /* end H5Pset_dataset_io_hyperslab_selection() */
