@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -15,7 +14,7 @@
  *
  * Created:		H5Pstrcpl.c
  *			October 26 2005
- *			James Laird <jlaird@ncsa.uiuc.edu>
+ *			James Laird
  *
  * Purpose:		String creation property list class routines
  *
@@ -26,18 +25,16 @@
 /* Module Setup */
 /****************/
 
-#include "H5Pmodule.h"          /* This source code file is part of the H5P module */
-
+#include "H5Pmodule.h" /* This source code file is part of the H5P module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5Fprivate.h"		/* Files */
-#include "H5Iprivate.h"		/* IDs			  		*/
-#include "H5Ppkg.h"		/* Property lists		  	*/
-
+#include "H5private.h"  /* Generic Functions			*/
+#include "H5Eprivate.h" /* Error handling		  	*/
+#include "H5Fprivate.h" /* Files */
+#include "H5Iprivate.h" /* IDs			  		*/
+#include "H5Ppkg.h"     /* Property lists		  	*/
 
 /****************/
 /* Local Macros */
@@ -45,22 +42,19 @@
 
 /* ========  String creation properties ======== */
 /* Definitions for character set encoding property */
-#define H5P_STRCRT_CHAR_ENCODING_SIZE  sizeof(H5T_cset_t)
-#define H5P_STRCRT_CHAR_ENCODING_DEF   H5F_DEFAULT_CSET
-#define H5P_STRCRT_CHAR_ENCODING_ENC   H5P__strcrt_char_encoding_enc
-#define H5P_STRCRT_CHAR_ENCODING_DEC   H5P__strcrt_char_encoding_dec
-
+#define H5P_STRCRT_CHAR_ENCODING_SIZE sizeof(H5T_cset_t)
+#define H5P_STRCRT_CHAR_ENCODING_DEF  H5F_DEFAULT_CSET
+#define H5P_STRCRT_CHAR_ENCODING_ENC  H5P__strcrt_char_encoding_enc
+#define H5P_STRCRT_CHAR_ENCODING_DEC  H5P__strcrt_char_encoding_dec
 
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
@@ -72,45 +66,41 @@ static herr_t H5P__strcrt_reg_prop(H5P_genclass_t *pclass);
 static herr_t H5P__strcrt_char_encoding_enc(const void *value, void **_pp, size_t *size);
 static herr_t H5P__strcrt_char_encoding_dec(const void **_pp, void *value);
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
 /* String creation property list class library initialization object */
 const H5P_libclass_t H5P_CLS_STRCRT[1] = {{
-    "string create",		/* Class name for debugging     */
-    H5P_TYPE_STRING_CREATE,     /* Class type                   */
+    "string create",        /* Class name for debugging     */
+    H5P_TYPE_STRING_CREATE, /* Class type                   */
 
-    &H5P_CLS_ROOT_g,		/* Parent class                 */
-    &H5P_CLS_STRING_CREATE_g,	/* Pointer to class             */
-    &H5P_CLS_STRING_CREATE_ID_g,	/* Pointer to class ID          */
-    NULL,			/* Pointer to default property list ID */
-    H5P__strcrt_reg_prop,	/* Default property registration routine */
+    &H5P_CLS_ROOT_g,             /* Parent class                 */
+    &H5P_CLS_STRING_CREATE_g,    /* Pointer to class             */
+    &H5P_CLS_STRING_CREATE_ID_g, /* Pointer to class ID          */
+    NULL,                        /* Pointer to default property list ID */
+    H5P__strcrt_reg_prop,        /* Default property registration routine */
 
-    NULL,		        /* Class creation callback      */
-    NULL,		        /* Class creation callback info */
-    NULL,			/* Class copy callback          */
-    NULL,		        /* Class copy callback info     */
-    NULL,			/* Class close callback         */
-    NULL 		        /* Class close callback info    */
+    NULL, /* Class creation callback      */
+    NULL, /* Class creation callback info */
+    NULL, /* Class copy callback          */
+    NULL, /* Class copy callback info     */
+    NULL, /* Class close callback         */
+    NULL  /* Class close callback info    */
 }};
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
 /* Property value defaults */
-static const H5T_cset_t H5P_def_char_encoding_g = H5P_STRCRT_CHAR_ENCODING_DEF;  /* Default character set encoding */
+static const H5T_cset_t H5P_def_char_encoding_g =
+    H5P_STRCRT_CHAR_ENCODING_DEF; /* Default character set encoding */
 
-
-
 /*-------------------------------------------------------------------------
  * Function:    H5P__strcrt_reg_prop
  *
@@ -125,21 +115,20 @@ static const H5T_cset_t H5P_def_char_encoding_g = H5P_STRCRT_CHAR_ENCODING_DEF;
 static herr_t
 H5P__strcrt_reg_prop(H5P_genclass_t *pclass)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Register character encoding */
-    if(H5P__register_real(pclass, H5P_STRCRT_CHAR_ENCODING_NAME, H5P_STRCRT_CHAR_ENCODING_SIZE, &H5P_def_char_encoding_g, 
-            NULL, NULL, NULL, H5P_STRCRT_CHAR_ENCODING_ENC, H5P_STRCRT_CHAR_ENCODING_DEC,
-            NULL, NULL, NULL, NULL) < 0)
+    if (H5P__register_real(pclass, H5P_STRCRT_CHAR_ENCODING_NAME, H5P_STRCRT_CHAR_ENCODING_SIZE,
+                           &H5P_def_char_encoding_g, NULL, NULL, NULL, H5P_STRCRT_CHAR_ENCODING_ENC,
+                           H5P_STRCRT_CHAR_ENCODING_DEC, NULL, NULL, NULL, NULL) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTINSERT, FAIL, "can't insert property into class")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5P__strcrt_reg_prop() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pset_char_encoding
  *
@@ -154,8 +143,8 @@ done:
 herr_t
 H5Pset_char_encoding(hid_t plist_id, H5T_cset_t encoding)
 {
-    H5P_genplist_t *plist;      /* Property list pointer */
-    herr_t ret_value = SUCCEED;   /* return value */
+    H5P_genplist_t *plist;               /* Property list pointer */
+    herr_t          ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "iTc", plist_id, encoding);
@@ -165,18 +154,17 @@ H5Pset_char_encoding(hid_t plist_id, H5T_cset_t encoding)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "character encoding is not valid")
 
     /* Get the plist structure */
-    if(NULL == (plist = H5P_object_verify(plist_id, H5P_STRING_CREATE)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_STRING_CREATE)))
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Set the character encoding */
-    if(H5P_set(plist, H5P_STRCRT_CHAR_ENCODING_NAME, &encoding) < 0)
+    if (H5P_set(plist, H5P_STRCRT_CHAR_ENCODING_NAME, &encoding) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "can't set character encoding")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5P_set_char_encoding() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pget_char_encoding
  *
@@ -191,26 +179,25 @@ done:
 herr_t
 H5Pget_char_encoding(hid_t plist_id, H5T_cset_t *encoding /*out*/)
 {
-    H5P_genplist_t *plist;      /* Property list pointer */
-    herr_t ret_value = SUCCEED; /* return value */
+    H5P_genplist_t *plist;               /* Property list pointer */
+    herr_t          ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "ix", plist_id, encoding);
 
     /* Get the plist structure */
-    if(NULL == (plist = H5P_object_verify(plist_id, H5P_STRING_CREATE)))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_STRING_CREATE)))
+        HGOTO_ERROR(H5E_ID, H5E_BADID, FAIL, "can't find object for ID")
 
     /* Get value */
-    if(encoding)
-        if(H5P_get(plist, H5P_STRCRT_CHAR_ENCODING_NAME, encoding) < 0)
+    if (encoding)
+        if (H5P_get(plist, H5P_STRCRT_CHAR_ENCODING_NAME, encoding) < 0)
             HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get character encoding flag")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pget_char_encoding() */
 
-
 /*-------------------------------------------------------------------------
  * Function:       H5P__strcrt_char_encoding_enc
  *
@@ -230,15 +217,15 @@ static herr_t
 H5P__strcrt_char_encoding_enc(const void *value, void **_pp, size_t *size)
 {
     const H5T_cset_t *encoding = (const H5T_cset_t *)value; /* Create local alias for values */
-    uint8_t **pp = (uint8_t **)_pp;
+    uint8_t         **pp       = (uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(encoding);
     HDassert(size);
 
-    if(NULL != *pp)
+    if (NULL != *pp)
         /* Encode character set encoding */
         *(*pp)++ = (uint8_t)*encoding;
 
@@ -248,7 +235,6 @@ H5P__strcrt_char_encoding_enc(const void *value, void **_pp, size_t *size)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5P__strcrt_char_encoding_enc() */
 
-
 /*-------------------------------------------------------------------------
  * Function:       H5P__strcrt_char_encoding_dec
  *
@@ -267,10 +253,10 @@ H5P__strcrt_char_encoding_enc(const void *value, void **_pp, size_t *size)
 static herr_t
 H5P__strcrt_char_encoding_dec(const void **_pp, void *_value)
 {
-    H5T_cset_t *encoding = (H5T_cset_t *)_value;            /* Character set encoding */
-    const uint8_t **pp = (const uint8_t **)_pp;
+    H5T_cset_t     *encoding = (H5T_cset_t *)_value; /* Character set encoding */
+    const uint8_t **pp       = (const uint8_t **)_pp;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
     HDassert(pp);
@@ -278,8 +264,7 @@ H5P__strcrt_char_encoding_dec(const void **_pp, void *_value)
     HDassert(encoding);
 
     /* Decode character set encoding */
-    *encoding = (H5T_cset_t)*(*pp)++;
+    *encoding = (H5T_cset_t) * (*pp)++;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5P__strcrt_char_encoding_dec() */
-
