@@ -151,45 +151,6 @@ typedef enum H5T_pad_t {
 } H5T_pad_t;
 //! <!-- [H5T_pad_t_snip] -->
 
-/**
- * Commands sent to conversion functions
- */
-typedef enum H5T_cmd_t {
-    H5T_CONV_INIT = 0, /**< query and/or initialize private data	     */
-    H5T_CONV_CONV = 1, /**< convert data from source to dest datatype */
-    H5T_CONV_FREE = 2  /**< function is being removed from path	     */
-} H5T_cmd_t;
-
-/**
- * How is the `bkg' buffer used by the conversion function?
- */
-typedef enum H5T_bkg_t {
-    H5T_BKG_NO   = 0, /**< background buffer is not needed, send NULL */
-    H5T_BKG_TEMP = 1, /**< bkg buffer used as temp storage only       */
-    H5T_BKG_YES  = 2  /**< init bkg buf with data before conversion   */
-} H5T_bkg_t;
-
-/**
- * Type conversion client data
- */
-//! <!-- [H5T_cdata_t_snip] -->
-typedef struct H5T_cdata_t {
-    H5T_cmd_t command;  /**< what should the conversion function do?    */
-    H5T_bkg_t need_bkg; /**< is the background buffer needed?	     */
-    hbool_t   recalc;   /**< recalculate private data		     */
-    void     *priv;     /**< private data				     */
-} H5T_cdata_t;
-//! <!-- [H5T_cdata_t_snip] -->
-
-/**
- * Conversion function persistence
- */
-typedef enum H5T_pers_t {
-    H5T_PERS_DONTCARE = -1, /**< wild card				     */
-    H5T_PERS_HARD     = 0,  /**< hard conversion function		     */
-    H5T_PERS_SOFT     = 1   /**< soft conversion function		     */
-} H5T_pers_t;
-
 /**
  * The order to retrieve atomic native datatype
  */
@@ -244,7 +205,7 @@ typedef struct {
  * Indicate that a string is variable length (null-terminated in C, instead of
  * fixed length)
  */
-#define H5T_VARIABLE ((size_t)(-1))
+#define H5T_VARIABLE SIZE_MAX
 
 /* Opaque information */
 /**
@@ -257,14 +218,6 @@ typedef struct {
 extern "C" {
 #endif
 
-/**
- * All datatype conversion functions are...
- */
-//! <!-- [H5T_conv_t_snip] -->
-typedef herr_t (*H5T_conv_t)(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, size_t nelmts, size_t buf_stride,
-                             size_t bkg_stride, void *buf, void *bkg, hid_t dset_xfer_plist);
-//! <!-- [H5T_conv_t_snip] -->
-
 //! <!-- [H5T_conv_except_func_t_snip] -->
 /**
  * \brief Exception handler.
@@ -456,6 +409,11 @@ H5_DLLVAR hid_t H5T_IEEE_F64LE_g;
  * Dataset region reference
  */
 #define H5T_STD_REF_DSETREG (H5OPEN H5T_STD_REF_DSETREG_g)
+/**
+ * \ingroup PDTSTD
+ * Generic reference
+ */
+#define H5T_STD_REF (H5OPEN H5T_STD_REF_g)
 H5_DLLVAR hid_t H5T_STD_I8BE_g;
 H5_DLLVAR hid_t H5T_STD_I8LE_g;
 H5_DLLVAR hid_t H5T_STD_I16BE_g;
@@ -482,6 +440,7 @@ H5_DLLVAR hid_t H5T_STD_B64BE_g;
 H5_DLLVAR hid_t H5T_STD_B64LE_g;
 H5_DLLVAR hid_t H5T_STD_REF_OBJ_g;
 H5_DLLVAR hid_t H5T_STD_REF_DSETREG_g;
+H5_DLLVAR hid_t H5T_STD_REF_g;
 
 /*
  * Types which are particular to Unix.
@@ -843,13 +802,11 @@ H5_DLLVAR hid_t H5T_VAX_F64_g;
  * C-style \Code{double}
  */
 #define H5T_NATIVE_DOUBLE (H5OPEN H5T_NATIVE_DOUBLE_g)
-#if H5_SIZEOF_LONG_DOUBLE != 0
 /**
  * \ingroup PDTNAT
  * C-style \Code{long double}
  */
 #define H5T_NATIVE_LDOUBLE (H5OPEN H5T_NATIVE_LDOUBLE_g)
-#endif
 /**
  * \ingroup PDTNAT
  * HDF5 8-bit bitfield based on native types
@@ -912,9 +869,7 @@ H5_DLLVAR hid_t H5T_NATIVE_LLONG_g;
 H5_DLLVAR hid_t H5T_NATIVE_ULLONG_g;
 H5_DLLVAR hid_t H5T_NATIVE_FLOAT_g;
 H5_DLLVAR hid_t H5T_NATIVE_DOUBLE_g;
-#if H5_SIZEOF_LONG_DOUBLE != 0
 H5_DLLVAR hid_t H5T_NATIVE_LDOUBLE_g;
-#endif
 H5_DLLVAR hid_t H5T_NATIVE_B8_g;
 H5_DLLVAR hid_t H5T_NATIVE_B16_g;
 H5_DLLVAR hid_t H5T_NATIVE_B32_g;
@@ -1133,6 +1088,18 @@ H5_DLL hid_t H5Tcopy(hid_t type_id);
  *
  */
 H5_DLL herr_t H5Tclose(hid_t type_id);
+/**
+ * \ingroup H5T
+ *
+ * \brief Asynchronous version of H5Tclose().
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Tclose_async(const char *app_file, const char *app_func, unsigned app_line, hid_t type_id,
+                             hid_t es_id);
+#else
+H5_DLL herr_t H5Tclose_async(hid_t type_id, hid_t es_id);
+#endif
 /**
  * \ingroup H5T
  *
@@ -1215,6 +1182,20 @@ H5_DLL herr_t H5Tlock(hid_t type_id);
  */
 H5_DLL herr_t H5Tcommit2(hid_t loc_id, const char *name, hid_t type_id, hid_t lcpl_id, hid_t tcpl_id,
                          hid_t tapl_id);
+/**
+ * \ingroup H5T
+ *
+ * \brief Asynchronous version of H5Tcommit2().
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Tcommit_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                              const char *name, hid_t type_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id,
+                              hid_t es_id);
+#else
+H5_DLL herr_t H5Tcommit_async(hid_t loc_id, const char *name, hid_t type_id, hid_t lcpl_id, hid_t tcpl_id,
+                              hid_t tapl_id, hid_t es_id);
+#endif
 /**
  * --------------------------------------------------------------------------
  * \ingroup H5T
@@ -1239,6 +1220,18 @@ H5_DLL herr_t H5Tcommit2(hid_t loc_id, const char *name, hid_t type_id, hid_t lc
  *
  */
 H5_DLL hid_t H5Topen2(hid_t loc_id, const char *name, hid_t tapl_id);
+/**
+ * \ingroup H5T
+ *
+ * \brief Asynchronous version of H5Topen2().
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Topen_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                           const char *name, hid_t tapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Topen_async(hid_t loc_id, const char *name, hid_t tapl_id, hid_t es_id);
+#endif
 /**
  * \ingroup H5T
  *
@@ -2306,7 +2299,7 @@ H5_DLL htri_t H5Tis_variable_str(hid_t type_id);
  *
  *          \li #H5T_NATIVE_FLOAT
  *          \li #H5T_NATIVE_DOUBLE
- *          \li H5T_NATIVE_LDOUBLE
+ *          \li #H5T_NATIVE_LDOUBLE
  *
  *          \li #H5T_NATIVE_B8
  *          \li #H5T_NATIVE_B16
@@ -2678,129 +2671,6 @@ H5_DLL herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset);
  */
 H5_DLL herr_t H5Tset_strpad(hid_t type_id, H5T_str_t strpad);
 
-/**
- * \ingroup CONV
- *
- * \brief Registers a datatype conversion function
- *
- * \param[in] pers Conversion function type
- * \param[in] name Name displayed in diagnostic output
- * \type_id{src_id} of source datatype
- * \type_id{dst_id} of destination datatype
- * \param[in] func Function to convert between source and destination datatypes
- *
- * \return \herr_t
- *
- * \details H5Tregister() registers a hard or soft conversion function for a
- *          datatype conversion path. The parameter \p pers indicates whether a
- *          conversion function is hard (#H5T_PERS_HARD) or soft
- *          (#H5T_PERS_SOFT). User-defined functions employing compiler casting
- *          are designated as \Emph{hard}; other user-defined conversion
- *          functions registered with the HDF5 library (with H5Tregister() )
- *          are designated as \Emph{soft}. The HDF5 library also has its own
- *          hard and soft conversion functions.
- *
- *          A conversion path can have only one hard function. When type is
- *          #H5T_PERS_HARD, \p func replaces any previous hard function.
- *
- *          When type is #H5T_PERS_SOFT, H5Tregister() adds the function to the
- *          end of the master soft list and replaces the soft function in all
- *          applicable existing conversion paths. Soft functions are used when
- *          determining which conversion function is appropriate for this path.
- *
- *          The \p name is used only for debugging and should be a short
- *          identifier for the function.
- *
- *          The path is specified by the source and destination datatypes \p
- *          src_id and \p dst_id. For soft conversion functions, only the class
- *          of these types is important.
- *
- *          The type of the conversion function pointer is declared as:
- *          \snippet this H5T_conv_t_snip
- *
- *          The \ref H5T_cdata_t \c struct is declared as:
- *          \snippet this H5T_cdata_t_snip
- *
- * \since 1.6.3 The following change occurred in the \ref H5T_conv_t function:
- *              the \c nelmts parameter type changed to size_t.
- *
- */
-H5_DLL herr_t H5Tregister(H5T_pers_t pers, const char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func);
-/**
- * \ingroup CONV
- *
- * \brief Removes a conversion function
- *
- * \param[in] pers Conversion function type
- * \param[in] name Name displayed in diagnostic output
- * \type_id{src_id} of source datatype
- * \type_id{dst_id} of destination datatype
- * \param[in] func Function to convert between source and destination datatypes
- *
- * \return \herr_t
- *
- * \details H5Tunregister() removes a conversion function matching criteria
- *          such as soft or hard conversion, source and destination types, and
- *          the conversion function.
- *
- *          If a user is trying to remove a conversion function he registered,
- *          all parameters can be used. If he is trying to remove a library’s
- *          default conversion function, there is no guarantee the \p name and
- *          \p func parameters will match the user’s chosen values. Passing in
- *          some values may cause this function to fail. A good practice is to
- *          pass in NULL as their values.
- *
- *          All parameters are optional. The missing parameters will be used to
- *          generalize the search criteria.
- *
- *          The conversion function pointer type declaration is described in
- *          H5Tregister().
- *
- * \version 1.6.3 The following change occurred in the \ref H5T_conv_t function:
- *                the \c nelmts parameter type changed to size_t.
- *
- */
-H5_DLL herr_t H5Tunregister(H5T_pers_t pers, const char *name, hid_t src_id, hid_t dst_id, H5T_conv_t func);
-/**
- * \ingroup CONV
- *
- * \brief Finds a conversion function
- *
- * \type_id{src_id} of source datatype
- * \type_id{dst_id} of destination datatype
- * \param[out] pcdata Pointer to type conversion data
- *
- * \return Returns a pointer to a suitable conversion function if successful.
- *         Otherwise returns NULL.
- *
- * \details H5Tfind() finds a conversion function that can handle a conversion
- *          from type \p src_id to type \p dst_id. The \p pcdata argument is a
- *          pointer to a pointer to type conversion data which was created and
- *          initialized by the soft type conversion function of this path when
- *          the conversion function was installed on the path.
- *
- */
-H5_DLL H5T_conv_t H5Tfind(hid_t src_id, hid_t dst_id, H5T_cdata_t **pcdata);
-/**
- * \ingroup CONV
- *
- * \brief Check whether the library’s default conversion is hard conversion
- *
- * \type_id{src_id} of source datatype
- * \type_id{dst_id} of destination datatype
- *
- * \return \htri_t
- *
- * \details H5Tcompiler_conv() determines whether the library’s conversion
- *          function from type \p src_id to type \p dst_id is a compiler (hard)
- *          conversion or not. A compiler conversion uses compiler’s casting; a
- *          library (soft) conversion uses the library’s own conversion
- *          function.
- *
- * \since 1.8.0
- *
- */
-H5_DLL htri_t H5Tcompiler_conv(hid_t src_id, hid_t dst_id);
 /**
  * --------------------------------------------------------------------------
  * \ingroup CONV
@@ -2843,12 +2713,50 @@ H5_DLL htri_t H5Tcompiler_conv(hid_t src_id, hid_t dst_id);
  */
 H5_DLL herr_t H5Tconvert(hid_t src_id, hid_t dst_id, size_t nelmts, void *buf, void *background,
                          hid_t plist_id);
+/**
+ * \ingroup VLEN
+ *
+ * \brief Reclaims the variable length (VL) datatype memory buffers
+ *
+ * \type_id
+ * \space_id
+ * \dxpl_id{plist_id} used to create the buffer
+ * \param[in] buf Pointer to the buffer to be reclaimed
+ *
+ * \return \herr_t
+ *
+ * \details H5Treclaim() reclaims memory buffers created to store VL datatypes.
+ *          It only frees the variable length data in the selection defined in
+ *          the dataspace specified by \p space_id. The dataset transfer
+ *          property list \p plist_id is required to find the correct
+ *          allocation and/or free methods for the variable-length data in the
+ *          buffer.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Treclaim(hid_t type_id, hid_t space_id, hid_t plist_id, void *buf);
 
 /* Symbols defined for compatibility with previous versions of the HDF5 API.
  *
  * Use of these symbols is deprecated.
  */
 
+/* API Wrappers for async routines */
+/* (Must be defined _after_ the function prototype) */
+/* (And must only defined when included in application code, not the library) */
+#ifndef H5T_MODULE
+#define H5Tcommit_async(...) H5Tcommit_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Topen_async(...)   H5Topen_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Tclose_async(...)  H5Tclose_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+
+/* Define "wrapper" versions of function calls, to allow compile-time values to
+ * be passed in by language wrapper or library layer on top of HDF5. */
+#define H5Tcommit_async_wrap H5_NO_EXPAND(H5Tcommit_async)
+#define H5Topen_async_wrap   H5_NO_EXPAND(H5Topen_async)
+#define H5Tclose_async_wrap  H5_NO_EXPAND(H5Tclose_async)
+#endif /* H5T_MODULE */
+
 #ifndef H5_NO_DEPRECATED_SYMBOLS
 
 /* Macros */
