@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -12,14 +11,14 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Friday, January 23, 1998
  */
 
 /* See H5private.h for how to include headers */
 #undef NDEBUG
 
-#define H5T_PACKAGE /*suppress error about including H5Tpkg      */
+#define H5T_FRIEND  /*suppress error about including H5Tpkg      */
 #include "H5Tpkg.h" /*to turn off hardware conversions*/
 #include "H5Iprivate.h"
 
@@ -110,8 +109,8 @@ typedef struct {
     long long r, s, t;
 } stype4;
 
-#define NX          100u
-#define NY          2000u
+#define NX          100U
+#define NY          2000U
 #define PACK_NMEMBS 100
 
 /*-------------------------------------------------------------------------
@@ -302,7 +301,7 @@ test_compound(char *filename, hid_t fapl)
             s1[i].c[1] != s2[i].c[1] || s1[i].c[2] != s2[i].c[2] || s1[i].c[3] != s2[i].c[3] ||
             s1[i].d != s2[i].d || s1[i].e != s2[i].e) {
             H5_FAILED();
-            puts("    Incorrect values read from the file");
+            HDputs("    Incorrect values read from the file");
             goto error;
         }
     }
@@ -339,7 +338,7 @@ test_compound(char *filename, hid_t fapl)
             s1[i].c[1] != s3[i].c[1] || s1[i].c[2] != s3[i].c[2] || s1[i].c[3] != s3[i].c[3] ||
             s1[i].d != s3[i].d || s1[i].e != s3[i].e) {
             H5_FAILED();
-            puts("    Incorrect values read from the file");
+            HDputs("    Incorrect values read from the file");
             goto error;
         }
     }
@@ -369,7 +368,7 @@ test_compound(char *filename, hid_t fapl)
     for (i = 0; i < NX * NY; i++) {
         if (s1[i].b != s4[i].b || s1[i].d != s4[i].d) {
             H5_FAILED();
-            puts("    Incorrect values read from the file");
+            HDputs("    Incorrect values read from the file");
             goto error;
         }
     }
@@ -413,7 +412,7 @@ test_compound(char *filename, hid_t fapl)
             s1[i].c[1] != s5[i].c[1] || s1[i].c[2] != s5[i].c[2] || s1[i].c[3] != s5[i].c[3] ||
             s1[i].d != s5[i].d || s1[i].e != s5[i].e) {
             H5_FAILED();
-            puts("    Incorrect values read from the file");
+            HDputs("    Incorrect values read from the file");
             goto error;
         }
     }
@@ -423,7 +422,7 @@ test_compound(char *filename, hid_t fapl)
         if (s5[i].pre != 1000 + 4 * i || s5[i].mid1 != 1001 + 4 * i || s5[i].mid2 != 1002 + 4 * i ||
             s5[i].post != 1003 + 4 * i) {
             H5_FAILED();
-            puts("    Memory values were clobbered");
+            HDputs("    Memory values were clobbered");
             goto error;
         }
     }
@@ -482,7 +481,7 @@ test_compound(char *filename, hid_t fapl)
             s1[i].c[1] != s6[i].c[1] || s1[i].c[2] != s6[i].c[2] || s1[i].c[3] != s6[i].c[3] ||
             s1[i].d != s6[i].d || s1[i].e != s6[i].e) {
             H5_FAILED();
-            puts("    Incorrect values read from the file");
+            HDputs("    Incorrect values read from the file");
             goto error;
         }
     }
@@ -492,7 +491,7 @@ test_compound(char *filename, hid_t fapl)
         if (s6[i].pre != 1000 + 4 * i || s6[i].mid1 != 1001 + 4 * i || s6[i].mid2 != 1002 + 4 * i ||
             s6[i].post != 1003 + 4 * i) {
             H5_FAILED();
-            puts("    Memory values were clobbered");
+            HDputs("    Memory values were clobbered");
             goto error;
         }
     }
@@ -561,7 +560,7 @@ test_compound(char *filename, hid_t fapl)
             s2[i].c[1] != s1[i].c[1] || s2[i].c[2] != s1[i].c[2] || s2[i].c[3] != s1[i].c[3] ||
             s2[i].d != s1[i].d || s2[i].e != s1[i].e) {
             H5_FAILED();
-            puts("    Incorrect values read from file");
+            HDputs("    Incorrect values read from file");
             goto error;
         }
     }
@@ -590,7 +589,7 @@ test_compound(char *filename, hid_t fapl)
 
     /* Read the dataset */
     s8 = (s1_t *)HDcalloc((size_t)(h_size[0] * h_size[1]), sizeof(s1_t));
-    assert(s8);
+    HDassert(s8);
     if (H5Dread(dataset, s1_tid, s8_m_sid, s8_f_sid, H5P_DEFAULT, s8) < 0) {
         goto error;
     }
@@ -604,7 +603,7 @@ test_compound(char *filename, hid_t fapl)
             if (ps8->a != ps1->a || ps8->b != ps1->b || ps8->c[0] != ps1->c[0] || ps8->c[1] != ps1->c[1] ||
                 ps8->c[2] != ps1->c[2] || ps8->c[3] != ps1->c[3] || ps8->d != ps1->d || ps8->e != ps1->e) {
                 H5_FAILED();
-                puts("    Incorrect values read from file");
+                HDputs("    Incorrect values read from file");
                 goto error;
             }
         }
@@ -643,7 +642,7 @@ test_compound(char *filename, hid_t fapl)
                     ps2->c[1] != ps1->c[1] || ps2->c[2] != ps1->c[2] || ps2->c[3] != ps1->c[3] ||
                     ps2->d != ps1->d || ps2->e != ps1->e) {
                     H5_FAILED();
-                    puts("    Memory values clobbered");
+                    HDputs("    Memory values clobbered");
                     goto error;
                 }
             }
@@ -652,7 +651,7 @@ test_compound(char *filename, hid_t fapl)
                     ps2->c[1] != (unsigned)(-1) || ps2->c[2] != (unsigned)(-1) ||
                     ps2->c[3] != (unsigned)(-1) || ps2->d != (unsigned)(-1) || ps2->e != (unsigned)(-1)) {
                     H5_FAILED();
-                    puts("    Incorrect values read from file");
+                    HDputs("    Incorrect values read from file");
                     goto error;
                 }
             }
@@ -691,7 +690,7 @@ test_compound(char *filename, hid_t fapl)
                     ps5->c[2] != ps1->c[2] || ps5->c[3] != ps1->c[3] || ps5->mid2 != (unsigned)(-1) ||
                     ps5->d != ps1->d || ps5->e != ps1->e || ps5->post != (unsigned)(-1)) {
                     H5_FAILED();
-                    puts("    Memory values clobbered");
+                    HDputs("    Memory values clobbered");
                     goto error;
                 }
             }
@@ -702,7 +701,7 @@ test_compound(char *filename, hid_t fapl)
                     ps5->c[3] != (unsigned)(-1) || ps5->mid2 != (unsigned)(-1) || ps5->d != (unsigned)(-1) ||
                     ps5->e != (unsigned)(-1) || ps5->post != (unsigned)(-1)) {
                     H5_FAILED();
-                    puts("    Incorrect values read from file");
+                    HDputs("    Incorrect values read from file");
                     goto error;
                 }
             }
@@ -713,7 +712,7 @@ test_compound(char *filename, hid_t fapl)
     /*
      *######################################################################
      * Step 12: Write an array into the middle third of the dataset
-     * initializeing only members `b' and `d' to -1.
+     * initializing only members `b' and `d' to -1.
      */
     TESTING("hyperslab part initialized write");
 
@@ -723,7 +722,7 @@ test_compound(char *filename, hid_t fapl)
     h_size[0]   = 2 * NX / 3 - f_offset[0];
     h_size[1]   = 2 * NY / 3 - f_offset[1];
     s11         = (s4_t *)HDmalloc((size_t)h_size[0] * (size_t)h_size[1] * sizeof(s4_t));
-    assert(s11);
+    HDassert(s11);
 
     /* Initialize */
     for (i = 0; i < h_size[0] * h_size[1]; i++) {
@@ -751,7 +750,7 @@ test_compound(char *filename, hid_t fapl)
                 ps1->c[1] != 8 * (i * NY + j) + 3 || ps1->c[2] != 8 * (i * NY + j) + 4 ||
                 ps1->c[3] != 8 * (i * NY + j) + 5 || ps1->e != 8 * (i * NY + j) + 7) {
                 H5_FAILED();
-                puts("    Write clobbered values");
+                HDputs("    Write clobbered values");
                 goto error;
             }
 
@@ -759,14 +758,14 @@ test_compound(char *filename, hid_t fapl)
                 j < f_offset[1] + h_size[1]) {
                 if (ps1->b != (unsigned)(-1) || ps1->d != (unsigned)(-1)) {
                     H5_FAILED();
-                    puts("    Wrong values written or read");
+                    HDputs("    Wrong values written or read");
                     goto error;
                 }
             }
             else {
                 if (ps1->b != 8 * (i * NY + j) + 1 || ps1->d != 8 * (i * NY + j) + 6) {
                     H5_FAILED();
-                    puts("    Write clobbered values");
+                    HDputs("    Write clobbered values");
                     goto error;
                 }
             }
@@ -792,7 +791,7 @@ test_compound(char *filename, hid_t fapl)
     return 0;
 
 error:
-    puts("*** DATASET TESTS FAILED ***");
+    HDputs("*** DATASET TESTS FAILED ***");
 
     /* Release resources */
     if (s1)
@@ -1378,32 +1377,32 @@ test_hdf5_src_subset(char *filename, hid_t fapl)
 
     /* Create xfer properties to preserve initialized data */
     if ((dxpl = H5Pcreate(H5P_DATASET_XFER)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Pset_preserve(dxpl, TRUE) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Rewrite contiguous data set */
     if ((dataset = H5Dopen2(file, DSET_NAME[0], H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Write the data to the dataset */
     if (H5Dwrite(dataset, rew_tid, H5S_ALL, H5S_ALL, dxpl, rew_buf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Dclose(dataset) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Rewrite chunked data set */
     if ((dataset = H5Dopen2(file, DSET_NAME[1], H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Write the data to the dataset */
     if (H5Dwrite(dataset, rew_tid, H5S_ALL, H5S_ALL, dxpl, rew_buf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Dclose(dataset) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     PASSED();
 
@@ -1415,48 +1414,48 @@ test_hdf5_src_subset(char *filename, hid_t fapl)
 
     /* Check contiguous data set */
     if ((dataset = H5Dopen2(file, DSET_NAME[0], H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Dread(dataset, dst_tid, H5S_ALL, H5S_ALL, dxpl, rbuf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (compare_data(orig, rbuf, TRUE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     if (H5Dclose(dataset) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Check chunked data set */
     if ((dataset = H5Dopen2(file, DSET_NAME[1], H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Dread(dataset, dst_tid, H5S_ALL, H5S_ALL, dxpl, rbuf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (compare_data(orig, rbuf, TRUE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     if (H5Dclose(dataset) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Finishing test and release resources */
     if (H5Sclose(space) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Pclose(dcpl) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Pclose(dxpl) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Tclose(src_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(dst_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(rew_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Fclose(file) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     HDfree(orig);
     HDfree(rbuf);
@@ -1466,6 +1465,10 @@ test_hdf5_src_subset(char *filename, hid_t fapl)
     return 0;
 
 error:
+    HDfree(orig);
+    HDfree(rbuf);
+    HDfree(rew_buf);
+
     HDputs("*** DATASET TESTS FAILED ***");
     return 1;
 }
@@ -1669,7 +1672,7 @@ test_hdf5_dst_subset(char *filename, hid_t fapl)
     return 0;
 
 error:
-    puts("*** DATASET TESTS FAILED ***");
+    HDputs("*** DATASET TESTS FAILED ***");
     return 1;
 }
 
@@ -1684,7 +1687,7 @@ error:
         for (_i = 0; _i < PACK_NMEMBS; _i++)                                                                 \
             HDprintf(" %d", order[_i]);                                                                      \
         HDprintf("\n    Inner compound order = %d, location = %d\n", sub_cmpd_order, order[sub_cmpd_order]); \
-        fflush(stdout);                                                                                      \
+        HDfflush(stdout);                                                                                    \
         goto error;                                                                                          \
     }
 
@@ -1719,7 +1722,7 @@ test_pack_ooo(void)
                                        * the compound */
     unsigned i, j;                    /* Indices */
 
-    HDsrand((unsigned)time(NULL));
+    HDsrand((unsigned)HDtime(NULL));
 
     /* Initialize "free_order" array to indicate that all slots in order are
      * free */
@@ -1762,7 +1765,7 @@ test_pack_ooo(void)
 
         /* Insert the compound members in the random order previously generated */
         for (i = 0; i < PACK_NMEMBS; i++) {
-            HDsprintf(name, "%05d", i);
+            HDsnprintf(name, sizeof(name), "%05d", i);
             if (i == sub_cmpd_order) {
                 if (H5Tinsert(cmpd, name, (size_t)(4 * order[i]), sub_cmpd) < 0)
                     PACK_OOO_ERROR
@@ -1795,7 +1798,7 @@ test_pack_ooo(void)
 
         /* Insert the compound members in the random order previously generated */
         for (i = 0; i < PACK_NMEMBS; i++) {
-            HDsprintf(name, "%05d", i);
+            HDsnprintf(name, sizeof(name), "%05d", i);
             if (i == sub_cmpd_order) {
                 if (H5Tinsert(cmpd, name, (size_t)(4 * order[i]), sub_cmpd) < 0)
                     PACK_OOO_ERROR
@@ -1830,7 +1833,7 @@ test_pack_ooo(void)
 
         /* Insert the compound members in reverse order, with compound last */
         for (i = 0; i < PACK_NMEMBS; i++) {
-            HDsprintf(name, "%05d", i);
+            HDsnprintf(name, sizeof(name), "%05d", i);
             if (i == PACK_NMEMBS - 1) {
                 if (H5Tinsert(cmpd, name, (size_t)(4 * (PACK_NMEMBS - i - 1)), sub_cmpd) < 0)
                     PACK_OOO_ERROR
@@ -1863,7 +1866,7 @@ test_pack_ooo(void)
 
         /* Insert the compound members in reverse order, with compound last */
         for (i = 0; i < PACK_NMEMBS; i++) {
-            HDsprintf(name, "%05d", i);
+            HDsnprintf(name, sizeof(name), "%05d", i);
             if (i == PACK_NMEMBS - 1) {
                 if (H5Tinsert(cmpd, name, (size_t)(4 * (PACK_NMEMBS - i - 1)), sub_cmpd) < 0)
                     PACK_OOO_ERROR
@@ -1898,7 +1901,7 @@ test_pack_ooo(void)
 
         /* Insert the compound members in forward order, with compound first */
         for (i = 0; i < PACK_NMEMBS; i++) {
-            HDsprintf(name, "%05d", i);
+            HDsnprintf(name, sizeof(name), "%05d", i);
             if (i == 0) {
                 if (H5Tinsert(cmpd, name, (size_t)(4 * i), sub_cmpd) < 0)
                     PACK_OOO_ERROR
@@ -1931,7 +1934,7 @@ test_pack_ooo(void)
 
         /* Insert the compound members in forward order */
         for (i = 0; i < PACK_NMEMBS; i++) {
-            HDsprintf(name, "%05d", i);
+            HDsnprintf(name, sizeof(name), "%05d", i);
             if (i == 0) {
                 if (H5Tinsert(cmpd, name, (size_t)(4 * i), sub_cmpd) < 0)
                     PACK_OOO_ERROR
@@ -1989,207 +1992,207 @@ test_ooo_order(char *filename, hid_t fapl_id)
     hid_t  dtype_tmp = -1;   /* Temp Datatype ID */
     H5T_t *dt        = NULL; /* Datatype pointer */
 
-    TESTING("that compound member insertion order is preserved")
+    TESTING("that compound member insertion order is preserved");
 
     /* Create the file */
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Create the compound */
     if ((dtype = H5Tcreate(H5T_COMPOUND, (size_t)20)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tinsert(dtype, "A", (size_t)8, H5T_STD_I32LE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tinsert(dtype, "B", (size_t)12, H5T_STD_I32LE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tinsert(dtype, "C", (size_t)0, H5T_STD_I32LE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tinsert(dtype, "D", (size_t)16, H5T_STD_I32LE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the compound is not packed */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the order is the same as the insertion order */
     if (H5Tget_member_offset(dtype, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Commit the datatype */
     if (H5Tcommit2(file, "dtype", dtype, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close and reopen the file */
     if (H5Tclose(dtype))
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Fclose(file))
-        TEST_ERROR
+        TEST_ERROR;
     if ((file = H5Fopen(filename, H5F_ACC_RDWR, fapl_id)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Open the type */
     if ((dtype_tmp = H5Topen2(file, "dtype", H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the compound is not packed */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype_tmp, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the order is the same as the insertion order */
     if (H5Tget_member_offset(dtype_tmp, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Copy the datatype */
     if ((dtype = H5Tcopy(dtype_tmp)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the compound is not packed */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the order is the same as the insertion order */
     if (H5Tget_member_offset(dtype, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Insert the last member */
     if (H5Tinsert(dtype, "E", (size_t)4, H5T_STD_I32LE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the compound is packed */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (!dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Verify that the order is the same as the insertion order */
     if (H5Tget_member_offset(dtype, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 4) != 4)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Commit the modified datatype */
     if (H5Tcommit2(file, "dtype2", dtype, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close and reopen the file */
     if (H5Tclose(dtype_tmp))
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tclose(dtype))
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Fclose(file))
-        TEST_ERROR
+        TEST_ERROR;
     if ((file = H5Fopen(filename, H5F_ACC_RDONLY, fapl_id)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Open the type, and verify status */
     if ((dtype_tmp = H5Topen2(file, "dtype2", H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype_tmp, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (!dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype_tmp, 4) != 4)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Copy the datatype, and verify status */
     if ((dtype = H5Tcopy(dtype_tmp)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (!dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 4) != 4)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Expand the type, and verify that it became unpacked */
     if (H5Tset_size(dtype, (size_t)21) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 4) != 4)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Shrink the type, and verify that it became packed */
     if (H5Tset_size(dtype, (size_t)20) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (NULL == (dt = (H5T_t *)H5I_object_verify(dtype, H5I_DATATYPE)))
-        TEST_ERROR
+        TEST_ERROR;
     if (!dt->shared->u.compnd.packed)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 0) != 8)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 1) != 12)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 2) != 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 3) != 16)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tget_member_offset(dtype, 4) != 4)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close */
     if (H5Tclose(dtype_tmp))
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tclose(dtype))
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Fclose(file))
-        TEST_ERROR
+        TEST_ERROR;
 
     PASSED();
     return 0;
@@ -2233,7 +2236,7 @@ main(int argc, char *argv[])
 
     /* Turn off optimized compound converter? */
     if (argc > 1) {
-        if (argc > 2 || strcmp("--noopt", argv[1])) {
+        if (argc > 2 || HDstrcmp("--noopt", argv[1]) != 0) {
             HDfprintf(stderr, "usage: %s [--noopt]\n", argv[0]);
             HDexit(EXIT_FAILURE);
         }
