@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -142,11 +141,11 @@ test_direct_chunk_write(hid_t file)
     size_t   buf_size  = CHUNK_NX * CHUNK_NY * sizeof(int);
 
     const Bytef *z_src        = (const Bytef *)(direct_buf);
-    Bytef *      z_dst        = NULL; /*destination buffer        */
+    Bytef       *z_dst        = NULL; /*destination buffer        */
     uLongf       z_dst_nbytes = (uLongf)DEFLATE_SIZE_ADJUST(buf_size);
     uLong        z_src_nbytes = (uLong)buf_size;
     int          aggression   = 9;    /* Compression aggression setting */
-    void *       outbuf       = NULL; /* Pointer to new buffer */
+    void        *outbuf       = NULL; /* Pointer to new buffer */
 
     hsize_t start[2];  /* Start of hyperslab */
     hsize_t stride[2]; /* Stride of hyperslab */
@@ -412,19 +411,19 @@ test_direct_chunk_overwrite_data(hid_t fid)
 
     /* Create the dataset's data space */
     if ((sid = H5Screate_simple(OVERWRITE_NDIMS, dset_dims, dset_max_dims)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Set chunk size and filll value */
     if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Pset_fill_value(dcpl_id, tid, &fill_value) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Pset_chunk(dcpl_id, OVERWRITE_NDIMS, chunk_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Create dataset */
     if ((did = H5Dcreate2(fid, DATASETNAME7, tid, sid, H5P_DEFAULT, dcpl_id, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Initialize data buffers */
     n = 0;
@@ -437,35 +436,35 @@ test_direct_chunk_overwrite_data(hid_t fid)
 
     /* Write chunk data using the direct write function. */
     if (H5Dwrite_chunk(did, H5P_DEFAULT, filter_mask, offset, buf_size, data_buf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Write second chunk. */
     offset[2] = OVERWRITE_CHUNK_NX;
     if (H5Dwrite_chunk(did, H5P_DEFAULT, filter_mask, offset, buf_size, data_buf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Overwrite first chunk. */
     offset[2] = 0;
     if (H5Dwrite_chunk(did, H5P_DEFAULT, filter_mask, offset, buf_size, overwrite_buf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Read the data back out */
     if (H5Dread(did, tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Ensure that the data are correct in chunk 1 */
     for (i = 0; i < OVERWRITE_CHUNK_NY; i++)
         for (j = 0; j < OVERWRITE_CHUNK_NX; j++) {
             if (read_buf[i][j] != OVERWRITE_VALUE)
-                TEST_ERROR
+                TEST_ERROR;
         }
 
     if (H5Pclose(dcpl_id) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Sclose(sid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     PASSED();
     return 0;
@@ -682,7 +681,7 @@ static size_t
 filter_bogus1(unsigned int flags, size_t H5_ATTR_UNUSED cd_nelmts,
               const unsigned int H5_ATTR_UNUSED *cd_values, size_t nbytes, size_t *buf_size, void **buf)
 {
-    int *  int_ptr  = (int *)*buf; /* Pointer to the data values */
+    int   *int_ptr  = (int *)*buf; /* Pointer to the data values */
     size_t buf_left = *buf_size;   /* Amount of data buffer left to process */
 
     if (flags & H5Z_FLAG_REVERSE) { /* read */
@@ -718,7 +717,7 @@ static size_t
 filter_bogus2(unsigned int flags, size_t H5_ATTR_UNUSED cd_nelmts,
               const unsigned int H5_ATTR_UNUSED *cd_values, size_t nbytes, size_t *buf_size, void **buf)
 {
-    int *  int_ptr  = (int *)*buf; /* Pointer to the data values */
+    int   *int_ptr  = (int *)*buf; /* Pointer to the data values */
     size_t buf_left = *buf_size;   /* Amount of data buffer left to process */
 
     if (flags & H5Z_FLAG_REVERSE) { /* read */
@@ -1463,7 +1462,7 @@ test_direct_chunk_read_no_cache(hid_t file)
     Bytef *z_dst        = (Bytef *)(direct_buf);
     uLong  z_dst_nbytes = (uLong)buf_size;
     int    aggression   = 9;    /* Compression aggression setting */
-    void * outbuf       = NULL; /* Pointer to new buffer */
+    void  *outbuf       = NULL; /* Pointer to new buffer */
 
     hsize_t start[2];  /* Start of hyperslab */
     hsize_t stride[2]; /* Stride of hyperslab */
@@ -1636,12 +1635,12 @@ test_direct_chunk_read_cache(hid_t file, hbool_t flush)
     hsize_t  offset[2];                       /* chunk offset used for H5Dread_chunk */
     size_t   buf_size = CHUNK_NX * CHUNK_NY * sizeof(int);
 
-    Bytef * z_src         = NULL; /* source buffer        */
+    Bytef  *z_src         = NULL; /* source buffer        */
     uLongf  z_src_nbytes  = (uLongf)DEFLATE_SIZE_ADJUST(buf_size);
-    Bytef * z_dst         = (Bytef *)(direct_buf);
+    Bytef  *z_dst         = (Bytef *)(direct_buf);
     uLong   z_dst_nbytes  = (uLong)buf_size;
     int     aggression    = 9;    /* Compression aggression setting */
-    void *  outbuf        = NULL; /* Pointer to new buffer */
+    void   *outbuf        = NULL; /* Pointer to new buffer */
     hsize_t read_buf_size = 0;
 
     hsize_t start[2];  /* Start of hyperslab */
@@ -2040,7 +2039,7 @@ test_read_unallocated_chunk(hid_t file)
 
             /* Check that the chunk read call does not succeed. */
             if (status != -1)
-                TEST_ERROR
+                TEST_ERROR;
 
             /* Query the size of the non-existent chunk */
             direct_chunk_nbytes = ULONG_MAX;
@@ -2052,9 +2051,9 @@ test_read_unallocated_chunk(hid_t file)
 
             /* Check that the chunk storage size call does not succeed. */
             if (status != -1)
-                TEST_ERROR
+                TEST_ERROR;
             if (direct_chunk_nbytes != ULONG_MAX)
-                TEST_ERROR
+                TEST_ERROR;
         }
     }
 
@@ -2167,7 +2166,7 @@ test_single_chunk(unsigned config)
     else
         /* Write the data to the dataset */
         if (H5Dwrite(did, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, (void *)wdata) < 0)
-        FAIL_STACK_ERROR;
+            FAIL_STACK_ERROR;
 
     /*
      * Close and release resources.
@@ -2204,18 +2203,18 @@ test_single_chunk(unsigned config)
 
         /* Verify returned filter mask */
         if (filters != 0)
-            TEST_ERROR
+            TEST_ERROR;
     } /* end if */
     else
         /* Read the data */
         if (H5Dread(did, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, rdata) < 0)
-        FAIL_STACK_ERROR;
+            FAIL_STACK_ERROR;
 
     /* Verify that the data read was correct.  */
     for (i = 0; i < DIM0; i++)
         for (j = 0; j < DIM1; j++)
             if (rdata[i][j] != wdata[i][j])
-                TEST_ERROR
+                TEST_ERROR;
 
     /*
      * Close and release resources
