@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -12,7 +11,7 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Raymond Lu <slu@ncsa.uiuc.edu>
+ * Programmer:  Raymond Lu
  *              Thursday, March 23, 2006
  *
  *  This program writes floating-point data to the HDF5 file.  It generates
@@ -123,53 +122,53 @@ create_normal_dset(hid_t fid, hid_t fsid, hid_t msid)
      * Create the dataset creation property list, set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace and
      * little-endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME, H5T_IEEE_F64LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close dataset
      */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace and
      * big-endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME1, H5T_IEEE_F64BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close dataset
      */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -222,44 +221,44 @@ create_scale_offset_dsets_float(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_scaleoffset(dcpl, H5Z_SO_FLOAT_DSCALE, 3) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME2, H5T_IEEE_F32LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME3, H5T_IEEE_F32BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -295,7 +294,7 @@ create_scale_offset_dsets_double(hid_t fid, hid_t fsid, hid_t msid)
     hid_t   dataset = -1; /* dataset handles */
     hid_t   dcpl    = -1;
     double  data[NX][NY]; /* data to write */
-    double  fillvalue   = -2.2f;
+    double  fillvalue   = -2.2;
     hsize_t chunk[RANK] = {CHUNK0, CHUNK1};
     int     i, j;
 
@@ -312,44 +311,44 @@ create_scale_offset_dsets_double(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_scaleoffset(dcpl, H5Z_SO_FLOAT_DSCALE, 3) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_DOUBLE, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME4, H5T_IEEE_F64LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_DOUBLE, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME5, H5T_IEEE_F64BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_DOUBLE, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -410,44 +409,44 @@ create_scale_offset_dsets_char(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_scaleoffset(dcpl, H5Z_SO_INT, H5Z_SO_INT_MINBITS_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_CHAR, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME6, H5T_STD_I8LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_CHAR, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME7, H5T_STD_I8BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_CHAR, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -508,44 +507,44 @@ create_scale_offset_dsets_short(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_scaleoffset(dcpl, H5Z_SO_INT, H5Z_SO_INT_MINBITS_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_SHORT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME8, H5T_STD_I16LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_SHORT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME9, H5T_STD_I16BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_SHORT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -606,44 +605,44 @@ create_scale_offset_dsets_int(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_scaleoffset(dcpl, H5Z_SO_INT, H5Z_SO_INT_MINBITS_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_INT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME10, H5T_STD_I32LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_INT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME11, H5T_STD_I32BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_INT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -705,44 +704,44 @@ create_scale_offset_dsets_long_long(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_scaleoffset(dcpl, H5Z_SO_INT, H5Z_SO_INT_MINBITS_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_LLONG, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME12, H5T_STD_I64LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_LLONG, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME13, H5T_STD_I64BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_LLONG, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -795,44 +794,44 @@ create_fletcher_dsets_float(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_filter(dcpl, H5Z_FILTER_FLETCHER32, 0, (size_t)0, NULL) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME14, H5T_IEEE_F32LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME15, H5T_IEEE_F32BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -886,49 +885,49 @@ create_deflate_dsets_float(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_deflate(dcpl, 6) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME16, H5T_IEEE_F32LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME17, H5T_IEEE_F32BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
 #else  /* H5_HAVE_FILTER_DEFLATE */
     const char *not_supported = "Deflate filter is not enabled. Can't create the dataset.";
 
-    puts(not_supported);
+    HDputs(not_supported);
 #endif /* H5_HAVE_FILTER_DEFLATE */
 
     return 0;
@@ -986,44 +985,44 @@ create_szip_dsets_float(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_szip(dcpl, H5_SZIP_NN_OPTION_MASK, 4) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME18, H5T_IEEE_F32LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME19, H5T_IEEE_F32BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -1077,44 +1076,44 @@ create_shuffle_dsets_float(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_shuffle(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace, little
      * endian datatype and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME20, H5T_IEEE_F32LE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if ((dataset = H5Dcreate2(fid, DATASETNAME21, H5T_IEEE_F32BE, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -1169,63 +1168,63 @@ create_nbit_dsets_float(hid_t fid, hid_t fsid, hid_t msid)
      * filter, set the chunk size, and set the fill value.
      */
     if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_nbit(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_chunk(dcpl, RANK, chunk) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Pset_fill_value(dcpl, H5T_NATIVE_FLOAT, &fillvalue) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Define user-defined single-precision floating-point type for dataset.
      * A 20-bit little-endian data type. */
     if ((datatype = H5Tcopy(H5T_IEEE_F32LE)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tset_fields(datatype, (size_t)26, (size_t)20, (size_t)6, (size_t)7, (size_t)13) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     offset = 7;
     if (H5Tset_offset(datatype, offset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     precision = 20;
     if (H5Tset_precision(datatype, precision) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tset_size(datatype, (size_t)4) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Tset_ebias(datatype, (size_t)31) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Create a new dataset within the file using defined dataspace,
      * user-defined datatype, and default dataset creation properties.
      */
     if ((dataset = H5Dcreate2(fid, DATASETNAME22, datatype, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Write the data to the dataset using default transfer properties.
      */
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close dataset */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Now create a dataset with a big-endian type */
     if (H5Tset_order(datatype, H5T_ORDER_BE) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if ((dataset = H5Dcreate2(fid, DATASETNAME23, datatype, fsid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dwrite(dataset, H5T_NATIVE_FLOAT, msid, fsid, H5P_DEFAULT, data) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
     if (H5Pclose(dcpl) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -1243,13 +1242,11 @@ error:
 /*-------------------------------------------------------------------------
  * Function:    main
  *
- * Purpose:     Create a file for cross_read.c test.
+ * Purpose:     Create a file for cross_read.c test
  *
- * Return:      Success:        exit(EXIT_SUCCESS)
- *              Failure:        exit(EXIT_FAILURE)
+ * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
  * Programmer:  Raymond Lu
- *              Some time ago
  *
  *-------------------------------------------------------------------------
  */
@@ -1267,11 +1264,8 @@ main(void)
      * default file creation properties, and default file
      * access properties.
      */
-    if ((file = H5Fcreate(H5FILE_NAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if ((file = H5Fcreate(H5FILE_NAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT)) < 0)
+        TEST_ERROR;
 
     /*
      * Describe the size of the array and create the data space for fixed
@@ -1280,134 +1274,83 @@ main(void)
      */
     dimsf[0] = NX + 1;
     dimsf[1] = NY;
-    if ((filespace = H5Screate_simple(RANK, dimsf, NULL)) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if ((filespace = H5Screate_simple(RANK, dimsf, NULL)) < 0)
+        TEST_ERROR;
     dimsf[0] = NX;
-    if (H5Sselect_hyperslab(filespace, H5S_SELECT_SET, start, NULL, dimsf, NULL) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (H5Sselect_hyperslab(filespace, H5S_SELECT_SET, start, NULL, dimsf, NULL) < 0)
+        TEST_ERROR;
 
     /* Create memory space.  This does not include the extra row for fill
      * values. */
     HDassert(dimsf[0] == NX);
     HDassert(dimsf[1] == NY);
-    if ((memspace = H5Screate_simple(RANK, dimsf, NULL)) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if ((memspace = H5Screate_simple(RANK, dimsf, NULL)) < 0)
+        TEST_ERROR;
 
     /* Create a regular dataset */
-    if (create_normal_dset(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_normal_dset(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of FLOAT with scale-offset filter */
-    if (create_scale_offset_dsets_float(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_scale_offset_dsets_float(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of DOUBLE with scale-offset filter */
-    if (create_scale_offset_dsets_double(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_scale_offset_dsets_double(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of CHAR with scale-offset filter */
-    if (create_scale_offset_dsets_char(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_scale_offset_dsets_char(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of SHORT with scale-offset filter */
-    if (create_scale_offset_dsets_short(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_scale_offset_dsets_short(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of INT with scale-offset filter */
-    if (create_scale_offset_dsets_int(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_scale_offset_dsets_int(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of LONG LONG with scale-offset filter */
-    if (create_scale_offset_dsets_long_long(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_scale_offset_dsets_long_long(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of FLOAT with fletcher filter */
-    if (create_fletcher_dsets_float(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_fletcher_dsets_float(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of FLOAT with deflate filter */
-    if (create_deflate_dsets_float(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_deflate_dsets_float(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
 #ifdef H5_HAVE_FILTER_SZIP
     /* Create a dataset of FLOAT with szip filter */
-    if (create_szip_dsets_float(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_szip_dsets_float(file, filespace, memspace) < 0)
+        TEST_ERROR;
 #else  /* H5_HAVE_FILTER_SZIP */
-    puts("Szip filter is not enabled. Can't create the dataset.");
+    HDputs("Szip filter is not enabled. Can't create the dataset.");
 #endif /* H5_HAVE_FILTER_SZIP */
 
     /* Create a dataset of FLOAT with shuffle filter */
-    if (create_shuffle_dsets_float(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_shuffle_dsets_float(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /* Create a dataset of FLOAT with nbit filter */
-    if (create_nbit_dsets_float(file, filespace, memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (create_nbit_dsets_float(file, filespace, memspace) < 0)
+        TEST_ERROR;
 
     /*
      * Close/release resources.
      */
-    if (H5Sclose(memspace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
-    if (H5Sclose(filespace) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
-    if (H5Fclose(file) < 0) {
-        H5_FAILED();
-        AT();
-        return 1;
-    }
+    if (H5Sclose(memspace) < 0)
+        TEST_ERROR;
+    if (H5Sclose(filespace) < 0)
+        TEST_ERROR;
+    if (H5Fclose(file) < 0)
+        TEST_ERROR;
 
-    return 0;
-}
+    HDexit(EXIT_SUCCESS);
+
+error:
+    HDexit(EXIT_FAILURE);
+} /* end main() */
