@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -69,7 +68,7 @@ static int
 test_1(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     uint8_t in[GHEAP_TEST_NOBJS];
@@ -178,7 +177,7 @@ static int
 test_2(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     uint8_t in[GHEAP_TEST_NOBJS];
@@ -278,7 +277,7 @@ static int
 test_3(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     size_t  u;
@@ -369,7 +368,7 @@ static int
 test_4(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     size_t  u;
@@ -466,9 +465,9 @@ static int
 test_ooo_indices(hid_t fapl)
 {
     hid_t    file = H5I_INVALID_HID;
-    H5F_t *  f    = NULL;
+    H5F_t   *f    = NULL;
     unsigned i, j;
-    H5HG_t * obj = NULL;
+    H5HG_t  *obj = NULL;
     herr_t   status;
     int      nerrors = 0;
     char     filename[1024];
@@ -586,7 +585,7 @@ main(void)
 
     /* Push API context */
     if (H5CX_push() < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     api_ctx_pushed = TRUE;
 
     nerrors += test_1(fapl_id);
@@ -604,8 +603,8 @@ main(void)
     HDputs("All global heap tests passed.");
 
     /* Pop API context */
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        FAIL_STACK_ERROR
+    if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
+        FAIL_STACK_ERROR;
     api_ctx_pushed = FALSE;
 
     h5_cleanup(FILENAME, fapl_id);
@@ -619,7 +618,7 @@ error:
     H5E_END_TRY;
 
     if (api_ctx_pushed)
-        H5CX_pop();
+        H5CX_pop(FALSE);
 
     HDputs("*** TESTS FAILED ***");
     HDexit(EXIT_FAILURE);
