@@ -27,12 +27,9 @@
 #include "H5FDhdfs.h" /* this file driver's utilities */
 
 #ifdef H5_HAVE_LIBHDFS
-
 #define HDFS_TEST_DEBUG        0
 #define HDFS_TEST_MAX_BUF_SIZE 256
 
-/* only include the testing macros if needed */
-
 /*****************************************************************************
  *
  * FILE-LOCAL TESTING MACROS
@@ -55,7 +52,7 @@
  *     4) Configurable expected-actual order in generated comparison strings.
  *        Some prefer `VERIFY(expected, actual)`, others
  *        `VERIFY(actual, expected)`. Provide preprocessor ifdef switch
- *        to satifsy both parties, assuming one paradigm per test file.
+ *        to satisfy both parties, assuming one paradigm per test file.
  *        (One could #undef and redefine the flag through the file as desired,
  *         but _why_.)
  *
@@ -105,7 +102,7 @@
  */
 #define JSFAILED_AT()                                                                                        \
     {                                                                                                        \
-        HDprintf("*FAILED* at %s:%d in %s()...\n", __FILE__, __LINE__, FUNC);                                \
+        HDprintf("*FAILED* at %s:%d in %s()...\n", __FILE__, __LINE__, __func__);                            \
     }
 
 /*----------------------------------------------------------------------------
@@ -233,9 +230,10 @@
  */
 #define JSERR_STR(expected, actual, reason)                                                                  \
     {                                                                                                        \
+        const char *_reason = reason;                                                                        \
         JSFAILED_AT()                                                                                        \
-        if ((reason) != NULL) {                                                                              \
-            HDprintf("%s\n", (reason));                                                                      \
+        if (_reason != NULL) {                                                                               \
+            HDprintf("%s\n", _reason);                                                                       \
         }                                                                                                    \
         else {                                                                                               \
             HDprintf("!!! Expected:\n%s\n!!!Actual:\n%s\n", (expected), (actual));                           \
@@ -305,7 +303,7 @@
  *----------------------------------------------------------------------------
  */
 #define JSVERIFY_STR(expected, actual, reason)                                                               \
-    if (strcmp((actual), (expected)) != 0) {                                                                 \
+    if (HDstrcmp((actual), (expected)) != 0) {                                                               \
         JSERR_STR((expected), (actual), (reason));                                                           \
         goto error;                                                                                          \
     } /* JSVERIFY_STR */
@@ -350,7 +348,7 @@
  *----------------------------------------------------------------------------
  */
 #define JSVERIFY_STR(actual, expected, reason)                                                               \
-    if (strcmp((actual), (expected)) != 0) {                                                                 \
+    if (HDstrcmp((actual), (expected)) != 0) {                                                               \
         JSERR_STR((expected), (actual), (reason));                                                           \
         goto error;                                                                                          \
     } /* JSVERIFY_STR */
@@ -383,6 +381,7 @@ static H5FD_hdfs_fapl_t default_fa = {
     "",          /* kerberos path */
     1024,        /* buffer size */
 };
+#endif /*  H5_HAVE_LIBHDFS */
 
 /******************
  * TEST FUNCTIONS *
@@ -405,11 +404,21 @@ static H5FD_hdfs_fapl_t default_fa = {
  * Programmer:  Jacob Smith
  *              2018-04-25
  *
+ * Changes:     None.
+ *
  *---------------------------------------------------------------------------
  */
 static int
 test_fapl_config_validation(void)
 {
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS fapl configuration validation");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
     /*********************
      * test-local macros *
      *********************/
@@ -555,9 +564,10 @@ test_fapl_config_validation(void)
             JSVERIFY(config.version, fa_fetch.version, "version number mismatch")
             JSVERIFY(config.namenode_port, fa_fetch.namenode_port, "namenode port mismatch")
             JSVERIFY(config.stream_buffer_size, fa_fetch.stream_buffer_size, "streambuffer size mismatch")
-            JSVERIFY_STR(config.namenode_name, fa_fetch.namenode_name, NULL)
-            JSVERIFY_STR(config.user_name, fa_fetch.user_name, NULL)
-            JSVERIFY_STR(config.kerberos_ticket_cache, fa_fetch.kerberos_ticket_cache, NULL)
+            JSVERIFY_STR(config.namenode_name, fa_fetch.namenode_name, "node name mismatch")
+            JSVERIFY_STR(config.user_name, fa_fetch.user_name, "user name mismatch")
+            JSVERIFY_STR(config.kerberos_ticket_cache, fa_fetch.kerberos_ticket_cache,
+                         "kerberos ticket cache mismatch")
         }
 
         /*-----------------------------
@@ -585,7 +595,9 @@ error:
         H5E_END_TRY;
     }
     return 1;
-} /* test_fapl_config_validation */
+#endif /* H5_HAVE_LIBHDFS */
+
+} /* end test_fapl_config_validation() */
 
 /*-------------------------------------------------------------------------
  *
@@ -602,19 +614,29 @@ error:
  * Programmer:  Jacob Smith
  *              2018-04-25
  *
+ * Changes:     None.
+ *
  *-------------------------------------------------------------------------
  */
 static int
 test_hdfs_fapl(void)
 {
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS fapl ");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
     /************************
      * test-local variables *
      ************************/
 
-    hid_t            fapl_id      = -1; /* file access property list ID */
-    hid_t            driver_id    = -1; /* ID for this VFD              */
-    unsigned long    driver_flags = 0;  /* VFD feature flags            */
-    H5FD_hdfs_fapl_t hdfs_fa_0    = {
+    hid_t fapl_id = -1;             /* file access property list ID */
+    hid_t driver_id = -1;           /* ID for this VFD              */
+    unsigned long driver_flags = 0; /* VFD feature flags            */
+    H5FD_hdfs_fapl_t hdfs_fa_0 = {
         1,    /* version*/
         "",   /* node name */
         9000, /* node port */
@@ -659,8 +681,9 @@ error:
     H5E_END_TRY;
 
     return 1;
+#endif /* H5_HAVE_LIBHDFS */
 
-} /* test_hdfs_fapl() */
+} /* end test_hdfs_fapl() */
 
 /*---------------------------------------------------------------------------
  *
@@ -684,6 +707,15 @@ static int
 test_vfd_open(void)
 {
 
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS VFD-level open");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
+
     /*********************
      * test-local macros *
      *********************/
@@ -700,10 +732,10 @@ test_vfd_open(void)
     struct test_condition {
         const char *message;
         const char *url;
-        unsigned    flags;
-        int         which_fapl;
-        haddr_t     maxaddr;
-        hbool_t     might_use_other_driver;
+        unsigned flags;
+        int which_fapl;
+        haddr_t maxaddr;
+        hbool_t might_use_other_driver;
     };
 
     /************************
@@ -792,11 +824,11 @@ test_vfd_open(void)
             FALSE,
         },
     };
-    unsigned i                        = 0;
+    unsigned i = 0;
     unsigned failing_conditions_count = 10;
-    H5FD_t  *fd                       = NULL;
-    hid_t    fapl_hdfs                = -1;
-    hid_t    fapl_unconfigured        = -1;
+    H5FD_t *fd = NULL;
+    hid_t fapl_hdfs = -1;
+    hid_t fapl_unconfigured = -1;
 
     TESTING("HDFS VFD-level open");
 
@@ -814,8 +846,8 @@ test_vfd_open(void)
     /* all the test cases that will _not_ open
      */
     for (i = 0; i < failing_conditions_count; i++) {
-        struct test_condition T       = failing_conditions[i];
-        hid_t                 fapl_id = H5P_DEFAULT;
+        struct test_condition T = failing_conditions[i];
+        hid_t fapl_id = H5P_DEFAULT;
 
         fd = NULL;
 
@@ -881,6 +913,7 @@ test_vfd_open(void)
     return 0;
 
 error:
+
     /***********
      * CLEANUP *
      ***********/
@@ -905,7 +938,9 @@ error:
 #undef FAPL_UNCONFIGURED
 #undef FAPL_HDFS
 
-} /* test_vfd_open */
+#endif /* H5_HAVE_LIBHDFS */
+
+} /* end test_vfd_open() */
 
 /*---------------------------------------------------------------------------
  *
@@ -928,6 +963,14 @@ error:
 static int
 test_eof_eoa(void)
 {
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS eof/eoa gets and sets");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
 
     /*********************
      * test-local macros *
@@ -942,7 +985,7 @@ test_eof_eoa(void)
      ************************/
 
     H5FD_t *fd_shakespeare = NULL;
-    hid_t   fapl_id        = -1;
+    hid_t fapl_id = -1;
 
     TESTING("HDFS eof/eoa gets and sets");
 
@@ -963,19 +1006,21 @@ test_eof_eoa(void)
 
     /* verify as found
      */
-    JSVERIFY(5458199, H5FDget_eof(fd_shakespeare), NULL)
+    JSVERIFY(5458199, H5FDget_eof(fd_shakespeare, H5FD_MEM_DEFAULT), "EOF mismatch")
+    JSVERIFY(H5FDget_eof(fd_shakespeare, H5FD_MEM_DEFAULT), H5FDget_eof(fd_shakespeare, H5FD_MEM_DRAW),
+             "mismatch between DEFAULT and RAW memory types")
     JSVERIFY(0, H5FDget_eoa(fd_shakespeare, H5FD_MEM_DEFAULT), "EoA should be unset by H5FDopen")
 
     /* set EoA below EoF
      */
     JSVERIFY(SUCCEED, H5FDset_eoa(fd_shakespeare, H5FD_MEM_DEFAULT, 44442202), "unable to set EoA (lower)")
-    JSVERIFY(5458199, H5FDget_eof(fd_shakespeare), "EoF changed")
+    JSVERIFY(5458199, H5FDget_eof(fd_shakespeare, H5FD_MEM_DEFAULT), "EoF changed")
     JSVERIFY(44442202, H5FDget_eoa(fd_shakespeare, H5FD_MEM_DEFAULT), "EoA unchanged")
 
     /* set EoA above EoF
      */
     JSVERIFY(SUCCEED, H5FDset_eoa(fd_shakespeare, H5FD_MEM_DEFAULT, 6789012), "unable to set EoA (higher)")
-    JSVERIFY(5458199, H5FDget_eof(fd_shakespeare), "EoF changed")
+    JSVERIFY(5458199, H5FDget_eof(fd_shakespeare, H5FD_MEM_DEFAULT), "EoF changed")
     JSVERIFY(6789012, H5FDget_eoa(fd_shakespeare, H5FD_MEM_DEFAULT), "EoA unchanged")
 
     /************
@@ -992,6 +1037,7 @@ test_eof_eoa(void)
     return 0;
 
 error:
+
     /***********
      * CLEANUP *
      ***********/
@@ -1009,7 +1055,9 @@ error:
 
     return 1;
 
-} /* test_eof_eoa */
+#endif /* H5_HAVE_LIBHDFS */
+
+} /* end test_eof_eoa() */
 
 /*-----------------------------------------------------------------------------
  *
@@ -1028,10 +1076,19 @@ error:
 static int
 test_H5FDread_without_eoa_set_fails(void)
 {
-    char         buffer[HDFS_TEST_MAX_BUF_SIZE];
-    unsigned int i                = 0;
-    H5FD_t      *file_shakespeare = NULL;
-    hid_t        fapl_id          = -1;
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS VFD read-eoa temporal coupling library limitation");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
+
+    char buffer[HDFS_TEST_MAX_BUF_SIZE];
+    unsigned int i = 0;
+    H5FD_t *file_shakespeare = NULL;
+    hid_t fapl_id = -1;
 
     TESTING("HDFS VFD read-eoa temporal coupling library limitation");
 
@@ -1080,6 +1137,7 @@ test_H5FDread_without_eoa_set_fails(void)
     return 0;
 
 error:
+
     /***********
      * CLEANUP *
      ***********/
@@ -1097,7 +1155,9 @@ error:
 
     return 1;
 
-} /* test_H5FDread_without_eoa_set_fails */
+#endif /* H5_HAVE_LIBHDFS */
+
+} /* end test_H5FDread_without_eoa_set_fails() */
 
 /*---------------------------------------------------------------------------
  *
@@ -1118,6 +1178,14 @@ error:
 static int
 test_read(void)
 {
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS VFD read/range-gets");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
 
     /*********************
      * test-local macros *
@@ -1128,10 +1196,10 @@ test_read(void)
      *************************/
     struct testcase {
         const char *message;  /* purpose of test case */
-        haddr_t     eoa_set;  /* set file EOA to this prior to read */
-        size_t      addr;     /* offset of read in file */
-        size_t      len;      /* length of read in file */
-        herr_t      success;  /* expected return value of read function */
+        haddr_t eoa_set;      /* set file EOA to this prior to read */
+        size_t addr;          /* offset of read in file */
+        size_t len;           /* length of read in file */
+        herr_t success;       /* expected return value of read function */
         const char *expected; /* expected contents of buffer; failure ignores */
     };
 
@@ -1188,14 +1256,14 @@ test_read(void)
             NULL,
         },
     };
-    unsigned        testcase_count = 6;
-    unsigned        test_i         = 0;
+    unsigned testcase_count = 6;
+    unsigned test_i = 0;
     struct testcase test;
-    herr_t          open_return = FAIL;
-    char            buffer[HDFS_TEST_MAX_BUF_SIZE];
-    unsigned int    i          = 0;
-    H5FD_t         *file_raven = NULL;
-    hid_t           fapl_id    = -1;
+    herr_t open_return = FAIL;
+    char buffer[HDFS_TEST_MAX_BUF_SIZE];
+    unsigned int i = 0;
+    H5FD_t *file_raven = NULL;
+    hid_t fapl_id = -1;
 
     TESTING("HDFS VFD read/range-gets");
 
@@ -1220,7 +1288,7 @@ test_read(void)
                           HADDR_UNDEF); /* Demonstrate success with "automatic" value */
     FAIL_IF(NULL == file_raven)
 
-    JSVERIFY(6464, H5FDget_eof(file_raven), NULL)
+    JSVERIFY(6464, H5FDget_eof(file_raven, H5FD_MEM_DEFAULT), "EOF mismatch")
 
     /*********
      * TESTS *
@@ -1232,7 +1300,7 @@ test_read(void)
          * per-test setup *
          * -------------- */
 
-        test        = cases[test_i];
+        test = cases[test_i];
         open_return = FAIL;
 
         FAIL_IF(HDFS_TEST_MAX_BUF_SIZE < test.len) /* buffer too small! */
@@ -1240,8 +1308,9 @@ test_read(void)
         FAIL_IF(FAIL == H5FDset_eoa(file_raven, H5FD_MEM_DEFAULT, test.eoa_set))
 
         /* zero buffer contents */
-        for (i = 0; i < HDFS_TEST_MAX_BUF_SIZE; i++)
+        for (i = 0; i < HDFS_TEST_MAX_BUF_SIZE; i++) {
             buffer[i] = 0;
+        }
 
         /* ------------ *
          * conduct test *
@@ -1254,8 +1323,10 @@ test_read(void)
         H5E_END_TRY;
 
         JSVERIFY(test.success, open_return, test.message)
-        if (open_return == SUCCEED)
+
+        if (open_return == SUCCEED) {
             JSVERIFY_STR(test.expected, buffer, NULL)
+        }
 
     } /* for each testcase */
 
@@ -1273,12 +1344,14 @@ test_read(void)
     return 0;
 
 error:
+
     /***********
      * CLEANUP *
      ***********/
 
-    if (file_raven)
+    if (file_raven != 0) {
         (void)H5FDclose(file_raven);
+    }
     if (fapl_id >= 0) {
         H5E_BEGIN_TRY
         {
@@ -1289,7 +1362,9 @@ error:
 
     return 1;
 
-} /* test_read */
+#endif /* H5_HAVE_LIBHDFS */
+
+} /* end test_read() */
 
 /*---------------------------------------------------------------------------
  *
@@ -1308,11 +1383,24 @@ error:
  * Programmer: Jacob Smith
  *             2017-11-06
  *
+ * Changes:
+ *     + modify from S3VFD codebase to HDFS; Minor changes, mostly.
+ *         + Jacob Smith 2018-06-08
+ *
  *---------------------------------------------------------------------------
  */
 static int
 test_noops_and_autofails(void)
 {
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS VFD always-fail and no-op routines");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
+
     /*********************
      * test-local macros *
      *********************/
@@ -1325,8 +1413,8 @@ test_noops_and_autofails(void)
      * test-local variables *
      ************************/
 
-    hid_t      fapl_id  = -1;
-    H5FD_t    *file     = NULL;
+    hid_t fapl_id = -1;
+    H5FD_t *file = NULL;
     const char data[36] = "The Force shall be with you, always";
 
     TESTING("HDFS VFD always-fail and no-op routines");
@@ -1374,6 +1462,7 @@ test_noops_and_autofails(void)
     return 0;
 
 error:
+
     /***********
      * CLEANUP *
      ***********/
@@ -1385,13 +1474,15 @@ error:
         }
         H5E_END_TRY;
     }
-    if (file) {
+    if (file != NULL) {
         (void)H5FDclose(file);
     }
 
     return 1;
 
-} /* test_noops_and_autofails */
+#endif /* H5_HAVE_LIBHDFS */
+
+} /* end test_noops_and_autofails() */
 
 /*---------------------------------------------------------------------------
  *
@@ -1420,7 +1511,7 @@ test_cmp(void)
 
     return 0;
 
-} /* test_cmp */
+} /* end test_cmp() */
 
 /*---------------------------------------------------------------------------
  *
@@ -1438,11 +1529,24 @@ test_cmp(void)
  * Programmer: Jacob Smith
  *             2017-11-07
  *
+ * Changes:
+ *     + modify from S3VFD codebase to HDFS; Minor changes, mostly.
+ *         + Jacob Smith 2018-06-08
+ *
  *---------------------------------------------------------------------------
  */
 static int
 test_H5F_integration(void)
 {
+#ifndef H5_HAVE_LIBHDFS
+    TESTING("HDFS file access through HD5F library (H5F API)");
+    SKIPPED();
+    HDputs("    HDFS VFD is not enabled");
+    HDfflush(stdout);
+    return 0;
+
+#else
+
     /*********************
      * test-local macros *
      *********************/
@@ -1455,7 +1559,7 @@ test_H5F_integration(void)
      * test-local variables *
      ************************/
 
-    hid_t file    = -1;
+    hid_t file = -1;
     hid_t fapl_id = -1;
 
     TESTING("HDFS file access through HD5F library (H5F API)");
@@ -1506,7 +1610,7 @@ error:
 
 #if HDFS_TEST_DEBUG
     HDprintf("\nerror!");
-    fflush(stdout);
+    HDfflush(stdout);
 #endif /* HDFS_TEST_DEBUG */
 
     if (fapl_id >= 0) {
@@ -1516,15 +1620,16 @@ error:
         }
         H5E_END_TRY;
     }
-    if (file > 0)
+    if (file > 0) {
         (void)H5Fclose(file);
+    }
 
     return 1;
 
-} /* test_H5F_integration */
-
 #endif /* H5_HAVE_LIBHDFS */
 
+} /* test_H5F_integration */
+
 /*-------------------------------------------------------------------------
  *
  * Function:    main
@@ -1542,21 +1647,15 @@ error:
 int
 main(void)
 {
-#ifdef H5_HAVE_LIBHDFS
     int nerrors = 0;
 
-    static char hdfs_namenode_name[HDFS_NAMENODE_NAME_MAX_SIZE] = "";
-    const char *hdfs_namenode_name_env                          = NULL;
-
-#endif /* H5_HAVE_LIBHDFS */
-
-    HDprintf("Testing hdfs VFD functionality.\n");
+    /******************
+     * commence tests *
+     ******************/
 
 #ifdef H5_HAVE_LIBHDFS
-
-    /********************
-     * initialize tests *
-     ********************/
+    static char hdfs_namenode_name[HDFS_NAMENODE_NAME_MAX_SIZE] = "";
+    const char *hdfs_namenode_name_env                          = NULL;
 
     hdfs_namenode_name_env = HDgetenv("HDFS_TEST_NAMENODE_NAME");
     if (hdfs_namenode_name_env == NULL || hdfs_namenode_name_env[0] == '\0') {
@@ -1566,13 +1665,12 @@ main(void)
         HDstrncpy(/* TODO: error-check? */
                   default_fa.namenode_name, hdfs_namenode_name_env, HDFS_NAMENODE_NAME_MAX_SIZE);
     }
-
-    /******************
-     * commence tests *
-     ******************/
+#endif /* H5_HAVE_LIBHDFS */
 
     h5_reset();
 
+    HDprintf("Testing hdfs VFD functionality.\n");
+
     nerrors += test_fapl_config_validation();
     nerrors += test_hdfs_fapl();
     nerrors += test_vfd_open();
@@ -1592,10 +1690,4 @@ main(void)
     }
     return nerrors; /* 0 if no errors, 1 if any errors */
 
-#else
-    HDprintf("SKIPPED - HDFS VFD not built\n");
-    return EXIT_SUCCESS;
-
-#endif /* H5_HAVE_LIBHDFS */
-
-} /* main() */
+} /* end main() */
