@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -11,13 +10,13 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:    Robb Matzke <matzke@llnl.gov>
+/* Programmer:    Robb Matzke
  *        Wednesday, October 15, 1997
  *
  * Purpose:    Tests various aspects of indexed raw data storage.
  */
 
-#define H5F_PACKAGE /*suppress error about including H5Fpkg	  */
+#define H5F_FRIEND /*suppress error about including H5Fpkg      */
 
 #include "h5test.h"
 
@@ -271,20 +270,21 @@ test_extend(hid_t f, const char *prefix, size_t nx, size_t ny, size_t nz)
         if (!ny) {
             ndims = 1;
             ny = nz = 1;
-            HDsprintf(dims, "%lu", (unsigned long)nx);
+            HDsnprintf(dims, sizeof(dims), "%lu", (unsigned long)nx);
         }
         else {
             ndims = 2;
             nz    = 1;
-            HDsprintf(dims, "%lux%lu", (unsigned long)nx, (unsigned long)ny);
+            HDsnprintf(dims, sizeof(dims), "%lux%lu", (unsigned long)nx, (unsigned long)ny);
         }
     }
     else {
         ndims = 3;
-        HDsprintf(dims, "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny, (unsigned long)nz);
+        HDsnprintf(dims, sizeof(dims), "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny,
+                   (unsigned long)nz);
     }
 
-    HDsprintf(s, "istore extend: %s", dims);
+    HDsnprintf(s, sizeof(s), "istore extend: %s", dims);
     TESTING(s);
     buf   = (uint8_t *)HDmalloc(nx * ny * nz);
     check = (uint8_t *)HDmalloc(nx * ny * nz);
@@ -298,7 +298,7 @@ test_extend(hid_t f, const char *prefix, size_t nx, size_t ny, size_t nz)
     max_corner[2] = 0;
 
     /* Build the new empty object */
-    HDsprintf(name, "%s_%s", prefix, dims);
+    HDsnprintf(name, sizeof(name), "%s_%s", prefix, dims);
     if ((dataset = new_object(f, name, ndims, whole_size, whole_size)) < 0) {
         HDfprintf(stderr, "    Cannot create %u-d object `%s'\n", ndims, name);
         goto error;
@@ -330,25 +330,6 @@ test_extend(hid_t f, const char *prefix, size_t nx, size_t ny, size_t nz)
             }
         }
 
-#if 0
-    if (0 == ctr)
-        HDfprintf(stderr,"\n");
-    HDfprintf(stderr,"    Insert: ctr=%lu, corner=(%ld", (unsigned long)ctr, (long)offset[0]);
-    if (ndims > 1)
-        HDfprintf(stderr,",%ld", (long)offset[1]);
-    if (ndims > 2)
-        HDfprintf(stderr,",%ld", (long)offset[2]);
-    HDfprintf(stderr,"), size=(%lu", (unsigned long)size[0]);
-    if (ndims > 1)
-        HDfprintf(stderr,",%lu", (unsigned long)size[1]);
-    if (ndims > 2)
-        HDfprintf(stderr,",%lu", (unsigned long)size[2]);
-    HDfprintf(stderr,"), %lu element%s", (unsigned long)nelmts, 1 == nelmts ? "" : "s");
-    if (0 == nelmts)
-        HDfprintf(stderr," *SKIPPED*");
-    HDfprintf(stderr,"\n");
-#endif
-
         /* Fill the source array */
         if (0 == nelmts)
             continue;
@@ -376,7 +357,7 @@ test_extend(hid_t f, const char *prefix, size_t nx, size_t ny, size_t nz)
             HDfprintf(stderr, "    Read failed: ctr=%lu\n", (unsigned long)ctr);
             goto error;
         }
-        if (HDmemcmp(buf, check, (size_t)nelmts)) {
+        if (HDmemcmp(buf, check, (size_t)nelmts) != 0) {
             H5_FAILED();
             HDfprintf(stderr, "    Read check failed: ctr=%lu\n", (unsigned long)ctr);
             HDfprintf(stderr, "    Wrote:\n");
@@ -478,7 +459,7 @@ test_sparse(hid_t f, const char *prefix, size_t nblocks, size_t nx, size_t ny, s
     hsize_t  ctr;
     char     dims[64], s[256], name[256];
     hsize_t  offset[3];
-    hsize_t  size[3], total = 0;
+    hsize_t  size[3];
     uint8_t *buf = NULL;
     hsize_t  whole_size[3]; /* Size of dataset's dataspace */
     size_t   u;             /* Local index variable */
@@ -487,23 +468,24 @@ test_sparse(hid_t f, const char *prefix, size_t nblocks, size_t nx, size_t ny, s
         if (!ny) {
             ndims = 1;
             ny = nz = 1;
-            HDsprintf(dims, "%lu", (unsigned long)nx);
+            HDsnprintf(dims, sizeof(dims), "%lu", (unsigned long)nx);
         }
         else {
             ndims = 2;
             nz    = 1;
-            HDsprintf(dims, "%lux%lu", (unsigned long)nx, (unsigned long)ny);
+            HDsnprintf(dims, sizeof(dims), "%lux%lu", (unsigned long)nx, (unsigned long)ny);
         }
     }
     else {
         ndims = 3;
-        HDsprintf(dims, "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny, (unsigned long)nz);
+        HDsnprintf(dims, sizeof(dims), "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny,
+                   (unsigned long)nz);
     }
 
-    HDsprintf(s, "istore sparse: %s", dims);
+    HDsnprintf(s, sizeof(s), "istore sparse: %s", dims);
     TESTING(s);
     if (skip_test) {
-        SKIPPED()
+        SKIPPED();
         return SUCCEED;
     }
     buf = (uint8_t *)HDmalloc(nx * ny * nz);
@@ -519,7 +501,7 @@ test_sparse(hid_t f, const char *prefix, size_t nblocks, size_t nx, size_t ny, s
     size[2] = nz;
 
     /* Build the new empty object */
-    HDsprintf(name, "%s_%s", prefix, dims);
+    HDsnprintf(name, sizeof(name), "%s_%s", prefix, dims);
     if ((dataset = new_object(f, name, ndims, whole_size, chunk_dims)) < 0) {
         HDprintf("    Cannot create %u-d object `%s'\n", ndims, name);
         goto error;
@@ -559,10 +541,6 @@ test_sparse(hid_t f, const char *prefix, size_t nblocks, size_t nx, size_t ny, s
             HDprintf(")\n");
             goto error;
         }
-        total += nx * ny * nz;
-#if 0
-    HDfprintf(stderr,"ctr: ctr=%Zu, total=%Zu\n", ctr, total);
-#endif
 
         /* We don't test reading yet.... */
     }
@@ -619,13 +597,13 @@ main(int argc, char *argv[])
     else {
         int i;
         for (i = 1, size_of_test = 0; i < argc; i++) {
-            if (!strcmp(argv[i], "small")) {
+            if (!HDstrcmp(argv[i], "small")) {
                 size_of_test |= TEST_SMALL;
             }
-            else if (!strcmp(argv[i], "medium")) {
+            else if (!HDstrcmp(argv[i], "medium")) {
                 size_of_test |= TEST_MEDIUM;
             }
-            else if (!strcmp(argv[i], "large")) {
+            else if (!HDstrcmp(argv[i], "large")) {
                 size_of_test |= TEST_LARGE;
             }
             else {
