@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -15,7 +14,7 @@
  * Purpose:    Tests hard, soft (symbolic) & external links.
  */
 
-#define H5G_PACKAGE
+#define H5G_FRIEND /*suppress error about including H5Gpkg      */
 #define H5G_TESTING
 
 #include "h5test.h"
@@ -63,14 +62,14 @@ external_link_env(hid_t fapl, hbool_t new_format)
         filename3[NAME_BUF_SIZE]; /* Holders for filename */
 
     if (new_format)
-        TESTING("external links via environment variable (w/new group format)")
+        TESTING("external links via environment variable (w/new group format)");
     else
-        TESTING("external links via environment variable")
+        TESTING("external links via environment variable");
 
     if ((envval = HDgetenv("HDF5_EXT_PREFIX")) == NULL)
         envval = "nomatch";
-    if (HDstrcmp(envval, ".:tmp_links_env"))
-        TEST_ERROR
+    if (HDstrcmp(envval, ".:tmp_links_env") != 0)
+        TEST_ERROR;
 
     /* Set up name for main file:"extlinks_env0" */
     h5_fixname(FILENAME[0], fapl, filename1, sizeof filename1);
@@ -80,30 +79,30 @@ external_link_env(hid_t fapl, hbool_t new_format)
 
     /* Create "tmp_links_env" directory */
     if (HDmkdir(TMPDIR, (mode_t)0755) < 0 && errno != EEXIST)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Set up name (location) for the target file: "tmp_links_env/extlinks1" */
     h5_fixname(FILENAME[2], fapl, filename3, sizeof filename3);
 
     /* Create the target file in "tmp_links_env" directory */
     if ((fid = H5Fcreate(filename3, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if ((gid = H5Gcreate2(fid, "A", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Closing for target file */
     if (H5Gclose(gid) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Fclose(fid) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Create the main file */
     if ((fid = H5Fcreate(filename1, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Create external link to target file */
     if (H5Lcreate_external(filename2, "/A", fid, "ext_link", H5P_DEFAULT, H5P_DEFAULT) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Open object through external link */
     H5E_BEGIN_TRY
@@ -115,15 +114,15 @@ external_link_env(hid_t fapl, hbool_t new_format)
     /* Should be able to find the target file from pathnames set via HDF5_EXT_PREFIX */
     if (gid < 0) {
         H5_FAILED();
-        puts("    Should have found the file in tmp_links_env directory.");
+        HDputs("    Should have found the file in tmp_links_env directory.");
         goto error;
     }
 
     /* closing for main file */
     if (H5Gclose(gid) < 0)
-        TEST_ERROR
+        TEST_ERROR;
     if (H5Fclose(fid) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     PASSED();
     return 0;
@@ -152,8 +151,20 @@ error:
 int
 main(void)
 {
-    hid_t fapl;        /* File access property lists */
-    int   nerrors = 0; /* Error from tests */
+    const char *env_h5_drvr; /* File driver value from environment */
+    hid_t       fapl;        /* File access property lists */
+    int         nerrors = 0; /* Error from tests */
+
+    /* Get the VFD to use */
+    env_h5_drvr = HDgetenv(HDF5_DRIVER);
+    if (env_h5_drvr == NULL)
+        env_h5_drvr = "nomatch";
+
+    /* Splitter VFD has issues with external links */
+    if (!HDstrcmp(env_h5_drvr, "splitter")) {
+        HDputs(" -- SKIPPED for incompatible VFD --");
+        HDexit(EXIT_SUCCESS);
+    }
 
     h5_reset();
     fapl = h5_fileaccess();
@@ -162,7 +173,7 @@ main(void)
 
     /* Set the "use the latest version of the format" bounds for creating objects in the file */
     if (H5Pset_libver_bounds(fapl, H5F_LIBVER_LATEST, H5F_LIBVER_LATEST) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     nerrors += external_link_env(fapl, TRUE) < 0 ? 1 : 0;
 
