@@ -47,7 +47,7 @@
  *     4) Configurable expected-actual order in generated comparison strings.
  *        Some prefer `VERIFY(expected, actual)`, others
  *        `VERIFY(actual, expected)`. Provide preprocessor ifdef switch
- *        to satifsy both parties, assuming one paradigm per test file.
+ *        to satisfy both parties, assuming one paradigm per test file.
  *        (One could #undef and redefine the flag through the file as desired,
  *         but _why_.)
  *        Provided as courtesy, per consideration for inclusion in the library
@@ -96,7 +96,7 @@
  */
 #define JSFAILED_AT()                                                                                        \
     {                                                                                                        \
-        HDprintf("*FAILED* at %s:%d in %s()...\n", __FILE__, __LINE__, FUNC);                                \
+        HDprintf("*FAILED* at %s:%d in %s()...\n", __FILE__, __LINE__, __func__);                            \
     }
 
 /*----------------------------------------------------------------------------
@@ -181,15 +181,21 @@
  *
  *----------------------------------------------------------------------------
  */
+static inline void
+jserr_long(long expected, long actual, const char *reason)
+{
+    if (reason != NULL) {
+        HDprintf("%s\n", reason);
+    }
+    else {
+        HDprintf("  ! Expected %ld\n  ! Actual   %ld\n", expected, actual);
+    }
+}
+
 #define JSERR_LONG(expected, actual, reason)                                                                 \
     {                                                                                                        \
         JSFAILED_AT()                                                                                        \
-        if (reason != NULL) {                                                                                \
-            HDprintf("%s\n", (reason));                                                                      \
-        }                                                                                                    \
-        else {                                                                                               \
-            HDprintf("  ! Expected %ld\n  ! Actual   %ld\n", (long)(expected), (long)(actual));              \
-        }                                                                                                    \
+        jserr_long((long)(expected), (long)(actual), reason);                                                \
     }
 
 /*----------------------------------------------------------------------------
@@ -220,19 +226,25 @@
  *
  *----------------------------------------------------------------------------
  */
+static inline void
+jserr_str(const char *expected, const char *actual, const char *reason)
+{
+    if (reason != NULL) {
+        HDprintf("%s\n", reason);
+    }
+    else {
+        HDprintf("!!! Expected:\n%s\n!!!Actual:\n%s\n", expected, actual);
+    }
+}
+
 #define JSERR_STR(expected, actual, reason)                                                                  \
     {                                                                                                        \
         JSFAILED_AT()                                                                                        \
-        if ((reason) != NULL) {                                                                              \
-            HDprintf("%s\n", (reason));                                                                      \
-        }                                                                                                    \
-        else {                                                                                               \
-            HDprintf("!!! Expected:\n%s\n!!!Actual:\n%s\n", (expected), (actual));                           \
-        }                                                                                                    \
+        jserr_str((expected), (actual), (reason));                                                           \
     }
 
 #ifdef JSVERIFY_EXP_ACT
-/* VERIFY rountines with paramter order (<expected>, <actual> [, <msg> ])
+/* VERIFY routines with parameter order (<expected>, <actual> [, <msg> ])
  */
 
 /*----------------------------------------------------------------------------
@@ -299,7 +311,7 @@
  *----------------------------------------------------------------------------
  */
 #define JSVERIFY_STR(expected, actual, reason)                                                               \
-    if (strcmp((actual), (expected)) != 0) {                                                                 \
+    if (HDstrcmp((actual), (expected)) != 0) {                                                               \
         JSERR_STR((expected), (actual), (reason));                                                           \
         goto error;                                                                                          \
     } /* JSVERIFY_STR */
@@ -347,7 +359,7 @@
  *----------------------------------------------------------------------------
  */
 #define JSVERIFY_STR(actual, expected, reason)                                                               \
-    if (strcmp((actual), (expected)) != 0) {                                                                 \
+    if (HDstrcmp((actual), (expected)) != 0) {                                                               \
         JSERR_STR((expected), (actual), (reason));                                                           \
         goto error;                                                                                          \
     } /* JSVERIFY_STR */
@@ -423,7 +435,7 @@ error:
  *
  * Purpose:
  *
- *     Demonstrate the construction of a Canoncial Request (and Signed Headers)
+ *     Demonstrate the construction of a Canonical Request (and Signed Headers)
  *
  *     Elided / not yet implemented:
  *         Query strings
@@ -718,7 +730,7 @@ test_hrb_init_request(void)
             FALSE,
         },
         {
-            "null verb substitues to GET",
+            "null verb substitutes to GET",
             NULL,
             "/MYPATH/MYFILE.tiff",
             "/MYPATH/MYFILE.tiff",
@@ -1131,10 +1143,10 @@ test_hrb_node_set(void)
          *********/
 
         for (mock_i = 0; test->given[mock_i] != NULL; mock_i += 2) {
-            const char *name = test->given[mock_i];
-            const char *valu = test->given[mock_i + 1];
+            const char *name  = test->given[mock_i];
+            const char *value = test->given[mock_i + 1];
 
-            FAIL_IF(SUCCEED != H5FD_s3comms_hrb_node_set(&list, name, valu))
+            FAIL_IF(SUCCEED != H5FD_s3comms_hrb_node_set(&list, name, value))
         }
         /********
          * TEST *
@@ -1150,11 +1162,11 @@ test_hrb_node_set(void)
         node   = list;
         mock_i = 0;
         while (test->expected[mock_i] != NULL && node != NULL) {
-            const char *name = test->expected[mock_i];
-            const char *valu = test->expected[mock_i + 1];
+            const char *name  = test->expected[mock_i];
+            const char *value = test->expected[mock_i + 1];
 
             JSVERIFY_STR(name, node->name, NULL)
-            JSVERIFY_STR(valu, node->value, NULL)
+            JSVERIFY_STR(value, node->value, NULL)
 
             mock_i += 2;
             node = node->next;
@@ -1269,10 +1281,10 @@ test_HMAC_SHA256(void)
             cases[i].msg);
         if (cases[i].ret == SUCCEED) {
 #ifdef VERBOSE
-            if (0 != strncmp(cases[i].exp, dest, HDstrlen(cases[i].exp))) {
+            if (0 != HDstrncmp(cases[i].exp, dest, HDstrlen(cases[i].exp))) {
                 /* print out how wrong things are, and then fail
                  */
-                dest = (char *)realloc(dest, cases[i].dest_size + 1);
+                dest = (char *)HDrealloc(dest, cases[i].dest_size + 1);
                 HDassert(dest != NULL);
                 dest[cases[i].dest_size] = 0;
                 HDfprintf(stdout, "ERROR:\n!!! \"%s\"\n != \"%s\"\n", cases[i].exp, dest);
@@ -1281,17 +1293,17 @@ test_HMAC_SHA256(void)
 #else  /* VERBOSE not defined */
             /* simple pass/fail test
              */
-            JSVERIFY(0, strncmp(cases[i].exp, dest, HDstrlen(cases[i].exp)), NULL);
+            JSVERIFY(0, HDstrncmp(cases[i].exp, dest, HDstrlen(cases[i].exp)), NULL);
 #endif /* VERBOSE */
         }
-        free(dest);
+        HDfree(dest);
     }
 
     PASSED();
     return 0;
 
 error:
-    free(dest);
+    HDfree(dest);
     return -1;
 
 } /* end test_HMAC_SHA256() */
@@ -1357,18 +1369,18 @@ test_nlowercase(void)
 
         JSVERIFY(SUCCEED, H5FD_s3comms_nlowercase(dest, cases[i].in, cases[i].len), cases[i].in)
         if (cases[i].len > 0) {
-            JSVERIFY(0, strncmp(dest, cases[i].exp, cases[i].len), NULL)
+            JSVERIFY(0, HDstrncmp(dest, cases[i].exp, cases[i].len), NULL)
         }
-        free(dest);
+        HDfree(dest);
     } /* end for each testcase */
 
-    JSVERIFY(FAIL, H5FD_s3comms_nlowercase(NULL, cases[0].in, cases[0].len), "null distination should fail")
+    JSVERIFY(FAIL, H5FD_s3comms_nlowercase(NULL, cases[0].in, cases[0].len), "null destination should fail")
 
     PASSED();
     return 0;
 
 error:
-    free(dest);
+    HDfree(dest);
     return -1;
 
 } /* end test_nlowercase() */
@@ -1547,7 +1559,7 @@ test_parse_url(void)
                 NULL,
                 "a=b&d=b",
             },
-            "QUERY with implict PATH",
+            "QUERY with implicit PATH",
         },
         {
             "http://[5]/path?a=b&d=b",
@@ -1729,7 +1741,7 @@ test_percent_encode_char(void)
         JSVERIFY(SUCCEED, H5FD_s3comms_percent_encode_char(dest, (const unsigned char)cases[i].c, &dest_len),
                  NULL)
         JSVERIFY(cases[i].exp_len, dest_len, NULL)
-        JSVERIFY(0, strncmp(dest, cases[i].exp, dest_len), NULL)
+        JSVERIFY(0, HDstrncmp(dest, cases[i].exp, dest_len), NULL)
         JSVERIFY_STR(cases[i].exp, dest, NULL)
     }
 
@@ -1768,8 +1780,8 @@ test_s3r_get_filesize(void)
      */
     if (FALSE == s3_test_bucket_defined) {
         SKIPPED();
-        puts("    environment variable HDF5_ROS3_TEST_BUCKET_URL not defined");
-        fflush(stdout);
+        HDputs("    environment variable HDF5_ROS3_TEST_BUCKET_URL not defined");
+        HDfflush(stdout);
         return 0;
     }
 
@@ -1828,14 +1840,14 @@ test_s3r_open(void)
 
     if (s3_test_credentials_loaded == 0) {
         SKIPPED();
-        puts("    s3 credentials are not loaded");
-        fflush(stdout);
+        HDputs("    s3 credentials are not loaded");
+        HDfflush(stdout);
         return 0;
     }
     if (FALSE == s3_test_bucket_defined) {
         SKIPPED();
-        puts("    environment variable HDF5_ROS3_TEST_BUCKET_URL not defined");
-        fflush(stdout);
+        HDputs("    environment variable HDF5_ROS3_TEST_BUCKET_URL not defined");
+        HDfflush(stdout);
         return 0;
     }
 
@@ -1861,7 +1873,7 @@ test_s3r_open(void)
         FAIL_IF(purl->port == NULL);
         FAIL_IF(5 < HDsnprintf(purl->port, 5, "9000"))
     }
-    else if (strcmp(purl->port, "9000") != 0) {
+    else if (HDstrcmp(purl->port, "9000") != 0) {
         FAIL_IF(5 < HDsnprintf(purl->port, 5, "9000"))
     }
     else {
@@ -2002,7 +2014,7 @@ error:
  *     H5FD_s3comms_s3r_read    << called by getsize(), multiple times working
  *     H5FD_s3comms_s3r_close
  *
- *     Shows most basic curl interation.
+ *     Shows most basic curl iteration.
  *
  * Programmer: Jacob Smith
  *             2017-10-06
@@ -2032,8 +2044,8 @@ test_s3r_read(void)
      */
     if (FALSE == s3_test_bucket_defined) {
         SKIPPED();
-        puts("    environment variable HDF5_ROS3_TEST_BUCKET_URL not defined");
-        fflush(stdout);
+        HDputs("    environment variable HDF5_ROS3_TEST_BUCKET_URL not defined");
+        HDfflush(stdout);
         return 0;
     }
 
@@ -2093,7 +2105,7 @@ test_s3r_read(void)
     JSVERIFY(SUCCEED, H5FD_s3comms_s3r_read(handle, (haddr_t)6370, (size_t)0, buffer), NULL)
     JSVERIFY(
         0,
-        strncmp(
+        HDstrncmp(
             buffer,
             "And my soul from out that shadow that lies floating on the floor\nShall be lifted—nevermore!\n",
             94),
@@ -2110,7 +2122,7 @@ test_s3r_read(void)
              H5FD_s3comms_s3r_read(handle, (haddr_t)6400, (size_t)100, /* 6400+100 > 6464 */
                                    buffer),
              NULL)
-    JSVERIFY(0, strcmp("", buffer), NULL)
+    JSVERIFY(0, HDstrcmp("", buffer), NULL)
 
     /************************
      * read starts past eof *
@@ -2120,14 +2132,14 @@ test_s3r_read(void)
              H5FD_s3comms_s3r_read(handle, (haddr_t)1200699, /* 1200699 > 6464 */
                                    (size_t)100, buffer),
              NULL)
-    JSVERIFY(0, strcmp("", buffer), NULL)
+    JSVERIFY(0, HDstrcmp("", buffer), NULL)
 
     /**********************
      * read starts on eof *
      **********************/
 
     JSVERIFY(FAIL, H5FD_s3comms_s3r_read(handle, (haddr_t)6464, (size_t)0, buffer), NULL)
-    JSVERIFY(0, strcmp("", buffer), NULL)
+    JSVERIFY(0, HDstrcmp("", buffer), NULL)
 
     /*************
      * TEAR DOWN *
@@ -2217,10 +2229,10 @@ test_signing_key(void)
         JSVERIFY(SUCCEED, H5FD_s3comms_signing_key(key, cases[i].secret_key, cases[i].region, cases[i].when),
                  NULL)
 
-        JSVERIFY(0, strncmp((const char *)cases[i].exp, (const char *)key, SHA256_DIGEST_LENGTH),
-                 cases[i].exp)
+        JSVERIFY(0, HDstrncmp((const char *)cases[i].exp, (const char *)key, SHA256_DIGEST_LENGTH),
+                 (const char *)cases[i].exp)
 
-        free(key);
+        HDfree(key);
         key = NULL;
     }
 
@@ -2243,7 +2255,7 @@ test_signing_key(void)
     JSVERIFY(FAIL, H5FD_s3comms_signing_key(key, cases[0].secret_key, cases[0].region, NULL),
              "time string cannot be NULL")
 
-    free(key);
+    HDfree(key);
     key = NULL;
 
     PASSED();
@@ -2251,7 +2263,7 @@ test_signing_key(void)
 
 error:
     if (key != NULL) {
-        free(key);
+        HDfree(key);
     }
 
     return -1;
@@ -2399,9 +2411,9 @@ test_trim(void)
         JSVERIFY(SUCCEED, H5FD_s3comms_trim(dest, str, cases[i].in_len, &dest_len), NULL)
         JSVERIFY(cases[i].exp_len, dest_len, cases[i].in)
         if (dest_len > 0) {
-            JSVERIFY(0, strncmp(cases[i].exp, dest, dest_len), cases[i].exp)
+            JSVERIFY(0, HDstrncmp(cases[i].exp, dest, dest_len), cases[i].exp)
         }
-        free(str);
+        HDfree(str);
         str = NULL;
     } /* end for each testcase */
 
@@ -2412,9 +2424,9 @@ test_trim(void)
     HDassert(str == NULL);
     str = (char *)HDmalloc(sizeof(char *) * 11);
     HDassert(str != NULL);
-    memcpy(str, "some text ", 11); /* string with null terminator */
+    HDmemcpy(str, "some text ", 11); /* string with null terminator */
     JSVERIFY(FAIL, H5FD_s3comms_trim(NULL, str, 10, &dest_len), "destination for trim cannot be NULL");
-    free(str);
+    HDfree(str);
     str = NULL;
 
     PASSED();
@@ -2422,7 +2434,7 @@ test_trim(void)
 
 error:
     if (str != NULL) {
-        free(str);
+        HDfree(str);
     }
     return -1;
 
@@ -2502,7 +2514,7 @@ test_uriencode(void)
     int             ncases       = 6;
     size_t          str_len      = 0;
 
-    TESTING("s3comms uriencode")
+    TESTING("s3comms uriencode");
 
     for (i = 0; i < ncases; i++) {
         str_len = cases[i].s_len;
@@ -2513,9 +2525,9 @@ test_uriencode(void)
                  H5FD_s3comms_uriencode(dest, cases[i].str, str_len, cases[i].encode_slash, &dest_written),
                  NULL);
         JSVERIFY(HDstrlen(cases[i].expected), dest_written, NULL)
-        JSVERIFY(0, strncmp(dest, cases[i].expected, dest_written), cases[i].expected);
+        JSVERIFY(0, HDstrncmp(dest, cases[i].expected, dest_written), cases[i].expected);
 
-        free(dest);
+        HDfree(dest);
         dest = NULL;
     } /* end for each testcase */
 
@@ -2531,7 +2543,7 @@ test_uriencode(void)
     JSVERIFY(FAIL, H5FD_s3comms_uriencode(dest, NULL, 5, FALSE, &dest_written),
              "source string cannot be NULL");
 
-    free(dest);
+    HDfree(dest);
     dest = NULL;
 
     PASSED();
@@ -2539,7 +2551,7 @@ test_uriencode(void)
 
 error:
     if (dest != NULL) {
-        free(dest);
+        HDfree(dest);
     }
     return -1;
 
@@ -2598,7 +2610,7 @@ main(void)
 
     bucket_url_env = HDgetenv("HDF5_ROS3_TEST_BUCKET_URL");
     if (bucket_url_env == NULL || bucket_url_env[0] == '\0') {
-        HDprintf("WARNING: S3 bucket url is not defined in enviornment "
+        HDprintf("WARNING: S3 bucket url is not defined in environment "
                  "variable 'HDF5_ROS3_TEST_BUCKET_URL'!\n");
     }
     else {
@@ -2606,7 +2618,7 @@ main(void)
         s3_test_bucket_defined = TRUE;
     }
 
-    /* tests ordered rougly by dependence */
+    /* tests ordered roughly by dependence */
     nerrors += test_macro_format_credential() < 0 ? 1 : 0;
     nerrors += test_trim() < 0 ? 1 : 0;
     nerrors += test_nlowercase() < 0 ? 1 : 0;
