@@ -350,6 +350,7 @@ main(int argc, char **argv)
     AddTest("mpiodup", test_fapl_mpio_dup, NULL, "fapl_mpio duplicate", NULL);
 
     AddTest("split", test_split_comm_access, NULL, "dataset using split communicators", PARATESTFILE);
+    AddTest("h5oflusherror", test_oflush, NULL, "H5Oflush failure", PARATESTFILE);
 
 #ifdef PB_OUT /* temporary: disable page buffering when parallel */
     AddTest("page_buffer", test_page_buffer_access, NULL, "page buffer usage in parallel", PARATESTFILE);
@@ -357,8 +358,7 @@ main(int argc, char **argv)
 
     AddTest("props", test_file_properties, NULL, "Coll Metadata file property settings", PARATESTFILE);
 
-    AddTest("invlibverassert", test_invalid_libver_bounds_file_close_assert, NULL,
-            "Invalid libver bounds assertion failure", PARATESTFILE);
+    AddTest("delete", test_delete, NULL, "MPI-IO VFD file delete", PARATESTFILE);
 
     AddTest("idsetw", dataset_writeInd, NULL, "dataset independent write", PARATESTFILE);
     AddTest("idsetr", dataset_readInd, NULL, "dataset independent read", PARATESTFILE);
@@ -374,8 +374,6 @@ main(int argc, char **argv)
     AddTest("selnone", none_selection_chunk, NULL, "chunked dataset with none-selection", PARATESTFILE);
     AddTest("calloc", test_chunk_alloc, NULL, "parallel extend Chunked allocation on serial file",
             PARATESTFILE);
-    AddTest("chkallocser2par", test_chunk_alloc_incr_ser_to_par, NULL,
-            "chunk allocation from serial to parallel file access", PARATESTFILE);
     AddTest("fltread", test_filter_read, NULL, "parallel read of dataset written serially with filters",
             PARATESTFILE);
 
@@ -476,6 +474,8 @@ main(int argc, char **argv)
 
     AddTest("edpl", test_plist_ed, NULL, "encode/decode Property Lists", NULL);
 
+    AddTest("extlink", external_links, NULL, "test external links", NULL);
+
     if ((mpi_size < 2) && MAINPROCESS) {
         HDprintf("File Image Ops daisy chain test needs at least 2 processes.\n");
         HDprintf("File Image Ops daisy chain test will be skipped \n");
