@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -29,9 +28,6 @@
 #define START_OF_DATA       0x0001
 #define END_OF_DATA         0x0002
 
-/* format for hsize_t */
-#define HSIZE_T_FORMAT "%" H5_PRINTF_LL_WIDTH "u"
-
 #define H5TOOLS_DUMP_MAX_RANK H5S_MAX_RANK
 
 /* Stream macros */
@@ -353,11 +349,11 @@ typedef struct h5tool_format_t {
      *
      *   listv:    h5watch: vector containing info about the list of compound fields to be printed.
      */
-    const char *                     cmpd_name;
-    const char *                     cmpd_sep;
-    const char *                     cmpd_pre;
-    const char *                     cmpd_suf;
-    const char *                     cmpd_end;
+    const char                      *cmpd_name;
+    const char                      *cmpd_sep;
+    const char                      *cmpd_pre;
+    const char                      *cmpd_suf;
+    const char                      *cmpd_end;
     const struct H5LD_memb_t *const *cmpd_listv;
 
     /*
@@ -513,7 +509,7 @@ typedef struct h5tool_format_t {
 } h5tool_format_t;
 
 typedef struct subset_d {
-    hsize_t *    data;
+    hsize_t     *data;
     unsigned int len;
 } subset_d;
 
@@ -553,6 +549,7 @@ typedef struct h5tools_context_t {
  */
 
 typedef enum { VOL_BY_NAME, VOL_BY_VALUE } h5tools_vol_info_type_t;
+typedef enum { VFD_BY_NAME, VFD_BY_VALUE } h5tools_vfd_info_type_t;
 
 typedef struct h5tools_vol_info_t {
     h5tools_vol_info_type_t type;
@@ -562,29 +559,33 @@ typedef struct h5tools_vol_info_t {
 
     /* Field specifying either the connector's name or value (ID) */
     union {
-        const char *       name;
+        const char        *name;
         H5VL_class_value_t value;
     } u;
 } h5tools_vol_info_t;
 
 typedef struct h5tools_vfd_info_t {
+    h5tools_vfd_info_type_t type;
 
     /* Pointer to information to be passed to the driver for its setup */
     const void *info;
 
-    /* Name of the VFD */
-    const char *name;
+    /* Field specifying either the driver's name or value (ID) */
+    union {
+        const char        *name;
+        H5FD_class_value_t value;
+    } u;
 } h5tools_vfd_info_t;
 
-/* This enum should match the entries in the above 'volnames'
- * since they are indices into the 'volnames' array. */
+/* This enum should match the entries in the 'volnames'
+ * array since they are indices into that array. */
 typedef enum {
     NATIVE_VOL_IDX = 0,
     PASS_THROUGH_VOL_IDX,
 } vol_idx;
 
-/* This enum should match the entries in the above 'drivernames'
- * since they are indices into the 'drivernames' array. */
+/* This enum should match the entries in the 'drivernames'
+ * array since they are indices into that array. */
 typedef enum {
     SEC2_VFD_IDX = 0,
     DIRECT_VFD_IDX,
@@ -598,6 +599,8 @@ typedef enum {
     MPIO_VFD_IDX,
     ROS3_VFD_IDX,
     HDFS_VFD_IDX,
+    SUBFILING_VFD_IDX,
+    ONION_VFD_IDX,
 } driver_idx;
 
 /* The following include, h5tools_str.h, must be after the
@@ -613,29 +616,29 @@ extern "C" {
 H5TOOLS_DLLVAR const char *volnames[];
 H5TOOLS_DLLVAR const char *drivernames[];
 
-H5TOOLS_DLLVAR h5tool_format_t             h5tools_dataformat;
-H5TOOLS_DLLVAR const h5tools_dump_header_t h5tools_standardformat;
+H5TOOLS_DLLVAR h5tool_format_t              h5tools_dataformat;
+H5TOOLS_DLLVAR const h5tools_dump_header_t  h5tools_standardformat;
 H5TOOLS_DLLVAR const h5tools_dump_header_t *h5tools_dump_header_format;
 H5TOOLS_DLLVAR H5E_auto2_t                  lib_func;
 H5TOOLS_DLLVAR H5E_auto2_t                  tools_func;
-H5TOOLS_DLLVAR void *                       lib_edata;
-H5TOOLS_DLLVAR void *                       tools_edata;
+H5TOOLS_DLLVAR void                        *lib_edata;
+H5TOOLS_DLLVAR void                        *tools_edata;
 
 H5TOOLS_DLLVAR unsigned           packed_bits_num;    /* number of packed bits to display */
 H5TOOLS_DLLVAR unsigned           packed_data_offset; /* offset of packed bits to display */
 H5TOOLS_DLLVAR unsigned           packed_data_length; /* length of packed bits to display */
 H5TOOLS_DLLVAR unsigned long long packed_data_mask;   /* mask in which packed bits to display */
-H5TOOLS_DLLVAR FILE *rawattrstream;                   /* output stream for raw attribute data */
-H5TOOLS_DLLVAR FILE *rawdatastream;                   /* output stream for raw data */
-H5TOOLS_DLLVAR FILE *rawinstream;                     /* input stream for raw input */
-H5TOOLS_DLLVAR FILE *rawoutstream;                    /* output stream for raw output */
-H5TOOLS_DLLVAR FILE *rawerrorstream;                  /* output stream for raw error */
-H5TOOLS_DLLVAR int   bin_output;                      /* binary output */
-H5TOOLS_DLLVAR int   bin_form;                        /* binary form */
-H5TOOLS_DLLVAR int   region_output;                   /* region output */
-H5TOOLS_DLLVAR int   oid_output;                      /* oid output */
-H5TOOLS_DLLVAR int   data_output;                     /* data output */
-H5TOOLS_DLLVAR int   attr_data_output;                /* attribute data output */
+H5TOOLS_DLLVAR FILE              *rawattrstream;      /* output stream for raw attribute data */
+H5TOOLS_DLLVAR FILE              *rawdatastream;      /* output stream for raw data */
+H5TOOLS_DLLVAR FILE              *rawinstream;        /* input stream for raw input */
+H5TOOLS_DLLVAR FILE              *rawoutstream;       /* output stream for raw output */
+H5TOOLS_DLLVAR FILE              *rawerrorstream;     /* output stream for raw error */
+H5TOOLS_DLLVAR int                bin_output;         /* binary output */
+H5TOOLS_DLLVAR int                bin_form;           /* binary form */
+H5TOOLS_DLLVAR int                region_output;      /* region output */
+H5TOOLS_DLLVAR int                oid_output;         /* oid output */
+H5TOOLS_DLLVAR int                data_output;        /* data output */
+H5TOOLS_DLLVAR int                attr_data_output;   /* attribute data output */
 
 /* sort parameters */
 H5TOOLS_DLLVAR H5_index_t      sort_by;    /* sort_by [creation_order | name]  */
