@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -44,7 +43,7 @@ typedef struct H5LD_memb_t {
 /* Variable length string datatype */
 #define STR_INIT_LEN 4096 /*initial length            */
 
-static char *  h5tools_escape(char *s, size_t size);
+static char   *h5tools_escape(char *s, size_t size);
 static hbool_t h5tools_str_is_zero(const void *_mem, size_t size);
 static void    h5tools_print_char(h5tools_str_t *str, const h5tool_format_t *info, char ch);
 void           h5tools_str_indent(h5tools_str_t *str, const h5tool_format_t *info, h5tools_context_t *ctx);
@@ -264,7 +263,9 @@ h5tools_str_fmt(h5tools_str_t *str /*in,out*/, size_t start, const char *fmt)
 
     /* Reset the output string and append a formatted version */
     h5tools_str_trunc(str, start);
+    H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
     h5tools_str_append(str, fmt, temp);
+    H5_GCC_CLANG_DIAG_ON("format-nonliteral")
 
     /* Free the temp buffer if we allocated one */
     if (temp != _temp)
@@ -300,11 +301,18 @@ h5tools_str_prefix(h5tools_str_t *str /*in,out*/, const h5tool_format_t *info, h
             if (i)
                 h5tools_str_append(str, "%s", OPT(info->idx_sep, ","));
 
-            h5tools_str_append(str, OPT(info->idx_n_fmt, HSIZE_T_FORMAT), (hsize_t)ctx->pos[i]);
+            H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
+            h5tools_str_append(str, OPT(info->idx_n_fmt, "%" PRIuHSIZE), (hsize_t)ctx->pos[i]);
+            H5_GCC_CLANG_DIAG_ON("format-nonliteral")
         }
     }
-    else /* Scalar */
-        h5tools_str_append(str, OPT(info->idx_n_fmt, HSIZE_T_FORMAT), (hsize_t)elmtno);
+    else {
+        /* Scalar */
+        H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
+        h5tools_str_append(str, OPT(info->idx_n_fmt, "%" PRIuHSIZE), (hsize_t)elmtno);
+        H5_GCC_CLANG_DIAG_ON("format-nonliteral")
+    }
+
     H5TOOLS_DEBUG("str=%s", str->s);
 
     H5TOOLS_ENDDEBUG(" ");
@@ -341,11 +349,18 @@ h5tools_str_region_prefix(h5tools_str_t *str /*in,out*/, const h5tool_format_t *
             if (i)
                 h5tools_str_append(str, "%s", OPT(info->idx_sep, ","));
 
-            h5tools_str_append(str, OPT(info->idx_n_fmt, HSIZE_T_FORMAT), (hsize_t)ctx->pos[i]);
+            H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
+            h5tools_str_append(str, OPT(info->idx_n_fmt, "%" PRIuHSIZE), (hsize_t)ctx->pos[i]);
+            H5_GCC_CLANG_DIAG_ON("format-nonliteral")
         }
     }
-    else /* Scalar */
-        h5tools_str_append(str, OPT(info->idx_n_fmt, HSIZE_T_FORMAT), (hsize_t)0);
+    else {
+        /* Scalar */
+        H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
+        h5tools_str_append(str, OPT(info->idx_n_fmt, "%" PRIuHSIZE), (hsize_t)0);
+        H5_GCC_CLANG_DIAG_ON("format-nonliteral")
+    }
+
     H5TOOLS_DEBUG("str=%s", str->s);
 
     H5TOOLS_ENDDEBUG(" ");
@@ -385,7 +400,7 @@ h5tools_str_dump_space_slabs(h5tools_str_t *str, hid_t rspace, const h5tool_form
     /* Start coordinates */
     h5tools_str_append(str, "%s%s ", info->line_indent, START);
     for (j = 0; j < ndims; j++)
-        h5tools_str_append(str, "%s" HSIZE_T_FORMAT, j ? "," : "(", start[j]);
+        h5tools_str_append(str, "%s%" PRIuHSIZE, j ? "," : "(", start[j]);
     h5tools_str_append(str, ")");
     h5tools_str_append(str, "%s", "\n");
     h5tools_str_indent(str, info, ctx);
@@ -393,7 +408,7 @@ h5tools_str_dump_space_slabs(h5tools_str_t *str, hid_t rspace, const h5tool_form
     /* Stride coordinates */
     h5tools_str_append(str, "%s ", STRIDE);
     for (j = 0; j < ndims; j++)
-        h5tools_str_append(str, "%s" HSIZE_T_FORMAT, j ? "," : "(", stride[j]);
+        h5tools_str_append(str, "%s%" PRIuHSIZE, j ? "," : "(", stride[j]);
     h5tools_str_append(str, ")");
     h5tools_str_append(str, "%s", "\n");
     h5tools_str_indent(str, info, ctx);
@@ -404,7 +419,7 @@ h5tools_str_dump_space_slabs(h5tools_str_t *str, hid_t rspace, const h5tool_form
         if (count[j] == H5S_UNLIMITED)
             h5tools_str_append(str, "%s%s", j ? "," : "(", "H5S_UNLIMITED");
         else
-            h5tools_str_append(str, "%s" HSIZE_T_FORMAT, j ? "," : "(", count[j]);
+            h5tools_str_append(str, "%s%" PRIuHSIZE, j ? "," : "(", count[j]);
     }
     h5tools_str_append(str, ")");
     h5tools_str_append(str, "%s", "\n");
@@ -416,7 +431,7 @@ h5tools_str_dump_space_slabs(h5tools_str_t *str, hid_t rspace, const h5tool_form
         if (block[j] == H5S_UNLIMITED)
             h5tools_str_append(str, "%s%s", j ? "," : "(", "H5S_UNLIMITED");
         else
-            h5tools_str_append(str, "%s" HSIZE_T_FORMAT, j ? "," : "(", block[j]);
+            h5tools_str_append(str, "%s%" PRIuHSIZE, j ? "," : "(", block[j]);
     }
     h5tools_str_append(str, ")");
 }
@@ -463,18 +478,19 @@ h5tools_str_dump_space_blocks(h5tools_str_t *str, hid_t rspace, const h5tool_for
         for (u = 0; u < nblocks; u++) {
             unsigned v;
 
+            H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
             h5tools_str_append(str, info->dset_blockformat_pre, u ? "," OPTIONAL_LINE_BREAK " " : "",
                                (unsigned long)u);
 
             /* Start coordinates and opposite corner */
             for (v = 0; v < ndims; v++)
-                h5tools_str_append(str, "%s" HSIZE_T_FORMAT, v ? "," : "(", ptdata[u * 2 * ndims + v]);
+                h5tools_str_append(str, "%s%" PRIuHSIZE, v ? "," : "(", ptdata[u * 2 * ndims + v]);
 
             for (v = 0; v < ndims; v++)
-                h5tools_str_append(str, "%s" HSIZE_T_FORMAT, v ? "," : ")-(",
-                                   ptdata[u * 2 * ndims + v + ndims]);
+                h5tools_str_append(str, "%s%" PRIuHSIZE, v ? "," : ")-(", ptdata[u * 2 * ndims + v + ndims]);
 
             h5tools_str_append(str, ")");
+            H5_GCC_CLANG_DIAG_ON("format-nonliteral")
         }
 
         HDfree(ptdata);
@@ -523,13 +539,15 @@ h5tools_str_dump_space_points(h5tools_str_t *str, hid_t rspace, const h5tool_for
         for (u = 0; u < npoints; u++) {
             unsigned v;
 
+            H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
             h5tools_str_append(str, info->dset_ptformat_pre, u ? "," OPTIONAL_LINE_BREAK " " : "",
                                (unsigned long)u);
 
             for (v = 0; v < ndims; v++)
-                h5tools_str_append(str, "%s" HSIZE_T_FORMAT, v ? "," : "(", (ptdata[u * ndims + v]));
+                h5tools_str_append(str, "%s%" PRIuHSIZE, v ? "," : "(", (ptdata[u * ndims + v]));
 
             h5tools_str_append(str, ")");
+            H5_GCC_CLANG_DIAG_ON("format-nonliteral")
         }
 
         HDfree(ptdata);
@@ -648,21 +666,23 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 {
     size_t         nsize, offset, size = 0, nelmts, start;
     H5T_sign_t     nsign;
-    char *         name   = NULL;
+    char          *name   = NULL;
     unsigned char *ucp_vp = (unsigned char *)vp;
-    char *         cp_vp  = (char *)vp;
+    char          *cp_vp  = (char *)vp;
     hid_t          memb   = H5I_INVALID_HID;
     hid_t          obj    = H5I_INVALID_HID;
     static char    fmt_llong[8], fmt_ullong[8];
     H5T_str_t      pad;
     H5T_class_t    type_class;
-    char *         ret_value = NULL;
+    char          *ret_value = NULL;
+
+    H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
 
     H5TOOLS_START_DEBUG(" ");
     /* Build default formats for long long types */
     if (!fmt_llong[0]) {
-        HDsnprintf(fmt_llong, sizeof(fmt_llong), "%%%sd", H5_PRINTF_LL_WIDTH);
-        HDsnprintf(fmt_ullong, sizeof(fmt_ullong), "%%%su", H5_PRINTF_LL_WIDTH);
+        HDsnprintf(fmt_llong, sizeof(fmt_llong), "%%lld");
+        HDsnprintf(fmt_ullong, sizeof(fmt_ullong), "%%llu");
     }
 
     /* Append value depending on data type */
@@ -727,7 +747,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
             case H5T_STRING: {
                 unsigned int i;
                 char         quote = '\0';
-                char *       s;
+                char        *s;
 
                 H5TOOLS_DEBUG("H5T_STRING");
                 quote = '\0';
@@ -1052,7 +1072,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 
                 H5TOOLS_DEBUG("H5T_ENUM");
                 if (H5Tenum_nameof(type, vp, enum_name, sizeof enum_name) >= 0)
-                    h5tools_str_append(str, h5tools_escape(enum_name, sizeof(enum_name)));
+                    h5tools_str_append(str, "%s", h5tools_escape(enum_name, sizeof(enum_name)));
                 else {
                     size_t i;
                     if (1 == nsize)
@@ -1080,7 +1100,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
                             case H5R_OBJECT1: {
                                 /* Object references -- show the type and OID of the referenced object. */
                                 H5O_info2_t oi;
-                                char *      obj_tok_str = NULL;
+                                char       *obj_tok_str = NULL;
 
                                 H5TOOLS_DEBUG("ref_type is H5R_OBJECT1");
                                 if ((obj = H5Ropen_object(ref_vp, H5P_DEFAULT, H5P_DEFAULT)) >= 0) {
@@ -1175,16 +1195,63 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
                             case H5R_MAXTYPE:
                             default:
                                 break;
-                        } /* end switch */
+                        }
                         H5TOOLS_DEBUG("H5T_REFERENCE:H5T_STD_REF end");
                     }
                     else if (H5Tequal(type, H5T_STD_REF_DSETREG)) {
                         /* if(nsize == H5R_DSET_REG_REF_BUF_SIZE) */
                         H5TOOLS_DEBUG("H5T_REFERENCE:H5T_STD_REF_DSETREG");
+                        h5tools_str_append(str, H5_TOOLS_DATASET);
+                        h5tools_str_sprint_old_reference(str, container, H5R_DATASET_REGION, vp);
                     }
                     else if (H5Tequal(type, H5T_STD_REF_OBJ)) {
                         /* if (nsize == H5R_OBJ_REF_BUF_SIZE) */
+                        /*
+                         * Object references -- show the type and OID of the referenced object.
+                         */
+                        H5O_info2_t oi;
+                        char       *obj_tok_str = NULL;
+
                         H5TOOLS_DEBUG("H5T_REFERENCE:H5T_STD_REF_OBJ");
+                        obj = H5Rdereference2(container, H5P_DEFAULT, H5R_OBJECT, vp);
+                        H5Oget_info3(obj, &oi, H5O_INFO_BASIC);
+
+                        /* Print object type and close object */
+                        switch (oi.type) {
+                            case H5O_TYPE_GROUP:
+                                h5tools_str_append(str, H5_TOOLS_GROUP);
+                                break;
+
+                            case H5O_TYPE_DATASET:
+                                h5tools_str_append(str, H5_TOOLS_DATASET);
+                                break;
+
+                            case H5O_TYPE_NAMED_DATATYPE:
+                                h5tools_str_append(str, H5_TOOLS_DATATYPE);
+                                break;
+
+                            case H5O_TYPE_UNKNOWN:
+                            case H5O_TYPE_NTYPES:
+                            default:
+                                h5tools_str_append(str, "%u-", (unsigned)oi.type);
+                                break;
+                        }
+                        H5Oclose(obj);
+
+                        /* Print OID */
+                        H5Otoken_to_str(obj, &oi.token, &obj_tok_str);
+
+                        if (info->obj_hidefileno)
+                            h5tools_str_append(str, info->obj_format, obj_tok_str);
+                        else
+                            h5tools_str_append(str, info->obj_format, oi.fileno, obj_tok_str);
+
+                        if (obj_tok_str) {
+                            H5free_memory(obj_tok_str);
+                            obj_tok_str = NULL;
+                        }
+
+                        h5tools_str_sprint_old_reference(str, container, H5R_OBJECT, vp);
                     } /* end else if (H5Tequal(type, H5T_STD_REF_OBJ)) */
                 }
                 break;
@@ -1265,6 +1332,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
                 nelmts = ((hvl_t *)((void *)cp_vp))->len;
 
                 for (i = 0; i < nelmts; i++) {
+                    H5TOOLS_DEBUG("H5T_VLEN %d of %ld", i, nelmts);
                     if (i)
                         h5tools_str_append(str, "%s", OPT(info->vlen_sep, "," OPTIONAL_LINE_BREAK));
 
@@ -1321,10 +1389,56 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 
     ret_value = h5tools_str_fmt(str, start, OPT(info->elmt_fmt, "%s"));
 
+    H5_GCC_CLANG_DIAG_ON("format-nonliteral")
+
     H5TOOLS_ENDDEBUG(" with %s", ret_value);
     return ret_value;
 }
 
+/*-------------------------------------------------------------------------
+ * Function:    h5tools_str_sprint_old_reference
+ *
+ * Purpose: Object reference -- show the name of the old referenced object.
+ *
+ * Return:  Nothing
+ *-------------------------------------------------------------------------
+ */
+void
+h5tools_str_sprint_old_reference(h5tools_str_t *str, hid_t container, H5R_type_t ref_type, void *vp)
+{
+    hid_t obj    = H5I_INVALID_HID;
+    hid_t region = H5I_INVALID_HID;
+    char  ref_name[1024];
+
+    H5TOOLS_START_DEBUG(" ");
+
+    h5tools_str_append(str, " \"");
+    if (ref_type == H5R_DATASET_REGION) {
+        obj = H5Rdereference2(container, H5P_DEFAULT, ref_type, vp);
+        if (obj >= 0) {
+            region = H5Rget_region(container, ref_type, vp);
+            if (region >= 0) {
+                H5Rget_name(obj, ref_type, vp, (char *)ref_name, 1024);
+                h5tools_str_append(str, "%s", ref_name);
+
+                H5Sclose(region);
+            } /* end if (region >= 0) */
+            H5Dclose(obj);
+        } /* end if (obj >= 0) */
+    }
+    else if (ref_type == H5R_OBJECT) {
+        obj = H5Rdereference2(container, H5P_DEFAULT, ref_type, vp);
+        if (obj >= 0) {
+            H5Rget_name(obj, ref_type, vp, (char *)ref_name, 1024);
+            h5tools_str_append(str, "%s", ref_name);
+            H5Dclose(obj);
+        }
+    }
+    h5tools_str_append(str, "\"");
+
+    H5TOOLS_ENDDEBUG(" ");
+}
+
 /*-------------------------------------------------------------------------
  * Function:    h5tools_str_sprint_reference
  *
@@ -1402,10 +1516,10 @@ h5tools_str_sprint_reference(h5tools_str_t *str, H5R_ref_t *ref_vp)
 static char *
 h5tools_escape(char *s /*in,out*/, size_t size)
 {
-    register size_t i;
-    const char *    escape;
-    char            octal[8];
-    size_t          n = HDstrlen(s);
+    size_t      i;
+    const char *escape;
+    char        octal[8];
+    size_t      n = HDstrlen(s);
 
     for (i = 0; i < n; i++) {
         switch (s[i]) {
