@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -38,11 +37,11 @@ static int   verbose_g = 0;
  * Command-line options: The user can specify short or long-named
  * parameters.
  */
-static const char *        s_opts   = "hVvd:n";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'},    {"version", no_arg, 'V'},
-                                       {"verbose", no_arg, 'v'}, {"dname", require_arg, 'd'},
-                                       {"noop", no_arg, 'n'},    {"enable-error-stack", no_arg, 'E'},
-                                       {NULL, 0, '\0'}};
+static const char            *s_opts   = "hVvd:n";
+static struct h5_long_options l_opts[] = {{"help", no_arg, 'h'},    {"version", no_arg, 'V'},
+                                          {"verbose", no_arg, 'v'}, {"dname", require_arg, 'd'},
+                                          {"noop", no_arg, 'n'},    {"enable-error-stack", no_arg, 'E'},
+                                          {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
  * Function: usage
@@ -106,7 +105,7 @@ parse_command_line(int argc, const char *const *argv)
     }
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'h':
                 usage(h5tools_getprogname());
@@ -123,11 +122,11 @@ parse_command_line(int argc, const char *const *argv)
                 break;
 
             case 'd': /* -d dname */
-                if (opt_arg != NULL && *opt_arg)
-                    dname_g = HDstrdup(opt_arg);
+                if (H5_optarg != NULL && *H5_optarg)
+                    dname_g = HDstrdup(H5_optarg);
                 if (dname_g == NULL) {
                     h5tools_setstatus(EXIT_FAILURE);
-                    error_msg("No dataset name\n", opt_arg);
+                    error_msg("No dataset name `%s`\n", H5_optarg);
                     usage(h5tools_getprogname());
                     goto error;
                 }
@@ -150,14 +149,14 @@ parse_command_line(int argc, const char *const *argv)
         } /* switch */
     }     /* while */
 
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
         h5tools_setstatus(EXIT_FAILURE);
         goto error;
     }
 
-    fname_g = HDstrdup(argv[opt_ind]);
+    fname_g = HDstrdup(argv[H5_optind]);
 
     return 0;
 
