@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -240,14 +239,14 @@ main(int argc, char *argv[])
     hid_t          fid  = H5I_INVALID_HID;
     hid_t          fapl = H5I_INVALID_HID;
     H5VL_object_t *vol_obj;
-    H5F_t *        f;
+    H5F_t         *f;
     haddr_t        addr        = 0;
     int            extra_count = 0; /* Number of extra arguments */
     haddr_t        extra[10];
     uint8_t        sig[H5F_SIGNATURE_LEN];
     size_t         u;
     H5E_auto2_t    func           = NULL;
-    void *         edata          = NULL;
+    void          *edata          = NULL;
     hbool_t        api_ctx_pushed = FALSE; /* Whether API context pushed */
     herr_t         status         = SUCCEED;
     int            exit_value     = 0;
@@ -647,7 +646,7 @@ main(int argc, char *argv[])
     }
     else if (!HDmemcmp(sig, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
-         * Debug an extensible aray header.
+         * Debug an extensible array header.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
         HDassert(cls);
@@ -668,7 +667,7 @@ main(int argc, char *argv[])
     }
     else if (!HDmemcmp(sig, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
-         * Debug an extensible aray index block.
+         * Debug an extensible array index block.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
         HDassert(cls);
@@ -689,7 +688,7 @@ main(int argc, char *argv[])
     }
     else if (!HDmemcmp(sig, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
-         * Debug an extensible aray super block.
+         * Debug an extensible array super block.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
         HDassert(cls);
@@ -709,7 +708,7 @@ main(int argc, char *argv[])
     }
     else if (!HDmemcmp(sig, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
-         * Debug an extensible aray data block.
+         * Debug an extensible array data block.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
         HDassert(cls);
@@ -816,12 +815,16 @@ main(int argc, char *argv[])
 done:
     if (fapl > 0)
         H5Pclose(fapl);
-    if (fid > 0)
-        H5Fclose(fid);
+    if (fid > 0) {
+        if (H5Fclose(fid) < 0) {
+            HDfprintf(stderr, "Error in closing file!\n");
+            exit_value = 1;
+        }
+    }
 
     /* Pop API context */
     if (api_ctx_pushed)
-        H5CX_pop();
+        H5CX_pop(FALSE);
 
     H5Eset_auto2(H5E_DEFAULT, func, edata);
 
