@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -35,7 +34,7 @@
 #define MICROSECOND 1000000.0
 
 /* report 0.0 in case t is zero too */
-#define MB_PER_SEC(bytes, t) ((fabs(t) < 0.0000000001) ? 0.0 : ((((double)bytes) / (double)ONE_MB) / (t)))
+#define MB_PER_SEC(bytes, t) ((fabs(t) < 0.0000000001) ? 0.0 : ((((double)(bytes)) / (double)ONE_MB) / (t)))
 
 #ifndef TRUE
 #define TRUE 1
@@ -52,7 +51,7 @@
 /* internal variables */
 static const char *prog             = NULL;
 static const char *option_prefix    = NULL;
-static char *      filename         = NULL;
+static char       *filename         = NULL;
 static int         compress_percent = 0;
 static int         compress_level   = Z_DEFAULT_COMPRESSION;
 static int         output, random_test = FALSE;
@@ -64,66 +63,15 @@ static void error(const char *fmt, ...);
 static void compress_buffer(Bytef *dest, uLongf *destLen, const Bytef *source, uLong sourceLen);
 
 /* commandline options : long and short form */
-static const char *        s_opts   = "hB:b:c:p:rs:0123456789";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'},
-                                       {"compressability", require_arg, 'c'},
-                                       {"compressabilit", require_arg, 'c'},
-                                       {"compressabili", require_arg, 'c'},
-                                       {"compressabil", require_arg, 'c'},
-                                       {"compressabi", require_arg, 'c'},
-                                       {"compressab", require_arg, 'c'},
-                                       {"compressa", require_arg, 'c'},
-                                       {"compress", require_arg, 'c'},
-                                       {"compres", require_arg, 'c'},
-                                       {"compre", require_arg, 'c'},
-                                       {"compr", require_arg, 'c'},
-                                       {"comp", require_arg, 'c'},
-                                       {"com", require_arg, 'c'},
-                                       {"co", require_arg, 'c'},
-                                       {"file-size", require_arg, 's'},
-                                       {"file-siz", require_arg, 's'},
-                                       {"file-si", require_arg, 's'},
-                                       {"file-s", require_arg, 's'},
-                                       {"file", require_arg, 's'},
-                                       {"fil", require_arg, 's'},
-                                       {"fi", require_arg, 's'},
-                                       {"max-buffer-size", require_arg, 'B'},
-                                       {"max-buffer-siz", require_arg, 'B'},
-                                       {"max-buffer-si", require_arg, 'B'},
-                                       {"max-buffer-s", require_arg, 'B'},
-                                       {"max-buffer", require_arg, 'B'},
-                                       {"max-buffe", require_arg, 'B'},
-                                       {"max-buff", require_arg, 'B'},
-                                       {"max-buf", require_arg, 'B'},
-                                       {"max-bu", require_arg, 'B'},
-                                       {"max-b", require_arg, 'B'},
-                                       {"max", require_arg, 'B'},
-                                       {"min-buffer-size", require_arg, 'b'},
-                                       {"min-buffer-siz", require_arg, 'b'},
-                                       {"min-buffer-si", require_arg, 'b'},
-                                       {"min-buffer-s", require_arg, 'b'},
-                                       {"min-buffer", require_arg, 'b'},
-                                       {"min-buffe", require_arg, 'b'},
-                                       {"min-buff", require_arg, 'b'},
-                                       {"min-buf", require_arg, 'b'},
-                                       {"min-bu", require_arg, 'b'},
-                                       {"min-b", require_arg, 'b'},
-                                       {"min", require_arg, 'b'},
-                                       {"prefix", require_arg, 'p'},
-                                       {"prefi", require_arg, 'p'},
-                                       {"pref", require_arg, 'p'},
-                                       {"pre", require_arg, 'p'},
-                                       {"pr", require_arg, 'p'},
-                                       {"random-test", no_arg, 'r'},
-                                       {"random-tes", no_arg, 'r'},
-                                       {"random-te", no_arg, 'r'},
-                                       {"random-t", no_arg, 'r'},
-                                       {"random", no_arg, 'r'},
-                                       {"rando", no_arg, 'r'},
-                                       {"rand", no_arg, 'r'},
-                                       {"ran", no_arg, 'r'},
-                                       {"ra", no_arg, 'r'},
-                                       {NULL, 0, '\0'}};
+static const char            *s_opts   = "hB:b:c:p:rs:0123456789";
+static struct h5_long_options l_opts[] = {{"help", no_arg, 'h'},
+                                          {"compressability", require_arg, 'c'},
+                                          {"file-size", require_arg, 's'},
+                                          {"max-buffer-size", require_arg, 'B'},
+                                          {"min-buffer-size", require_arg, 'b'},
+                                          {"prefix", require_arg, 'p'},
+                                          {"random-test", no_arg, 'r'},
+                                          {NULL, 0, '\0'}};
 
 /*
  * Function:    error
@@ -138,7 +86,9 @@ error(const char *fmt, ...)
 
     va_start(ap, fmt);
     HDfprintf(stderr, "%s: error: ", prog);
+    H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
     HDvfprintf(stderr, fmt, ap);
+    H5_GCC_CLANG_DIAG_ON("format-nonliteral")
     HDfprintf(stderr, "\n");
     va_end(ap);
     HDexit(EXIT_FAILURE);
@@ -154,7 +104,7 @@ error(const char *fmt, ...)
 static void
 cleanup(void)
 {
-    if (!HDgetenv("HDF5_NOCLEANUP"))
+    if (!HDgetenv(HDF5_NOCLEANUP))
         HDunlink(filename);
     HDfree(filename);
 }
@@ -162,7 +112,7 @@ cleanup(void)
 static void
 write_file(Bytef *source, uLongf sourceLen)
 {
-    Bytef *        d_ptr, *dest;
+    Bytef         *d_ptr, *dest;
     uLongf         d_len, destLen;
     struct timeval timer_start, timer_stop;
 
@@ -318,7 +268,7 @@ usage(void)
     HDfprintf(stdout, "                                data you want [default: 0]");
     HDfprintf(stdout, "     -s S, --file-size=S        Maximum size of uncompressed file [default: 64M]\n");
     HDfprintf(stdout, "     -B S, --max-buffer_size=S  Maximum size of buffer [default: 1M]\n");
-    HDfprintf(stdout, "     -b S, --min-buffer_size=S  Minumum size of buffer [default: 128K]\n");
+    HDfprintf(stdout, "     -b S, --min-buffer_size=S  Minimum size of buffer [default: 128K]\n");
     HDfprintf(stdout, "     -p D, --prefix=D           The directory prefix to place the file\n");
     HDfprintf(stdout, "     -r, --random-test          Use random data to write to the file\n");
     HDfprintf(stdout, "                                [default: no]\n");
@@ -354,7 +304,7 @@ static unsigned long
 parse_size_directive(const char *size)
 {
     unsigned long s;
-    char *        endptr;
+    char         *endptr;
 
     s = HDstrtoul(size, &endptr, 10);
 
@@ -387,8 +337,8 @@ parse_size_directive(const char *size)
 static void
 fill_with_random_data(Bytef *src, uLongf src_len)
 {
-    register unsigned u;
-    h5_stat_t         stat_buf;
+    unsigned  u;
+    h5_stat_t stat_buf;
 
     if (HDstat("/dev/urandom", &stat_buf) == 0) {
         uLongf len = src_len;
@@ -434,10 +384,10 @@ do_write_test(unsigned long file_size, unsigned long min_buf_size, unsigned long
     uLongf         src_len, total_len;
     struct timeval timer_start, timer_stop;
     double         total_time;
-    Bytef *        src;
+    Bytef         *src;
 
     for (src_len = min_buf_size; src_len <= max_buf_size; src_len <<= 1) {
-        register unsigned long i, iters;
+        unsigned long i, iters;
 
         iters = file_size / src_len;
         src   = (Bytef *)HDcalloc(1, sizeof(Bytef) * src_len);
@@ -447,7 +397,7 @@ do_write_test(unsigned long file_size, unsigned long min_buf_size, unsigned long
             error("out of memory");
         }
 
-        compression_time = 0.0F;
+        compression_time = 0.0;
 
         if (random_test)
             fill_with_random_data(src, src_len);
@@ -540,7 +490,7 @@ do_write_test(unsigned long file_size, unsigned long min_buf_size, unsigned long
  * Modifications:
  */
 int
-main(int argc, const char *argv[])
+main(int argc, char *argv[])
 {
     unsigned long min_buf_size = 128 * ONE_KB, max_buf_size = ONE_MB;
     unsigned long file_size = 64 * ONE_MB;
@@ -551,7 +501,7 @@ main(int argc, const char *argv[])
     /* Initialize h5tools lib */
     h5tools_init();
 
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) > 0) {
+    while ((opt = H5_get_option(argc, (const char *const *)argv, s_opts, l_opts)) > 0) {
         switch ((char)opt) {
             case '0':
             case '1':
@@ -566,13 +516,13 @@ main(int argc, const char *argv[])
                 compress_level = opt - '0';
                 break;
             case 'B':
-                max_buf_size = parse_size_directive(opt_arg);
+                max_buf_size = parse_size_directive(H5_optarg);
                 break;
             case 'b':
-                min_buf_size = parse_size_directive(opt_arg);
+                min_buf_size = parse_size_directive(H5_optarg);
                 break;
             case 'c':
-                compress_percent = (int)HDstrtol(opt_arg, NULL, 10);
+                compress_percent = (int)HDstrtol(H5_optarg, NULL, 10);
 
                 if (compress_percent < 0)
                     compress_percent = 0;
@@ -581,13 +531,13 @@ main(int argc, const char *argv[])
 
                 break;
             case 'p':
-                option_prefix = opt_arg;
+                option_prefix = H5_optarg;
                 break;
             case 'r':
                 random_test = TRUE;
                 break;
             case 's':
-                file_size = parse_size_directive(opt_arg);
+                file_size = parse_size_directive(H5_optarg);
                 break;
             case '?':
                 usage();
@@ -602,7 +552,7 @@ main(int argc, const char *argv[])
     }
 
     if (min_buf_size > max_buf_size)
-        error("minmum buffer size (%d) exceeds maximum buffer size (%d)", min_buf_size, max_buf_size);
+        error("minimum buffer size (%d) exceeds maximum buffer size (%d)", min_buf_size, max_buf_size);
 
     HDfprintf(stdout, "Filesize: %ld\n", file_size);
 
